@@ -30,11 +30,13 @@ public:
 	static AccountHandler * static_constructor();
 
 	// dialog management
-	virtual void			embedDialogWidgets(void* embeddingParent);
+	virtual void			embedDialogWidgets(void* pEmbeddingParent);
+	virtual void			removeDialogWidgets(void* pEmbeddingParent);
 	virtual void			storeProperties();
 
 private:
 	// dialog management
+	GtkWidget*				table;
 	GtkWidget*				username_entry;
 	GtkWidget*				password_entry;
 	GtkWidget*				server_entry;
