@@ -171,8 +171,9 @@ UT_sint32 XMPPAccountHandler::connect()
 	
 	UT_return_val_if_fail(m_pConnection == 0, -1); // internal error, we still seem to be connected
 
+	// try to request a frame here; note that this might return 0, for example
+	// on application startup
 	XAP_Frame *pFrame = XAP_App::getApp()->getLastFocussedFrame();
-	UT_return_val_if_fail(pFrame, -1);	
 	
 	const std::string server = getProperty("server");
 	const std::string port = getProperty("port"); // TODO: unused atm
@@ -193,13 +194,15 @@ UT_sint32 XMPPAccountHandler::connect()
 			lm_connection_unref(m_pConnection);
 			m_pConnection = NULL;
 			
-			// inform the user of the connection failure
-			// TODO: this shouldn't be here, the caller should handle this
-			UT_UTF8String msg;
-			// TODO: make this localizable
-			UT_UTF8String_sprintf(msg, "Error while connecting to %s: %s\n", server.c_str(), (error ? error->message : "")); 
-			pFrame->showMessageBox(msg.utf8_str(), XAP_Dialog_MessageBox::b_O, XAP_Dialog_MessageBox::a_OK);
-						
+			if (pFrame)
+			{
+				// inform the user of the connection failure
+				// TODO: this shouldn't be here, the caller should handle this
+				UT_UTF8String msg;
+				// TODO: make this localizable
+				UT_UTF8String_sprintf(msg, "Error while connecting to %s: %s\n", server.c_str(), (error ? error->message : "")); 
+				pFrame->showMessageBox(msg.utf8_str(), XAP_Dialog_MessageBox::b_O, XAP_Dialog_MessageBox::a_OK);
+			}			
 			return 2; // no connection
 		}
 		UT_DEBUGMSG(("connect() - connection established!\n"));
@@ -215,13 +218,15 @@ UT_sint32 XMPPAccountHandler::connect()
 			lm_connection_unref(m_pConnection);
 			m_pConnection = NULL;
 			
-			// inform the user of the authentication failure
-			// TODO: this shouldn't be here, the caller should handle this
-			UT_UTF8String msg;
-			// TODO: make this localizable
-			UT_UTF8String_sprintf(msg, "Error while connecting to %s: %s\n", server.c_str(), (error ? error->message : "")); 
-			pFrame->showMessageBox(msg.utf8_str(), XAP_Dialog_MessageBox::b_O, XAP_Dialog_MessageBox::a_OK);
-
+			if (pFrame)
+			{
+				// inform the user of the authentication failure
+				// TODO: this shouldn't be here, the caller should handle this
+				UT_UTF8String msg;
+				// TODO: make this localizable
+				UT_UTF8String_sprintf(msg, "Error while connecting to %s: %s\n", server.c_str(), (error ? error->message : "")); 
+				pFrame->showMessageBox(msg.utf8_str(), XAP_Dialog_MessageBox::b_O, XAP_Dialog_MessageBox::a_OK);
+			}
 			return 3; // Invalid authentication
 		}
 		UT_DEBUGMSG(("connect() - user (%s) authenticated!\n", username.c_str()));
@@ -250,12 +255,15 @@ UT_sint32 XMPPAccountHandler::connect()
 			// FIXME: unregister the message handlers!
 			// ...
 			
-			// inform the user of the sending error
-			// TODO: this shouldn't be here, the caller should handle this
-			UT_UTF8String msg;
-			// TODO: make this localizable
-			UT_UTF8String_sprintf(msg, "Error while connecting to %s: %s\n", server.c_str(), (error ? error->message : "")); 
-			pFrame->showMessageBox(msg.utf8_str(), XAP_Dialog_MessageBox::b_O, XAP_Dialog_MessageBox::a_OK);			
+			if (pFrame)
+			{
+				// inform the user of the sending error
+				// TODO: this shouldn't be here, the caller should handle this
+				UT_UTF8String msg;
+				// TODO: make this localizable
+				UT_UTF8String_sprintf(msg, "Error while connecting to %s: %s\n", server.c_str(), (error ? error->message : "")); 
+				pFrame->showMessageBox(msg.utf8_str(), XAP_Dialog_MessageBox::b_O, XAP_Dialog_MessageBox::a_OK);			
+			}
 			
 			return 4; // error sending msg
 		}
@@ -281,13 +289,15 @@ UT_sint32 XMPPAccountHandler::connect()
 	{
 		UT_DEBUGMSG(("lm_connection_new error for server: %s", server.c_str()));
 		
-		// inform the user of the sending error
-		// TODO: this shouldn't be here, the caller should handle this
-		UT_UTF8String msg;
-		// TODO: make this localizable
-		UT_UTF8String_sprintf(msg, "Error while connecting to %s: internal error\n", server.c_str()); 
-		pFrame->showMessageBox(msg.utf8_str(), XAP_Dialog_MessageBox::b_O, XAP_Dialog_MessageBox::a_OK);				
-		
+		if (pFrame)
+		{
+			// inform the user of the sending error
+			// TODO: this shouldn't be here, the caller should handle this
+			UT_UTF8String msg;
+			// TODO: make this localizable
+			UT_UTF8String_sprintf(msg, "Error while connecting to %s: internal error\n", server.c_str()); 
+			pFrame->showMessageBox(msg.utf8_str(), XAP_Dialog_MessageBox::b_O, XAP_Dialog_MessageBox::a_OK);				
+		}
 		return -1; // internal error
 	}
 		
@@ -298,31 +308,34 @@ bool XMPPAccountHandler::disconnect()
 {
 	UT_DEBUGMSG(("XMPPAccountHandler::disconnect()\n"));
 
-	// unregister and destroy the message handler callbacks
-	if (m_pPresenceHandler)
+	if (m_pConnection)
 	{
-		lm_connection_unregister_message_handler(m_pConnection, m_pPresenceHandler, LM_MESSAGE_TYPE_PRESENCE);
-		lm_message_handler_unref(m_pPresenceHandler);
-		m_pPresenceHandler = NULL;
-	}
+		// unregister and destroy the message handler callbacks
+		if (m_pPresenceHandler)
+		{
+			lm_connection_unregister_message_handler(m_pConnection, m_pPresenceHandler, LM_MESSAGE_TYPE_PRESENCE);
+			lm_message_handler_unref(m_pPresenceHandler);
+			m_pPresenceHandler = NULL;
+		}
 	
-	if (m_pStreamErrorHandler)
-	{
-		lm_connection_unregister_message_handler(m_pConnection, m_pStreamErrorHandler, LM_MESSAGE_TYPE_STREAM_ERROR);
-		lm_message_handler_unref(m_pStreamErrorHandler);
-		m_pStreamErrorHandler = NULL;
-	}
+		if (m_pStreamErrorHandler)
+		{
+			lm_connection_unregister_message_handler(m_pConnection, m_pStreamErrorHandler, LM_MESSAGE_TYPE_STREAM_ERROR);
+			lm_message_handler_unref(m_pStreamErrorHandler);
+			m_pStreamErrorHandler = NULL;
+		}
 
-	if (m_pChatHandler)
-	{
-		lm_connection_unregister_message_handler(m_pConnection, m_pChatHandler, LM_MESSAGE_TYPE_MESSAGE);
-		lm_message_handler_unref(m_pChatHandler);
-		m_pChatHandler = NULL;
-	}
+		if (m_pChatHandler)
+		{
+			lm_connection_unregister_message_handler(m_pConnection, m_pChatHandler, LM_MESSAGE_TYPE_MESSAGE);
+			lm_message_handler_unref(m_pChatHandler);
+			m_pChatHandler = NULL;
+		}
 	
-	lm_connection_close(m_pConnection, NULL);
-	lm_connection_unref(m_pConnection);
-	m_pConnection = NULL;
+		lm_connection_close(m_pConnection, NULL);
+		lm_connection_unref(m_pConnection);
+		m_pConnection = NULL;
+	}
 	m_bLoggedIn = false;
 	
 	// signal all listeners we are logged out
@@ -338,18 +351,11 @@ bool XMPPAccountHandler::disconnect()
 		pManager->unregisterEventListener(this);	
 	}
 	else
-		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);	
-	
+		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
 	
 	return true;
 }
 
-bool XMPPAccountHandler::autoConnect()
-{
-	const std::string resource = getProperty("autoconnect");
-	return strcmp(resource.c_str(), "true") == 0;
-}
-
 bool XMPPAccountHandler::_send(const UT_UTF8String& packet)
 {
 	GError* error = NULL;
@@ -507,39 +513,6 @@ void XMPPAccountHandler::joinSessionAsync(const Buddy& buddy, DocHandle& docHand
 	send(NULL, sDocRequest, PT_Handler, buddy);
 }
 
-void XMPPAccountHandler::signal(const Event& event, const Buddy* pSource)
-{
-	UT_DEBUGMSG(("XMPPAccountHandler::signal()\n"));
-
-	// broadcast this event over our network (if applicable for each message type)
-	EventPacket* pPacket = event.constructPacket();
-	if (pPacket)
-	{
-		UT_GenericVector<Buddy*> vRecipients = 
-			(event.isBroadcast() ? getBuddies() : event.getRecipients());
-		
-		for (UT_sint32 i = 0; i < vRecipients.getItemCount(); i++)
-		{
-			Buddy* pRecipient = vRecipients.getNthItem(i);
-			if (pRecipient)
-			{
-				if (!pSource || 
-					(pSource && pRecipient->getName() != pSource->getName())
-					)
-				{
-					send(0, pPacket->serialize(), pPacket->getType(), *pRecipient);
-				}
-				else
-				{
-					// the event came originated at this buddy, so make sure not to send it
-					// back to him, as it would result in a broadcast storm and
-					// kill the network really fast
-				}
-			}
-		}
-	}
-}
-
 /* 
  * packet handling functions 
  */
