@@ -2,7 +2,7 @@
 
 /* AbiCollab- Code to enable the modification of remote documents.
  * Copyright (C) 2005 by Martin Sevior
- * Copyright (C) 2006 by Marc Maurer <uwog@uwog.net>
+ * Copyright (C) 2006,2007 by Marc Maurer <uwog@uwog.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -58,8 +58,13 @@
 // session includes
 #include "AbiCollab.h"
 
-// accounts includes
+// account handler includes
+#ifdef ABICOLLAB_HANDLER_XMPP
 #include <handlers/xmpp/xp/XMPPAccountHandler.h>
+#endif
+#ifdef ABICOLLAB_HANDLER_TCP
+#include <handlers/tcp/xp/TCPAccountHandler.h>
+#endif
 
 // event includes
 #include <handlers/xp/Event.h>
@@ -179,7 +184,12 @@ bool AbiCollabSessionManager::registerDialogs(void)
 
 bool AbiCollabSessionManager::registerAccountHandlers(void)
 {
+#ifdef ABICOLLAB_HANDLER_XMPP
 	m_regAccountHandlers.push_back(XMPPAccountHandlerConstructor);
+#endif
+#ifdef ABICOLLAB_HANDLER_TCP
+	m_regAccountHandlers.push_back(TCPAccountHandlerConstructor);
+#endif
 	return true;
 }
 
@@ -202,9 +212,12 @@ bool AbiCollabSessionManager::unregisterDialogs(void)
 
 void AbiCollabSessionManager::loadProfile()
 {
-	UT_DEBUGMSG(("AbiCollabSessionManager::loadProfile()"));
+	UT_DEBUGMSG(("AbiCollabSessionManager::loadProfile()\n"));
 
-	UT_UTF8String profile = UT_catPathname(XAP_App::getApp() -> getUserPrivateDirectory(), "AbiCollab.Profile");
+	gchar *s = g_build_filename(XAP_App::getApp()->getUserPrivateDirectory(), 
+								"AbiCollab.Profile", NULL);
+	UT_UTF8String profile(s);
+	FREEP(s);
 
 	GsfInput* in = NULL;
 	char *uri = UT_go_filename_to_uri(profile.utf8_str());
@@ -385,7 +398,12 @@ void AbiCollabSessionManager::storeProfile()
 			xmlTextWriterEndDocument(writer);
 			xmlFreeTextWriter(writer);
 
-			UT_UTF8String profile = UT_catPathname(XAP_App::getApp()->getUserPrivateDirectory(), "AbiCollab.Profile");
+			gchar * s = g_build_filename(XAP_App::getApp()->getUserPrivateDirectory(), 
+										 "AbiCollab.Profile",NULL);
+			UT_UTF8String profile(s);
+			FREEP(s);
+
+
 			GsfOutput* out = UT_go_file_create (profile.utf8_str(), NULL);
 			if (out)
 			{
@@ -485,7 +503,7 @@ AbiCollab* AbiCollabSessionManager::getSessionFromDocumentId(const UT_UTF8String
 		if (pCollab)
 		{
 			PD_Document* pDoc = pCollab->getDocument();
-			if (pDoc->getDocUUIDString() == sDocumentId)
+			if (strcmp(pDoc->getDocUUIDString(), sDocumentId.utf8_str()) == 0)
 			{
 				return pCollab;
 			}
