@@ -498,7 +498,7 @@ bool ABI_Collab_Export::mapChangeRecordToString(const PX_ChangeRecord * pcr,
 			     bool b = m_pDoc->getAttrProp(indexAP, &pAP);
 			     UT_DEBUGMSG(("dataItem Index = %d pAP %x \n",indexAP,pAP));
 			     UT_return_val_if_fail(b,b);
-			     const XML_Char * pszDataName = NULL;
+			     const gchar * pszDataName = NULL;
 			     (pAP)->getAttribute(PT_DATAITEM_ATTRIBUTE_NAME,pszDataName);
 			     if(pszDataName == NULL)
 			     {
@@ -671,8 +671,8 @@ bool  ABI_Collab_Export::mapAttributesToString(UT_sint32 indx, UT_UTF8String & s
 	UT_return_val_if_fail(b,b);
 	UT_sint32 nAtts = static_cast<UT_sint32>(pAP->getAttributeCount());
 	UT_sint32 i = 0;
-	const XML_Char * szName = NULL;
-	const XML_Char * szVal = NULL;
+	const gchar * szName = NULL;
+	const gchar * szVal = NULL;
 	for(i=0; i<nAtts;i++)
 	{
 		pAP->getNthAttribute(i,szName,szVal);
