@@ -196,8 +196,8 @@ bool ABI_Collab_Import::import(const SessionPacket& packet)
 				UT_ASSERT(pos <= getEndOfDoc());
 				// todo: remove these temp vars
 				UT_UTF8String sFrag = crp->getFrag();
-				const XML_Char** szProps = const_cast<const XML_Char**>(crp->getProps());
-				const XML_Char** szAtts = const_cast<const XML_Char**>(crp->getAtts());
+				const gchar** szProps = const_cast<const gchar**>(crp->getProps());
+				const gchar** szAtts = const_cast<const gchar**>(crp->getAtts());
 				UT_UTF8String sValue = crp->getValue();
 				
 				PT_DocPosition iPos2 = 0;
@@ -218,7 +218,7 @@ bool ABI_Collab_Import::import(const SessionPacket& packet)
 						break;
 					case PX_ChangeRecord::PXT_InsertSpan:
 						{
-							printf("Doing InsertSpan |%s| \n", sValue.utf8_str());
+							UT_DEBUGMSG(("Doing InsertSpan |%s| \n", sValue.utf8_str()));
 							UT_UCS4String UCSChars = sValue.ucs4_str();
 							m_pDoc->insertSpan(pos,UCSChars.ucs4_str(),UCSChars.length());
 						}
@@ -597,7 +597,7 @@ bool ABI_Collab_Import::import(const SessionPacket& packet)
 					case PX_ChangeRecord::PXT_CreateDataItem:
 						{
 							UT_DEBUGMSG(("Doing CreateDataItem |%s| \n", sValue.utf8_str()));
-							const char * szNameV = UT_strdup(crp->getAttribute(PT_DATAITEM_ATTRIBUTE_NAME));
+							const char * szNameV = g_strdup(crp->getAttribute(PT_DATAITEM_ATTRIBUTE_NAME));
 							const void * pToken = NULL;
 							void * pHandle = NULL;
 							UT_ByteBuf * pBuf= new UT_ByteBuf();
