@@ -44,7 +44,7 @@
 
 #include <handlers/xp/Buddy.h>
 
-static const XML_Char * szAbiCollab_Packet_PTName[] =
+static const gchar * szAbiCollab_Packet_PTName[] =
 {
     PT_STYLE_ATTRIBUTE_NAME		,
     PT_LEVEL_ATTRIBUTE_NAME		,
@@ -442,11 +442,11 @@ char * Packet::getAttribute(char * szName) const
 {
 	UT_sint32 i = 0;
 	char * value = NULL;
-	while(m_szAtts && (m_szAtts[i] != NULL) && (UT_strcmp(m_szAtts[i],szName) != 0))
+	while(m_szAtts && (m_szAtts[i] != NULL) && (strcmp(m_szAtts[i],szName) != 0))
 	{
 		i += 2;
 	}
-	if(UT_strcmp(m_szAtts[i],szName) == 0)
+	if(strcmp(m_szAtts[i],szName) == 0)
 	{
 		value = m_szAtts[i+1];
 	}
@@ -456,30 +456,30 @@ char * Packet::getAttribute(char * szName) const
 bool Packet::fillPTAttributes(xmlNode * node)
 {
 	char * value = NULL;
-	const XML_Char * szAtt = NULL;
+	const gchar * szAtt = NULL;
 	_freeAtts();
 	UT_GenericVector<const char *> vecAtts;
 	UT_sint32 i = 0;
-	for(i=0; i < (sizeof(szAbiCollab_Packet_PTName) / sizeof(XML_Char *));i++)
+	for(i=0; i < (sizeof(szAbiCollab_Packet_PTName) / sizeof(gchar *));i++)
 	{
 		szAtt = szAbiCollab_Packet_PTName[i];
 		value = (char *)xmlGetProp(node,reinterpret_cast<const xmlChar *>(szAtt));
 		if(value != 0)
 		{
 			xxx_UT_DEBUGMSG(("Found Attribute |%s| Value |%s| \n",szAtt,value));
-			vecAtts.addItem(UT_strdup(szAtt));
-			vecAtts.addItem(UT_strdup(value));
+			vecAtts.addItem(g_strdup(szAtt));
+			vecAtts.addItem(g_strdup(value));
 			FREEP(value);
 		}
 	}
 	UT_uint32 isize = vecAtts.getItemCount();
 	if(isize > 1)
 	{
-		m_szAtts = new XML_Char *[isize+1];
+		m_szAtts = new gchar *[isize+1];
 		UT_uint32 i = 0;
 		for(i=0;i< isize;i++)
 		{
-			m_szAtts[i] = const_cast<XML_Char *>(reinterpret_cast<const XML_Char *>(vecAtts.getNthItem(i)));
+			m_szAtts[i] = const_cast<gchar *>(reinterpret_cast<const gchar *>(vecAtts.getNthItem(i)));
 			xxx_UT_DEBUGMSG(("String %d value |%s| \n",i,m_szAtts[i]));
 		}
 		m_szAtts[isize] = 0;
@@ -516,7 +516,7 @@ bool Packet::fillPropsFromString(UT_UTF8String& sProps)
 	{
 	    _freeProps();
 	}
-	m_szProps = new XML_Char * [vProps.size()*2 + 1];
+	m_szProps = new gchar * [vProps.size()*2 + 1];
 	UT_uint32 j= 0;
 	for (j=0; j < vProps.getItemCount(); j++)
 	{
@@ -529,8 +529,8 @@ bool Packet::fillPropsFromString(UT_UTF8String& sProps)
 			return false;
 		}
 		
-		m_szProps[i] = UT_strdup(keyValue.substr(0, ppos).c_str());
-		m_szProps[i+1] = UT_strdup(keyValue.substr(ppos+1, keyValue.length()-(ppos+1)).c_str());
+		m_szProps[i] = g_strdup(keyValue.substr(0, ppos).c_str());
+		m_szProps[i+1] = g_strdup(keyValue.substr(ppos+1, keyValue.length()-(ppos+1)).c_str());
 		xxx_UT_DEBUGMSG(("Found Prop |%s| Value |%s| \n",m_szProps[i],m_szProps[i+1]));
 		i+=2;
 	}
