@@ -259,8 +259,8 @@ AbiCommand::doCommands (void)
 			UT_UTF8String *pTok =
 				const_cast < UT_UTF8String * >(static_cast < const UT_UTF8String * >(toks.getNthItem (0)));
 
-			if (pTok && UT_strcmp (pTok->utf8_str (), "quit") == 0
-				|| UT_strcmp (pTok->utf8_str (), "q") == 0)
+			if (pTok && strcmp (pTok->utf8_str (), "quit") == 0
+				|| strcmp (pTok->utf8_str (), "q") == 0)
 				bQuit = true;
 			else
 			{
@@ -354,7 +354,7 @@ AbiCommand::parseTokens (UT_Vector * pToks)
 	//
 	// New document
 	//
-	if (UT_strcmp (pCom0->utf8_str (), "new") == 0)
+	if (strcmp (pCom0->utf8_str (), "new") == 0)
 	{
 		printf ("Attempting to create a new document \n");
 		PD_Document *pDoc = new PD_Document (m_pApp);
@@ -377,7 +377,7 @@ AbiCommand::parseTokens (UT_Vector * pToks)
 	//
 	// Load in a document
 	//
-	if (UT_strcmp (pCom0->utf8_str (), "load") == 0)
+	if (strcmp (pCom0->utf8_str (), "load") == 0)
 	{
 		printf ("Attempting to load a document \n");
 		if (count >= 2)
@@ -404,7 +404,7 @@ AbiCommand::parseTokens (UT_Vector * pToks)
 	//
 	// printfile
 	//
-	else if (UT_strcmp (pCom0->utf8_str (), "printfile") == 0)
+	else if (strcmp (pCom0->utf8_str (), "printfile") == 0)
 	{
 		if (count >= 2)
 		{
@@ -418,7 +418,7 @@ AbiCommand::parseTokens (UT_Vector * pToks)
 	//
 	// inserttext
 	//
-	else if (UT_strcmp (pCom0->utf8_str (), "inserttext") == 0)
+	else if (strcmp (pCom0->utf8_str (), "inserttext") == 0)
 	{
 		if (count >= 2)
 		{
@@ -432,7 +432,7 @@ AbiCommand::parseTokens (UT_Vector * pToks)
 	//
 	// delete
 	//
-	else if (UT_strcmp (pCom0->utf8_str (), "delete") == 0)
+	else if (strcmp (pCom0->utf8_str (), "delete") == 0)
 	{
 		if (deleteText (pToks))
 			return 0;
@@ -443,7 +443,7 @@ AbiCommand::parseTokens (UT_Vector * pToks)
 	//
 	// Replace Next
 	//
-	else if (UT_strcmp (pCom0->utf8_str (), "replacenext") == 0)
+	else if (strcmp (pCom0->utf8_str (), "replacenext") == 0)
 	{
 		if (count > 2)
 			return RES_TO_STATUS (replaceNext (pToks));
@@ -452,7 +452,7 @@ AbiCommand::parseTokens (UT_Vector * pToks)
 	//
 	// replaceAll
 	//
-	else if (UT_strcmp (pCom0->utf8_str (), "replaceall") == 0)
+	else if (strcmp (pCom0->utf8_str (), "replaceall") == 0)
 	{
 		if (count > 2)
 			return RES_TO_STATUS (replaceAll (pToks));
@@ -461,7 +461,7 @@ AbiCommand::parseTokens (UT_Vector * pToks)
 	//
 	// Move point to somewhere
 	//
-	else if (UT_strcmp (pCom0->utf8_str (), "movept") == 0)
+	else if (strcmp (pCom0->utf8_str (), "movept") == 0)
 	{
 		if (count > 1)
 			return RES_TO_STATUS (movePoint (pToks));
@@ -470,7 +470,7 @@ AbiCommand::parseTokens (UT_Vector * pToks)
 	//
 	// Open a graphical window on the document
 	//
-	else if (UT_strcmp (pCom0->utf8_str (), "visualedit") == 0)
+	else if (strcmp (pCom0->utf8_str (), "visualedit") == 0)
 	{
 		return RES_TO_STATUS (viewDoc ());
 	}
@@ -478,7 +478,7 @@ AbiCommand::parseTokens (UT_Vector * pToks)
 	//
 	// Start selection
 	//
-	else if (UT_strcmp (pCom0->utf8_str (), "selectstart") == 0)
+	else if (strcmp (pCom0->utf8_str (), "selectstart") == 0)
 	{
 		if (m_pCurView)
 		{
@@ -495,7 +495,7 @@ AbiCommand::parseTokens (UT_Vector * pToks)
 	//
 	// Clear selection
 	//
-	else if (UT_strcmp (pCom0->utf8_str (), "selectclear") == 0)
+	else if (strcmp (pCom0->utf8_str (), "selectclear") == 0)
 	{
 		if (m_pCurView)
 		{
@@ -510,7 +510,7 @@ AbiCommand::parseTokens (UT_Vector * pToks)
 	//
 	// findnext
 	//
-	else if (UT_strcmp (pCom0->utf8_str (), "findnext") == 0)
+	else if (strcmp (pCom0->utf8_str (), "findnext") == 0)
 	{
 		if (m_pCurView && (pToks->getItemCount () > 1))
 		{
@@ -535,7 +535,7 @@ AbiCommand::parseTokens (UT_Vector * pToks)
 	//
 	// Save
 	//
-	else if (UT_strcmp (pCom0->utf8_str (), "save") == 0)
+	else if (strcmp (pCom0->utf8_str (), "save") == 0)
 	{
 		if (m_pCurDoc)
 		{
@@ -579,8 +579,8 @@ AbiCommand::parseTokens (UT_Vector * pToks)
 	//
 	// Convert to Text
 	//
-	else if (UT_strcmp (pCom0->utf8_str (), "converttotext") == 0 ||
-			 UT_strcmp (pCom0->utf8_str (), "convert") == 0)
+	else if (strcmp (pCom0->utf8_str (), "converttotext") == 0 ||
+			 strcmp (pCom0->utf8_str (), "convert") == 0)
 	{
 		AP_Convert APConvert;
 		UT_UTF8String src;
@@ -628,7 +628,7 @@ AbiCommand::parseTokens (UT_Vector * pToks)
 	//
 	// Write PID to file
 	//
-	else if (UT_strcmp (pCom0->utf8_str (), "writepid") == 0)
+	else if (strcmp (pCom0->utf8_str (), "writepid") == 0)
 	{
 		if (pToks->getItemCount () < 2)
 			return -1;
@@ -649,7 +649,7 @@ AbiCommand::parseTokens (UT_Vector * pToks)
 	//
 	// server
 	//      
-	else if (UT_strcmp (pCom0->utf8_str (), "server") == 0)
+	else if (strcmp (pCom0->utf8_str (), "server") == 0)
 	{
 		if (pToks->getItemCount () < 2)
 			return -1;
@@ -664,7 +664,7 @@ AbiCommand::parseTokens (UT_Vector * pToks)
 	//
 	// PNG preview
 	//
-	else if (UT_strcmp (pCom0->utf8_str (), "previewpng") == 0)
+	else if (strcmp (pCom0->utf8_str (), "previewpng") == 0)
 	{
 		UT_UTF8String src, destPNG, sWidth, sHeight;
 
@@ -692,7 +692,7 @@ AbiCommand::parseTokens (UT_Vector * pToks)
 	//
 	// Help
 	//
-	else if (UT_strcmp (pCom0->utf8_str (), "help") == 0)
+	else if (strcmp (pCom0->utf8_str (), "help") == 0)
 	{
 		printf ("Currently implemented commands are:\n");
 		printf ("help                        - Prints this message\n");
@@ -872,27 +872,27 @@ AbiCommand::movePoint (UT_Vector * pToks)
 		bool bAbsMove = false;
 		UT_sint32 amt = 0;
 
-		if (UT_stricmp (pTarget->utf8_str (), "BOD") == 0)
+		if (g_ascii_strcasecmp (pTarget->utf8_str (), "BOD") == 0)
 			docpos = FV_DOCPOS_BOD;
-		else if (UT_stricmp (pTarget->utf8_str (), "EOD") == 0)
+		else if (g_ascii_strcasecmp (pTarget->utf8_str (), "EOD") == 0)
 			docpos = FV_DOCPOS_EOD;
-		else if (UT_stricmp (pTarget->utf8_str (), "BOB") == 0)
+		else if (g_ascii_strcasecmp (pTarget->utf8_str (), "BOB") == 0)
 			docpos = FV_DOCPOS_BOB;
-		else if (UT_stricmp (pTarget->utf8_str (), "EOB") == 0)
+		else if (g_ascii_strcasecmp (pTarget->utf8_str (), "EOB") == 0)
 			docpos = FV_DOCPOS_EOB;
-		else if (UT_stricmp (pTarget->utf8_str (), "BOP") == 0)
+		else if (g_ascii_strcasecmp (pTarget->utf8_str (), "BOP") == 0)
 			docpos = FV_DOCPOS_BOP;
-		else if (UT_stricmp (pTarget->utf8_str (), "EOP") == 0)
+		else if (g_ascii_strcasecmp (pTarget->utf8_str (), "EOP") == 0)
 			docpos = FV_DOCPOS_EOP;
-		else if (UT_stricmp (pTarget->utf8_str (), "BOL") == 0)
+		else if (g_ascii_strcasecmp (pTarget->utf8_str (), "BOL") == 0)
  			docpos = FV_DOCPOS_BOL;
-		else if (UT_stricmp (pTarget->utf8_str (), "EOL") == 0)
+		else if (g_ascii_strcasecmp (pTarget->utf8_str (), "EOL") == 0)
 			docpos = FV_DOCPOS_EOL;
-		else if (UT_stricmp (pTarget->utf8_str (), "BOS") == 0)
+		else if (g_ascii_strcasecmp (pTarget->utf8_str (), "BOS") == 0)
 			docpos = FV_DOCPOS_BOS;
-		else if (UT_stricmp (pTarget->utf8_str (), "EOS") == 0)
+		else if (g_ascii_strcasecmp (pTarget->utf8_str (), "EOS") == 0)
 			docpos = FV_DOCPOS_EOS;
-		else if (UT_stricmp (pTarget->utf8_str (), "BOW") == 0)
+		else if (g_ascii_strcasecmp (pTarget->utf8_str (), "BOW") == 0)
 			docpos = FV_DOCPOS_BOW;
 		else if (*(pTarget->utf8_str ()) == '+'
 				 || *(pTarget->utf8_str ()) == '-')
