@@ -45,7 +45,7 @@
 #include <goffice/graph/gog-object-xml.h>
 #include <goffice/data/go-data-simple.h>
 #include <goffice/graph/gog-renderer-gnome-print.h>
-#include <goffice/utils/go-format.h>
+#include <goffice/utils/go-locale.h>
 #include <gsf/gsf-impl-utils.h>
 #include <gsf/gsf-output-memory.h>
 #include <gsf/gsf-libxml.h>
@@ -70,7 +70,7 @@ class AbiGO_LocaleTransactor
 AbiGO_LocaleTransactor::AbiGO_LocaleTransactor (int category, const char * locale)
   : mCategory (category), mOldLocale (0)
 {
-	mOldLocale = UT_strdup(setlocale(category, NULL));
+	mOldLocale = g_strdup(setlocale(category, NULL));
 	go_setlocale (category, locale);
 
 	// TODO: win32 may need to free old_locale
@@ -142,8 +142,8 @@ cb_graph_dim_editor_update (GtkEntry *gee,
 	GOData *data = NULL;
 	double val;
 	char sep[2], col_sep[2], *end;
-	sep[0] = go_format_get_arg_sep ();
-	col_sep[0] = go_format_get_col_sep ();
+	sep[0] = go_locale_get_arg_sep ();
+	col_sep[0] = go_locale_get_col_sep ();
 	sep[1] = col_sep[1]= 0;
 	char const* str = gtk_entry_get_text (gee);
 	if (str == NULL)
@@ -516,7 +516,7 @@ bool GR_GOChartManager::createPNGSnapshot(AD_Document * pDoc, UT_Rect & rec,
   UT_UTF8String sID = "snapshot-png-";
   sID += szDataID;
   const char* mimetypePNG = NULL;
-  mimetypePNG = UT_strdup("image/png");
+  mimetypePNG = g_strdup("image/png");
   pDoc->createDataItem(sID.utf8_str(),false,reinterpret_cast< const UT_ByteBuf *>(pBuf),mimetypePNG,NULL);
   delete pBuf;
   delete pImage;
