@@ -99,7 +99,7 @@ static bool s_AskForGOComponentPathname(XAP_Frame * pFrame,
 	// raise the file-open dialog for inserting a component.
 	// return a_OK or a_CANCEL depending on which button
 	// the user hits.
-	// return a pointer a UT_strdup()'d string containing the
+	// return a pointer a g_strdup()'d string containing the
 	// pathname the user entered -- ownership of this goes
 	// to the caller (so free it when you're done with it).
 
@@ -148,7 +148,7 @@ static bool s_AskForGOComponentPathname(XAP_Frame * pFrame,
 		const char * szResultPathname = pDialog->getPathname();
 		UT_DEBUGMSG(("OBJECT Path Name selected = %s \n",szResultPathname));
 		if (szResultPathname && *szResultPathname)
-			UT_cloneString(*ppPathname,szResultPathname);
+			*ppPathname = g_strdup(szResultPathname);
 
 		UT_sint32 type = pDialog->getFileType();
 
@@ -389,7 +389,7 @@ void GR_GOComponentManager::makeSnapShot(UT_sint32 uid, UT_Rect & rec)
 		}
 		else
 		{
-			const char* mimetypeSVG = UT_strdup("image/svg");
+			const char* mimetypeSVG = g_strdup("image/svg");
 			m_pDoc->createDataItem(sID.utf8_str(),false,reinterpret_cast< const UT_ByteBuf *>(pBuf),mimetypeSVG,NULL);
 			pItem->m_bHasSnapshot = true;
 		}
@@ -437,7 +437,7 @@ bool GR_GOComponentManager::createPNGSnapshot(AD_Document * pDoc, UT_Rect & rec,
   UT_UTF8String sID = "snapshot-png-";
   sID += szDataID;
   const char* mimetypePNG = NULL;
-  mimetypePNG = UT_strdup("image/png");
+  mimetypePNG = g_strdup("image/png");
   pDoc->createDataItem(sID.utf8_str(),false,reinterpret_cast< const UT_ByteBuf *>(pBuf),mimetypePNG,NULL);
   delete pBuf;
   delete pImage;
@@ -802,7 +802,7 @@ void GOComponentView::loadBuffer(UT_ByteBuf const *sGOComponentData, char *_mime
 			GParamSpec *prop_spec;
 			int i = 0;
 			GValue res = { 0 };
-			XML_Char const *szName, *szValue;
+			gchar const *szName, *szValue;
 			while (Props->getNthProperty (i++, szName, szValue)) {
 				prop_spec = g_object_class_find_property (
 						G_OBJECT_GET_CLASS (component), szName);
