@@ -53,6 +53,7 @@ ODe_AbiDocListener::ODe_AbiDocListener (PD_Document* pDocument,
       m_apiLastSpan(0),
       m_bInSpan(false),
       m_bInBlock(false),
+      m_bInBookmark(false),
       m_bInHyperlink(false),
       m_bInSection(false),
       m_iInTable(0),
@@ -61,7 +62,7 @@ ODe_AbiDocListener::ODe_AbiDocListener (PD_Document* pDocument,
       m_pCurrentImpl(pListenerImpl),
       m_deleteCurrentWhenPop(deleteWhenPop)
 {
-    UT_ASSERT(pListenerImpl != NULL);
+    UT_ASSERT_HARMLESS(pListenerImpl != NULL);
 }
 
 
@@ -151,7 +152,17 @@ bool ODe_AbiDocListener::populate(PL_StruxFmtHandle sfh,
                 {
                     _closeSpan();
                     _closeField();
-                    //_openTag("bookmark", "/",false, api,pcr->getXID(),true);
+
+                    const PP_AttrProp* pAP = NULL;
+                    m_pDocument->getAttrProp(api,&pAP);
+                    const gchar* pValue = NULL;
+
+                    if(pAP && pAP->getAttribute("type",pValue) && pValue && (strcmp(pValue, "start") == 0)) {
+                        _openBookmark(api);
+                    } else {
+                        _closeBookmark(api);
+                    }
+
                     return true;
                 }
 
@@ -161,7 +172,7 @@ bool ODe_AbiDocListener::populate(PL_StruxFmtHandle sfh,
                     _closeField();
                     const PP_AttrProp* pAP = NULL;
                     m_pDocument->getAttrProp(api,&pAP);
-                    const XML_Char* pValue = NULL;
+                    const gchar* pValue = NULL;
 
                     if(pAP && pAP->getAttribute("xlink:href",pValue) && pValue) {
                         _openHyperlink(api);
@@ -210,8 +221,8 @@ bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle sdh,
     *psfh = 0;                          // we don't need it.
 
     PT_AttrPropIndex api = pcr->getIndexAP();
-    //const XML_Char* image_name =
-    //    _getObjectKey(api, static_cast<const XML_Char*>(PT_STRUX_IMAGE_DATAID));
+    //const gchar* image_name =
+    //    _getObjectKey(api, static_cast<const gchar*>(PT_STRUX_IMAGE_DATAID));
         
 
     switch (pcrx->getStruxType())
@@ -221,6 +232,7 @@ bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle sdh,
         {
             _closeSpan();
             _closeField();
+            _closeBookmark(m_bookmarkName);
             _closeHyperlink();
             _closeBlock();
             _closeSection();
@@ -232,6 +244,7 @@ bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle sdh,
         {
             _closeSpan();
             _closeField();
+            _closeBookmark(m_bookmarkName);
             _closeHyperlink();
             _closeBlock();
             _openTable(api);
@@ -242,6 +255,7 @@ bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle sdh,
         {
             _closeSpan();
             _closeField();
+            _closeBookmark(m_bookmarkName);
             _closeHyperlink();
             _closeBlock();
             _openCell(api);
@@ -252,6 +266,7 @@ bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle sdh,
         {
             _closeSpan();
             _closeField();
+            _closeBookmark(m_bookmarkName);
             _closeHyperlink();
             _openFootnote(api);
         }
@@ -261,6 +276,7 @@ bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle sdh,
         {
             _closeSpan();
             _closeField();
+            _closeBookmark(m_bookmarkName);
             _closeHyperlink();
             _openEndnote(api);
         }
@@ -270,6 +286,7 @@ bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle sdh,
         {
             _closeSpan();
             _closeField();
+            _closeBookmark(m_bookmarkName);
             _closeHyperlink();
             _closeBlock();
             _openTOC(api);
@@ -280,6 +297,7 @@ bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle sdh,
         {
             _closeSpan();
             _closeField();
+            _closeBookmark(m_bookmarkName);
             _closeHyperlink();
             _closeBlock();
             //_openTag("margin","",true,pcr->getIndexAP(),pcr->getXID());
@@ -290,6 +308,7 @@ bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle sdh,
         {
             _closeSpan();
             _closeField();
+            _closeBookmark(m_bookmarkName);
             _closeHyperlink();
             _closeBlock();
             _openFrame(api);
@@ -300,6 +319,7 @@ bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle sdh,
         {
             _closeSpan();
             _closeField();
+            _closeBookmark(m_bookmarkName);
             _closeHyperlink();
             _closeBlock();
             _closeTable();
@@ -310,6 +330,7 @@ bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle sdh,
         {
             _closeSpan();
             _closeField();
+            _closeBookmark(m_bookmarkName);
             _closeHyperlink();
             _closeBlock();
             _closeCell();
@@ -320,6 +341,7 @@ bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle sdh,
         {
             _closeSpan();
             _closeField();
+            _closeBookmark(m_bookmarkName);
             _closeHyperlink();
             _closeBlock();
             _closeFootnote();
@@ -330,6 +352,7 @@ bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle sdh,
         {
             _closeSpan();
             _closeField();
+            _closeBookmark(m_bookmarkName);
             _closeHyperlink();
             _closeBlock();
             _closeEndnote();
@@ -340,6 +363,7 @@ bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle sdh,
         {
             _closeSpan();
             _closeField();
+            _closeBookmark(m_bookmarkName);
             _closeHyperlink();
             _closeBlock();
             _closeTOC();
@@ -350,6 +374,7 @@ bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle sdh,
         {
             _closeSpan();
             _closeField();
+            _closeBookmark(m_bookmarkName);
             _closeHyperlink();
             _closeBlock();
         }
@@ -359,6 +384,7 @@ bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle sdh,
         {
             _closeSpan();
             _closeField();
+            _closeBookmark(m_bookmarkName);
             _closeHyperlink();
             _closeBlock();
             _closeFrame();
@@ -369,6 +395,7 @@ bool ODe_AbiDocListener::populateStrux(PL_StruxDocHandle sdh,
         {
             _closeSpan();
             _closeField();
+            _closeBookmark(m_bookmarkName);
             _closeHyperlink();
             _closeBlock();
             _openBlock(api);
@@ -426,6 +453,7 @@ bool ODe_AbiDocListener::signal(UT_uint32 iSignal)
 void ODe_AbiDocListener::finished() {
     _closeSpan();
     _closeField();
+    _closeBookmark(m_bookmarkName);
     _closeHyperlink();
     _closeBlock();
     
@@ -601,7 +629,7 @@ void ODe_AbiDocListener::_openField(const PX_ChangeRecord_Object* pcro,
     UT_return_if_fail(m_pDocument->getAttrProp (api, &pAP) && pAP);
 
     UT_UTF8String value = m_pCurrentField->getValue();
-    const XML_Char * szValue = NULL;
+    const gchar * szValue = NULL;
 
     UT_return_if_fail(pAP->getAttribute ("type", szValue) && szValue);
     m_currentFieldType = szValue;
@@ -931,6 +959,64 @@ void ODe_AbiDocListener::_closeTOC() {
 }
 
 
+/**
+ * 
+ */
+void ODe_AbiDocListener::_openBookmark(PT_AttrPropIndex api) {
+    const PP_AttrProp* pAP = NULL;
+    bool ok = false;
+
+    ok = m_pDocument->getAttrProp (api, &pAP);
+    if (ok && pAP) {
+        const gchar* pValue = NULL;
+        if(pAP->getAttribute("name",pValue) && pValue) {
+            m_bookmarkName = pValue;
+        } else {
+           UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+        }
+
+        m_bInBookmark = true;
+        m_pCurrentImpl->openBookmark(pAP);
+    }
+}
+
+
+/**
+ * 
+ */
+void ODe_AbiDocListener::_closeBookmark(UT_UTF8String &sBookmarkName) {
+    if (!m_bInBookmark || sBookmarkName.empty())
+        return;
+
+    _closeSpan();
+
+    m_pCurrentImpl->closeBookmark(sBookmarkName);
+    m_bInBookmark = false;
+    m_bookmarkName.clear();
+}
+
+
+/**
+ * 
+ */
+void ODe_AbiDocListener::_closeBookmark(PT_AttrPropIndex api) {
+    if (!m_bInBookmark)
+        return;
+
+    _closeSpan();
+
+    const PP_AttrProp* pAP = NULL;
+    bool ok = false;
+
+    ok = m_pDocument->getAttrProp (api, &pAP);
+    if (ok && pAP) {
+        m_pCurrentImpl->closeBookmark(pAP);
+    }
+    m_bInBookmark = false;
+    m_bookmarkName.clear();
+}
+
+
 /**
  * 
  */
@@ -965,13 +1051,13 @@ void ODe_AbiDocListener::_closeHyperlink() {
 /**
  * 
  */
-const XML_Char* ODe_AbiDocListener::_getObjectKey(const PT_AttrPropIndex& api,
-                                                  const XML_Char* key) {
+const gchar* ODe_AbiDocListener::_getObjectKey(const PT_AttrPropIndex& api,
+                                                  const gchar* key) {
     const PP_AttrProp * pAP = NULL;
     bool bHaveProp = m_pDocument->getAttrProp(api,&pAP);
     if (bHaveProp && pAP)
     {
-        const XML_Char* value;
+        const gchar* value;
         if (pAP->getAttribute(key, value))
             return value;
     }
@@ -984,7 +1070,7 @@ const XML_Char* ODe_AbiDocListener::_getObjectKey(const PT_AttrPropIndex& api,
  * 
  */
 void ODe_AbiDocListener::_insertInlinedImage(PT_AttrPropIndex api) {
-    const XML_Char* pImageName;
+    const gchar* pImageName;
     const PP_AttrProp* pAP;
     bool ok;
 
@@ -994,7 +1080,7 @@ void ODe_AbiDocListener::_insertInlinedImage(PT_AttrPropIndex api) {
     }
 
     pImageName = 
-        _getObjectKey(api, static_cast<const XML_Char*>("dataid"));
+        _getObjectKey(api, static_cast<const gchar*>("dataid"));
 
     m_pCurrentImpl->insertInlinedImage(pImageName, pAP);
 }
@@ -1005,7 +1091,7 @@ void ODe_AbiDocListener::_insertInlinedImage(PT_AttrPropIndex api) {
  */
 void ODe_AbiDocListener::_insertEmbeddedImage(PT_AttrPropIndex api) {
     UT_UTF8String snapshot = "snapshot-png-";
-    const XML_Char* pImageName = NULL;
+    const gchar* pImageName = NULL;
     const PP_AttrProp* pAP;
     bool ok;
 
@@ -1015,7 +1101,7 @@ void ODe_AbiDocListener::_insertEmbeddedImage(PT_AttrPropIndex api) {
     }
 
     pImageName = 
-        _getObjectKey(api, static_cast<const XML_Char*>("dataid"));
+        _getObjectKey(api, static_cast<const gchar*>("dataid"));
 
     if(pImageName) {
         snapshot+=pImageName;
@@ -1029,8 +1115,8 @@ void ODe_AbiDocListener::_insertEmbeddedImage(PT_AttrPropIndex api) {
  */
 void ODe_AbiDocListener::_insertMath(PT_AttrPropIndex api) {
 
-    const XML_Char* szMath = NULL;
-    szMath = _getObjectKey(api, static_cast<const XML_Char*>("dataid"));
+    const gchar* szMath = NULL;
+    szMath = _getObjectKey(api, static_cast<const gchar*>("dataid"));
 
     UT_return_if_fail(szMath);
 
@@ -1048,8 +1134,6 @@ void ODe_AbiDocListener::_insertMath(PT_AttrPropIndex api) {
     UT_UCS4String buf = sMathML.utf8_str();
     UT_UTF8String output = "";
 
-    _openSpan(api);
-
     const PP_AttrProp * pAP = NULL;
     bool bHaveProp = m_pDocument->getAttrProp(api,&pAP);
     UT_LocaleTransactor t(LC_NUMERIC, "C");
@@ -1058,6 +1142,8 @@ void ODe_AbiDocListener::_insertMath(PT_AttrPropIndex api) {
 
     UT_return_if_fail(bHaveProp && pAP);
 
+    _openSpan(api);
+
     if(pAP->getProperty("width", szMath)) {
         dInch = static_cast<double>(atoi(szMath))/UT_LAYOUT_RESOLUTION;
         UT_UTF8String_sprintf(dimension,"%fin",dInch);
