@@ -154,7 +154,7 @@ bool ODe_Style_Style::write(GsfOutput* pODT, const UT_UTF8String& rSpacesOffset)
  */
 bool ODe_Style_Style::hasTextStyleProps(const PP_AttrProp* pAP) {
     
-    const XML_Char* pValue;
+    const gchar* pValue;
     bool ok;
     
     ok = pAP->getProperty("color", pValue);
@@ -207,7 +207,7 @@ bool ODe_Style_Style::hasTextStyleProps(const PP_AttrProp* pAP) {
  */
 bool ODe_Style_Style::hasParagraphStyleProps(const PP_AttrProp* pAP) {
     
-    const XML_Char* pValue;
+    const gchar* pValue;
     bool ok;
     
     ok = pAP->getProperty("bgcolor", pValue);
@@ -224,6 +224,11 @@ bool ODe_Style_Style::hasParagraphStyleProps(const PP_AttrProp* pAP) {
     if (ok && pValue != NULL) {
         return true;
     }
+
+    ok = pAP->getProperty("text-indent", pValue);
+    if (ok && pValue != NULL) {
+        return true;
+    }
     
     ok = pAP->getProperty("widows", pValue);
     if (ok && pValue != NULL) {
@@ -275,7 +280,7 @@ bool ODe_Style_Style::hasParagraphStyleProps(const PP_AttrProp* pAP) {
  * 
  */
 bool ODe_Style_Style::hasSectionInfo(const PP_AttrProp* pAP) {
-    const XML_Char* pValue;
+    const gchar* pValue;
     bool ok;
     
     ok = pAP->getProperty("columns", pValue);
@@ -296,7 +301,7 @@ bool ODe_Style_Style::hasSectionInfo(const PP_AttrProp* pAP) {
  * 
  */
 bool ODe_Style_Style::hasTableCellStyleProps(const PP_AttrProp* pAP) {
-    const XML_Char* pValue;
+    const gchar* pValue;
     bool ok;
     
     // Left border
@@ -368,7 +373,7 @@ bool ODe_Style_Style::hasTableCellStyleProps(const PP_AttrProp* pAP) {
  * 
  */
 bool ODe_Style_Style::hasTableStyleProps(const PP_AttrProp* pAP) {
-    const XML_Char* pValue;
+    const gchar* pValue;
     bool ok;
     
     ok = pAP->getProperty("background-color", pValue);
@@ -494,7 +499,7 @@ ODe_Style_Style& ODe_Style_Style::operator=(const ODe_Style_Style& rStyle) {
  */
 bool ODe_Style_Style::fetchAttributesFromAbiStyle(const PP_AttrProp* pAP) {
 
-    const XML_Char* pValue;
+    const gchar* pValue;
     bool ok;
     
     ok = pAP->getAttribute(PT_NAME_ATTRIBUTE_NAME, pValue);
@@ -504,14 +509,14 @@ bool ODe_Style_Style::fetchAttributesFromAbiStyle(const PP_AttrProp* pAP) {
     ok = pAP->getAttribute(PT_FOLLOWEDBY_ATTRIBUTE_NAME, pValue);
     if (ok && pValue != NULL) {
         
-        if (UT_strcmp("Current Settings", pValue) != 0) {
+        if (strcmp("Current Settings", pValue) != 0) {
             m_nextStyleName = pValue;
         }
     }
     
     ok = pAP->getAttribute(PT_BASEDON_ATTRIBUTE_NAME, pValue);
     if (ok && pValue != NULL) {
-        if (UT_strcmp(pValue, "None") != 0) {
+        if (strcmp(pValue, "None") != 0) {
             // OpenDocument don't use a "None" to say that is has no parent.
             // To say that it simply doesn't define this attribute.
             m_parentStyleName = pValue;
@@ -537,7 +542,7 @@ bool ODe_Style_Style::fetchAttributesFromAbiStyle(const PP_AttrProp* pAP) {
  * Defines the style from attributes and properties of an AbiWord <span>.
  */
 void ODe_Style_Style::fetchAttributesFromAbiSpan(const PP_AttrProp* pAP) {
-    const XML_Char* pValue;
+    const gchar* pValue;
     bool ok;
     
     ok = pAP->getAttribute("style", pValue);
@@ -557,7 +562,7 @@ void ODe_Style_Style::fetchAttributesFromAbiSpan(const PP_AttrProp* pAP) {
  * Fetch attributes from an AbiWord <p> tag. Usually paragraph style attributes.
  */
 void ODe_Style_Style::fetchAttributesFromAbiBlock(const PP_AttrProp* pAP) {
-    const XML_Char* pValue;
+    const gchar* pValue;
     bool ok;
     
     ok = pAP->getAttribute("style", pValue);
@@ -632,7 +637,7 @@ void ODe_Style_Style::fetchAttributesFromAbiFrame(const PP_AttrProp& rAP) {
 /**
  * 
  */
-void ODe_Style_Style::setBreakBefore(const XML_Char* pBreakBefore) {
+void ODe_Style_Style::setBreakBefore(const gchar* pBreakBefore) {
     if (m_pParagraphProps == NULL) {
         m_pParagraphProps = new ParagraphProps();
     }
@@ -654,7 +659,7 @@ const UT_UTF8String& ODe_Style_Style::getFontName() {
 /**
  * 
  */
-void ODe_Style_Style::setColumnWidth(const XML_Char* pColumnWidth) {
+void ODe_Style_Style::setColumnWidth(const gchar* pColumnWidth) {
     if (m_pColumnProps == NULL) {
         m_pColumnProps = new ColumnProps();
     }
@@ -665,7 +670,7 @@ void ODe_Style_Style::setColumnWidth(const XML_Char* pColumnWidth) {
 /**
  * 
  */
-void ODe_Style_Style::setRowHeight(const XML_Char* pRowHeight) {
+void ODe_Style_Style::setRowHeight(const gchar* pRowHeight) {
     if (m_pRowProps == NULL) {
         m_pRowProps = new RowProps();
     }
@@ -763,7 +768,7 @@ bool ODe_Style_Style::SectionProps::isEmpty() const {
  */
 void ODe_Style_Style::SectionProps::
 fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
-    const XML_Char* pValue;
+    const gchar* pValue;
     bool ok;
     
     ok = rAP.getProperty("columns", pValue);
@@ -837,6 +842,7 @@ bool ODe_Style_Style::SectionProps::operator==(
  */
 bool ODe_Style_Style::ParagraphProps::isEmpty() const {
     return ( m_textAlign.empty() &&
+             m_textIndent.empty() &&
              m_lineHeight.empty() &&
              m_lineHeightAtLeast.empty() &&
              m_backgroundColor.empty() &&
@@ -856,17 +862,17 @@ bool ODe_Style_Style::ParagraphProps::isEmpty() const {
  */
 void ODe_Style_Style::ParagraphProps::
 fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
-    const XML_Char* pValue;
+    const gchar* pValue;
     bool ok;
     
     ok = rAP.getProperty("bgcolor", pValue);
     if (ok && pValue != NULL) {
         
-        if (UT_XML_strlen(pValue)==6) {
+        if (strlen(pValue)==6) {
             // It should be a RGB color.
             UT_UTF8String_sprintf(m_backgroundColor, "#%s", pValue);
         } else {
-            UT_ASSERT(UT_strcmp("transparent", pValue)==0);
+            UT_ASSERT(strcmp("transparent", pValue)==0);
             m_backgroundColor = pValue;
         }
     }
@@ -878,7 +884,7 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
             int len = strlen(pValue);
 
             if((len > 1) && (pValue[len - 1] == '+')) {
-               XML_Char* temp = (XML_Char*)pValue;
+               gchar* temp = (gchar*)pValue;
                temp[len-1] = '\0';
                m_lineHeightAtLeast = UT_UTF8String_sprintf("%fin", UT_convertToDimension(temp, DIM_IN));
                m_lineHeight.clear(); // make sure this is empty
@@ -896,16 +902,21 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     
     ok = rAP.getProperty("text-align", pValue);
     if (ok && pValue != NULL) {
-        if(!UT_strcmp(pValue, "right")) {
+        if(!strcmp(pValue, "right")) {
             m_textAlign = "end"; //see Bug 10719
         } else {
             m_textAlign = pValue;
         }
     }
 
+    ok = rAP.getProperty("text-indent", pValue);
+    if (ok && pValue != NULL) {
+        m_textIndent = pValue;
+    }
+
     ok = rAP.getProperty("dom-dir", pValue);
     if (ok && pValue != NULL) {
-        if(!UT_strcmp(pValue, "rtl")) {
+        if(!strcmp(pValue, "rtl")) {
             m_writingMode = "rl";
         } else {
             m_writingMode = "lr";
@@ -944,7 +955,7 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     
     ok = rAP.getProperty("keep-with-next", pValue);
     if (ok && pValue != NULL) {
-        if (!UT_strcmp(pValue, "yes")) {
+        if (!strcmp(pValue, "yes")) {
             m_keepWithNext = "always";
         } else {
             m_keepWithNext = "auto";
@@ -967,6 +978,7 @@ write(UT_UTF8String& rOutput, const UT_UTF8String& rSpacesOffset) const {
     rOutput += "<style:paragraph-properties";
     
     ODe_writeAttribute(rOutput, "fo:text-align", m_textAlign);
+    ODe_writeAttribute(rOutput, "fo:text-indent", m_textIndent);
     ODe_writeAttribute(rOutput, "fo:line-height", m_lineHeight);
     ODe_writeAttribute(rOutput, "style:line-height-at-least", m_lineHeightAtLeast);
     ODe_writeAttribute(rOutput, "fo:background-color", m_backgroundColor);
@@ -991,6 +1003,7 @@ ODe_Style_Style::ParagraphProps& ODe_Style_Style::ParagraphProps::operator=(
                                        const ParagraphProps& rParagraphProps) {
                                         
     m_textAlign = rParagraphProps.m_textAlign;
+    m_textIndent = rParagraphProps.m_textIndent;
     m_lineHeight = rParagraphProps.m_lineHeight;
     m_lineHeightAtLeast = rParagraphProps.m_lineHeightAtLeast;
     m_backgroundColor = rParagraphProps.m_backgroundColor;
@@ -1016,6 +1029,7 @@ bool ODe_Style_Style::ParagraphProps::operator==(
 
     return                    
         m_textAlign       == rParagraphProps.m_textAlign &&
+        m_textIndent       == rParagraphProps.m_textIndent &&
         m_lineHeight      == rParagraphProps.m_lineHeight &&
         m_lineHeightAtLeast == rParagraphProps.m_lineHeightAtLeast &&
         m_backgroundColor == rParagraphProps.m_backgroundColor &&
@@ -1058,15 +1072,15 @@ bool ODe_Style_Style::TextProps::isEmpty() const {
  */
 void ODe_Style_Style::TextProps::
 fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
-    const XML_Char* pValue;
+    const gchar* pValue;
     bool ok;
     
     ok = rAP.getProperty("color", pValue);
     if (ok && pValue != NULL) {
-        if (UT_XML_strlen(pValue)==6) {
+        if (strlen(pValue)==6) {
             UT_UTF8String_sprintf(m_color, "#%s", pValue);
         } else {
-            UT_ASSERT(UT_XML_strlen(pValue)==7);
+            UT_ASSERT(strlen(pValue)==7);
             UT_ASSERT(pValue[0]=='#');
             m_color = pValue;
         }
@@ -1074,7 +1088,7 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     
     ok = rAP.getProperty("text-decoration", pValue);
     if (ok && pValue != NULL) {
-        XML_Char buffer[500];
+        gchar buffer[500];
         UT_uint32 i,j;
         bool keepGoing = true;
         bool finishedWord = false;
@@ -1095,10 +1109,10 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
             }
             
             if (finishedWord) {
-                if (!UT_strcmp(buffer, "underline")) {
+                if (!strcmp(buffer, "underline")) {
                     m_underlineType = "single";
                     
-                } else if (!UT_strcmp(buffer, "line-through")) {
+                } else if (!strcmp(buffer, "line-through")) {
                     m_lineThroughType = "single";
                 }
                 finishedWord = false;
@@ -1116,14 +1130,14 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     
     ok = rAP.getProperty("text-position", pValue);
     if (ok && pValue != NULL) {
-        if (!UT_strcmp("subscript", pValue)) {
+        if (!strcmp("subscript", pValue)) {
             // Hard coded, it's ugly but I can't do otherwise.
             m_textPosition = "-33%";
-        } else if (!UT_strcmp("superscript", pValue)) {
+        } else if (!strcmp("superscript", pValue)) {
             // Hard coded, it's ugly but I can't do otherwise.
             m_textPosition = "33%";
         } else {
-            UT_ASSERT( !UT_strcmp("normal", pValue) );
+            UT_ASSERT( !strcmp("normal", pValue) );
             m_textPosition.clear();
         }
     }
@@ -1143,17 +1157,17 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     
     ok = rAP.getProperty("lang", pValue);
     if (ok && pValue != NULL) {
-        if (!UT_strcmp(pValue, "-none-")) {
+        if (!strcmp(pValue, "-none-")) {
             m_language = "none";
             m_country = "none";
         } else {
-            XML_Char strLanguage[3];
-            XML_Char strCountry[3];
+            gchar strLanguage[3];
+            gchar strCountry[3];
 
             // All valid strings should have 5 chars. e.g.: "en-US"
-            UT_ASSERT( UT_XML_strlen(pValue) == 5); 
+            UT_ASSERT( strlen(pValue) == 5); 
             
-            if (UT_XML_strlen(pValue) == 5) {
+            if (strlen(pValue) == 5) {
                 strLanguage[0] = pValue[0];
                 strLanguage[1] = pValue[1];
                 strLanguage[2] = 0;
@@ -1173,7 +1187,7 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     
     ok = rAP.getProperty("font-style", pValue);
     if (ok && pValue != NULL) {
-        if (!UT_strcmp(pValue, "italic")) {
+        if (!strcmp(pValue, "italic")) {
             m_fontStyle = "italic";
         }
     }
@@ -1181,8 +1195,10 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     
     ok = rAP.getProperty("font-weight", pValue);
     if (ok && pValue != NULL) {
-        if (!UT_strcmp(pValue, "bold")) {
+        if (!strcmp(pValue, "bold")) {
             m_fontWeight = "bold";
+        } else if (!strcmp(pValue, "normal")) {
+            m_fontWeight = "normal";
         }
     }
 }
@@ -1279,7 +1295,7 @@ bool ODe_Style_Style::TableProps::isEmpty() const {
  */
 void ODe_Style_Style::TableProps::
 fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
-    const XML_Char* pValue;
+    const gchar* pValue;
     bool ok;
     
     ok = rAP.getProperty("background-color", pValue);
@@ -1289,7 +1305,7 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     
     ok = rAP.getProperty("table-column-props", pValue);
     if (ok && pValue != NULL) {
-        XML_Char buffer[100];
+        gchar buffer[100];
         UT_uint32 i;
         double tableWidth = 0.0;
         UT_Dimension dimension;
@@ -1510,7 +1526,7 @@ bool ODe_Style_Style::CellProps::isEmpty() const {
  */
 void ODe_Style_Style::CellProps::
 fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
-    const XML_Char* pValue;
+    const gchar* pValue;
     bool ok;
     
     // Left border
@@ -1674,7 +1690,7 @@ bool ODe_Style_Style::GraphicProps::isEmpty() const {
  */
 void ODe_Style_Style::GraphicProps::
 fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
-    const XML_Char* pValue = NULL;
+    const gchar* pValue = NULL;
     bool ok;
     
     // Left border
@@ -1787,10 +1803,10 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     
     ok = rAP.getProperty("wrap-mode", pValue);
     if (ok && pValue != NULL) {
-        if (!UT_strcmp(pValue, "above-text")) {
+        if (!strcmp(pValue, "above-text")) {
             m_wrap = "run-through";
             m_runThrough = "foreground";
-        } else if (!UT_strcmp(pValue, "wrapped-both")) {
+        } else if (!strcmp(pValue, "wrapped-both")) {
             m_wrap = "parallel";
         } else {
             UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
@@ -1801,7 +1817,7 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     ok = rAP.getProperty("position-to", pValue);
     UT_ASSERT (ok && pValue != NULL);
 
-    if (!UT_strcmp(pValue, "block-above-text")) {
+    if (!strcmp(pValue, "block-above-text")) {
         m_horizontalRel = "paragraph";
         m_verticalRel = "paragraph";
     } else {
