@@ -175,7 +175,7 @@ void ODe_Text_Listener::closeBlock() {
 void ODe_Text_Listener::openSpan(const PP_AttrProp* pAP) {
     UT_UTF8String styleName;
     bool ok;
-    const XML_Char* pValue;
+    const gchar* pValue;
     
     if ( ODe_Style_Style::hasTextStyleProps(pAP) ) {
             
@@ -227,12 +227,12 @@ void ODe_Text_Listener::closeSpan() {
 void ODe_Text_Listener::openFrame(const PP_AttrProp* pAP,
                                   ODe_ListenerAction& rAction) {
     bool ok;
-    const XML_Char* pValue;
+    const gchar* pValue;
     
     ok = pAP->getProperty("frame-type", pValue);
     UT_ASSERT_HARMLESS(ok && pValue != NULL);
     
-    if (pValue && !UT_strcmp(pValue, "textbox")) {
+    if (pValue && !strcmp(pValue, "textbox")) {
         ODe_Frame_Listener* pFrameListener;
             
         // Paragraph anchored textboxes goes inside the paragraph that
@@ -251,7 +251,7 @@ void ODe_Text_Listener::openFrame(const PP_AttrProp* pAP,
                                                 
         rAction.pushListenerImpl(pFrameListener, true);
         m_openedODTextboxFrame = true;
-    } else if (pValue && !UT_strcmp(pValue, "image")) {
+    } else if (pValue && !strcmp(pValue, "image")) {
         ok = pAP->getAttribute("strux-image-dataid", pValue);
         if(ok && pValue)
             insertPositionedImage(pValue, pAP);
@@ -291,31 +291,31 @@ void ODe_Text_Listener::openField(const fd_Field* field, const UT_UTF8String& fi
     UT_UTF8String escape = fieldValue;
     escape.escapeXML();
 
-    if(!UT_strcmp(fieldType.utf8_str(),"page_number")) {
+    if(!strcmp(fieldType.utf8_str(),"page_number")) {
         ODe_writeToFile(m_pParagraphContent, UT_UTF8String_sprintf("<text:page-number>%s",escape.utf8_str()));
-    } else if(!UT_strcmp(fieldType.utf8_str(),"page_count")) {
+    } else if(!strcmp(fieldType.utf8_str(),"page_count")) {
         ODe_writeToFile(m_pParagraphContent, UT_UTF8String_sprintf("<text:page-count>%s",escape.utf8_str()));
-    } else if(!UT_strcmp(fieldType.utf8_str(),"meta_creator")) {
+    } else if(!strcmp(fieldType.utf8_str(),"meta_creator")) {
         ODe_writeToFile(m_pParagraphContent, UT_UTF8String_sprintf("<text:author-name>%s",escape.utf8_str()));
-    } else if(!UT_strcmp(fieldType.utf8_str(),"meta_title")) {
+    } else if(!strcmp(fieldType.utf8_str(),"meta_title")) {
         ODe_writeToFile(m_pParagraphContent, UT_UTF8String_sprintf("<text:title>%s",escape.utf8_str()));
-    } else if(!UT_strcmp(fieldType.utf8_str(),"meta_description")) {
+    } else if(!strcmp(fieldType.utf8_str(),"meta_description")) {
         ODe_writeToFile(m_pParagraphContent, UT_UTF8String_sprintf("<text:description>%s",escape.utf8_str()));
-    } else if(!UT_strcmp(fieldType.utf8_str(),"meta_subject")) {
+    } else if(!strcmp(fieldType.utf8_str(),"meta_subject")) {
         ODe_writeToFile(m_pParagraphContent, UT_UTF8String_sprintf("<text:subject>%s",escape.utf8_str()));
-    } else if(!UT_strcmp(fieldType.utf8_str(),"meta_keywords")) {
+    } else if(!strcmp(fieldType.utf8_str(),"meta_keywords")) {
         ODe_writeToFile(m_pParagraphContent, UT_UTF8String_sprintf("<text:keywords>%s",escape.utf8_str()));
-    } else if(!UT_strcmp(fieldType.utf8_str(),"char_count")) {
+    } else if(!strcmp(fieldType.utf8_str(),"char_count")) {
         ODe_writeToFile(m_pParagraphContent, UT_UTF8String_sprintf("<text:character-count>%s",escape.utf8_str()));
-    } else if(!UT_strcmp(fieldType.utf8_str(),"word_count")) {
+    } else if(!strcmp(fieldType.utf8_str(),"word_count")) {
         ODe_writeToFile(m_pParagraphContent, UT_UTF8String_sprintf("<text:word-count>%s",escape.utf8_str()));
-    } else if(!UT_strcmp(fieldType.utf8_str(),"para_count")) {
+    } else if(!strcmp(fieldType.utf8_str(),"para_count")) {
         ODe_writeToFile(m_pParagraphContent, UT_UTF8String_sprintf("<text:paragraph-count>%s",escape.utf8_str()));
-    } else if(!UT_strcmp(fieldType.utf8_str(),"file_name")) {
+    } else if(!strcmp(fieldType.utf8_str(),"file_name")) {
         ODe_writeToFile(m_pParagraphContent, UT_UTF8String_sprintf("<text:file-name>%s",escape.utf8_str()));
-    } else if(!UT_strcmp(fieldType.utf8_str(),"time")) {
+    } else if(!strcmp(fieldType.utf8_str(),"time")) {
         ODe_writeToFile(m_pParagraphContent, UT_UTF8String_sprintf("<text:time>%s",escape.utf8_str()));
-    } else if(!UT_strcmp(fieldType.utf8_str(),"date")) {
+    } else if(!strcmp(fieldType.utf8_str(),"date")) {
         ODe_writeToFile(m_pParagraphContent, UT_UTF8String_sprintf("<text:date>%s",escape.utf8_str()));
     } else {
         UT_DEBUGMSG(("openField(): Unhandled field in the ODT exporter: %s\n", fieldType.utf8_str()));
@@ -329,31 +329,31 @@ void ODe_Text_Listener::openField(const fd_Field* field, const UT_UTF8String& fi
 void ODe_Text_Listener::closeField(const UT_UTF8String& fieldType) {
     UT_return_if_fail(fieldType.length());
 
-    if(!UT_strcmp(fieldType.utf8_str(),"page_number")) {
+    if(!strcmp(fieldType.utf8_str(),"page_number")) {
         ODe_writeToFile(m_pParagraphContent, "</text:page-number>");
-    } else if(!UT_strcmp(fieldType.utf8_str(),"page_count")) {
+    } else if(!strcmp(fieldType.utf8_str(),"page_count")) {
         ODe_writeToFile(m_pParagraphContent, "</text:page-count>");
-    } else if(!UT_strcmp(fieldType.utf8_str(),"meta_creator")) {
+    } else if(!strcmp(fieldType.utf8_str(),"meta_creator")) {
         ODe_writeToFile(m_pParagraphContent, "</text:author-name>");
-    } else if(!UT_strcmp(fieldType.utf8_str(),"meta_title")) {
+    } else if(!strcmp(fieldType.utf8_str(),"meta_title")) {
         ODe_writeToFile(m_pParagraphContent, "</text:title>");
-    } else if(!UT_strcmp(fieldType.utf8_str(),"meta_description")) {
+    } else if(!strcmp(fieldType.utf8_str(),"meta_description")) {
         ODe_writeToFile(m_pParagraphContent, "</text:description>");
-    } else if(!UT_strcmp(fieldType.utf8_str(),"meta_subject")) {
+    } else if(!strcmp(fieldType.utf8_str(),"meta_subject")) {
         ODe_writeToFile(m_pParagraphContent, "</text:subject>");
-    } else if(!UT_strcmp(fieldType.utf8_str(),"meta_keywords")) {
+    } else if(!strcmp(fieldType.utf8_str(),"meta_keywords")) {
         ODe_writeToFile(m_pParagraphContent, "</text:keywords>");
-    } else if(!UT_strcmp(fieldType.utf8_str(),"char_count")) {
+    } else if(!strcmp(fieldType.utf8_str(),"char_count")) {
         ODe_writeToFile(m_pParagraphContent, "</text:character-count>");
-    } else if(!UT_strcmp(fieldType.utf8_str(),"word_count")) {
+    } else if(!strcmp(fieldType.utf8_str(),"word_count")) {
         ODe_writeToFile(m_pParagraphContent, "</text:word-count>");
-    } else if(!UT_strcmp(fieldType.utf8_str(),"para_count")) {
+    } else if(!strcmp(fieldType.utf8_str(),"para_count")) {
         ODe_writeToFile(m_pParagraphContent, "</text:paragraph-count>");
-    } else if(!UT_strcmp(fieldType.utf8_str(),"file_name")) {
+    } else if(!strcmp(fieldType.utf8_str(),"file_name")) {
         ODe_writeToFile(m_pParagraphContent, "</text:file-name>");
-    } else if(!UT_strcmp(fieldType.utf8_str(),"time")) {
+    } else if(!strcmp(fieldType.utf8_str(),"time")) {
         ODe_writeToFile(m_pParagraphContent, "</text:time>");
-    } else if(!UT_strcmp(fieldType.utf8_str(),"date")) {
+    } else if(!strcmp(fieldType.utf8_str(),"date")) {
         ODe_writeToFile(m_pParagraphContent, "</text:date>");
     } else {
         UT_DEBUGMSG(("closeField(): Unhandled field in the ODT exporter: %s\n", fieldType.utf8_str()));
@@ -432,7 +432,7 @@ void ODe_Text_Listener::closeEndnote(ODe_ListenerAction& rAction) {
 void ODe_Text_Listener::openTOC(const PP_AttrProp* pAP) {
     UT_UTF8String output;
     bool ok;
-    const XML_Char* pValue = 0;
+    const gchar* pValue = 0;
     UT_uint8 outlineLevel;
     UT_UTF8String str;
     
@@ -570,6 +570,71 @@ void ODe_Text_Listener::closeTOC() {
 }
 
 
+/**
+ * 
+ */
+void ODe_Text_Listener::openBookmark(const PP_AttrProp* pAP) {
+    UT_return_if_fail(pAP);
+
+    UT_UTF8String output = "<text:bookmark-start text:name=\"", escape;
+    const gchar* pValue = NULL;
+
+    if(pAP->getAttribute("type",pValue) && pValue && (strcmp(pValue, "start") == 0)) {
+        if(pAP->getAttribute("name",pValue) && pValue) {
+            escape = pValue;
+            escape.escapeXML();
+
+            if(escape.length()) {
+                output+= escape;
+                output+="\"/>";
+                ODe_writeToFile(m_pParagraphContent, output);
+            }
+        }
+    }
+}
+
+/**
+ * 
+ */
+void ODe_Text_Listener::closeBookmark(const PP_AttrProp* pAP) {
+    UT_return_if_fail(pAP);
+
+    UT_UTF8String output = "<text:bookmark-end text:name=\"", escape;
+    const gchar* pValue = NULL;
+
+    if(pAP->getAttribute("type",pValue) && pValue && (strcmp(pValue, "end") == 0)) {
+        if(pAP->getAttribute("name",pValue) && pValue) {
+            escape = pValue;
+            escape.escapeXML();
+
+            if(escape.length()) {
+                output+= escape;
+                output+="\"/>";
+                ODe_writeToFile(m_pParagraphContent, output);
+            }
+        }
+    }
+}
+
+
+/**
+ * 
+ */
+void ODe_Text_Listener::closeBookmark(UT_UTF8String &sBookmarkName) {
+    UT_return_if_fail(sBookmarkName.length());
+
+    UT_UTF8String output = "<text:bookmark-end text:name=\"", escape;
+    escape = sBookmarkName;
+    escape.escapeXML();
+
+    if(escape.length()) {
+        output+= escape;
+        output+="\"/>";
+        ODe_writeToFile(m_pParagraphContent, output);
+    }
+}
+
+
 /**
  * 
  */
@@ -577,7 +642,7 @@ void ODe_Text_Listener::openHyperlink(const PP_AttrProp* pAP) {
     UT_return_if_fail(pAP);
 
     UT_UTF8String output = "<text:a ", escape;
-    const XML_Char* pValue = NULL;
+    const gchar* pValue = NULL;
 
     if(pAP->getAttribute("xlink:href",pValue) && pValue) {
         escape = pValue;
@@ -672,12 +737,13 @@ void ODe_Text_Listener::insertTabChar() {
 /**
  *
  */
-void ODe_Text_Listener::insertInlinedImage(const XML_Char* pImageName,
+void ODe_Text_Listener::insertInlinedImage(const gchar* pImageName,
                                                  const PP_AttrProp* pAP) {
     UT_UTF8String output;
     UT_UTF8String str;
+    UT_UTF8String escape;
     ODe_Style_Style* pStyle;
-    const XML_Char* pValue;
+    const gchar* pValue;
     bool ok;
 
     
@@ -706,18 +772,44 @@ void ODe_Text_Listener::insertInlinedImage(const XML_Char* pImageName,
     output += "><draw:image xlink:href=\"Pictures/";
     output += pImageName;
     output += ".png\" xlink:type=\"simple\" xlink:show=\"embed\""
-              " xlink:actuate=\"onLoad\"/></draw:frame>";
-    
+              " xlink:actuate=\"onLoad\"/>";
+
+    ok = pAP->getAttribute("alt", pValue);
+    if (ok && pValue != NULL) {
+       escape = pValue;
+       escape.escapeXML();
+       if(escape.length()) {
+           output += "<svg:desc>";
+           output += escape.utf8_str();
+           output += "</svg:desc>";
+       }
+       escape.clear();
+    }
+
+    ok = pAP->getAttribute("title", pValue);
+    if (ok && pValue != NULL) {
+       escape = pValue;
+       escape.escapeXML();
+       if(escape.length()) {
+           output += "<svg:title>";
+           output += escape.utf8_str();
+           output += "</svg:title>";
+       }
+    }
+
+    output += "</draw:frame>";
+
     ODe_writeToFile(m_pParagraphContent, output);
 }
 
 
-void ODe_Text_Listener::insertPositionedImage(const XML_Char* pImageName,
+void ODe_Text_Listener::insertPositionedImage(const gchar* pImageName,
                                                  const PP_AttrProp* pAP) {
     UT_UTF8String output = "<text:p>";
     UT_UTF8String str;
+    UT_UTF8String escape;
     ODe_Style_Style* pStyle;
-    const XML_Char* pValue;
+    const gchar* pValue;
     bool ok;
    
     pStyle = new ODe_Style_Style();
@@ -725,13 +817,13 @@ void ODe_Text_Listener::insertPositionedImage(const XML_Char* pImageName,
 
     //set wrapping
     ok = pAP->getProperty("wrap-mode", pValue);
-    if(ok && pValue && !UT_strcmp(pValue, "wrapped-to-right")) {
+    if(ok && pValue && !strcmp(pValue, "wrapped-to-right")) {
         pStyle->setWrap("right");
     }
-    else if(ok && pValue && !UT_strcmp(pValue, "wrapped-to-left")) {
+    else if(ok && pValue && !strcmp(pValue, "wrapped-to-left")) {
         pStyle->setWrap("left");
     }
-    else if(ok && pValue && !UT_strcmp(pValue, "wrapped-both")) {
+    else if(ok && pValue && !strcmp(pValue, "wrapped-both")) {
         pStyle->setWrap("parallel");
     }
     else { //this handles the above-text case and any other unforeseen ones
@@ -743,10 +835,10 @@ void ODe_Text_Listener::insertPositionedImage(const XML_Char* pImageName,
     
     output += "<draw:frame text:anchor-type=\"";
     ok = pAP->getProperty("position-to", pValue);
-    if(ok && pValue && !UT_strcmp(pValue, "column-above-text")) {
+    if(ok && pValue && !strcmp(pValue, "column-above-text")) {
         output+="paragraph\""; //the spec doesn't seem to handle column anchoring
     }
-    else if(ok && pValue && !UT_strcmp(pValue, "page-above-text")) {
+    else if(ok && pValue && !strcmp(pValue, "page-above-text")) {
         output+="page\"";
     }
     else { //this handles the block-above-text case and any other unforeseen ones
@@ -770,7 +862,32 @@ void ODe_Text_Listener::insertPositionedImage(const XML_Char* pImageName,
     output += "><draw:image xlink:href=\"Pictures/";
     output += pImageName;
     output += ".png\" xlink:type=\"simple\" xlink:show=\"embed\""
-              " xlink:actuate=\"onLoad\"/></draw:frame></text:p>";
+              " xlink:actuate=\"onLoad\"/>";
+
+    ok = pAP->getAttribute("alt", pValue);
+    if (ok && pValue != NULL) {
+       escape = pValue;
+       escape.escapeXML();
+       if(escape.length()) {
+           output += "<svg:desc>";
+           output += escape.utf8_str();
+           output += "</svg:desc>";
+       }
+       escape.clear();
+    }
+
+    ok = pAP->getAttribute("title", pValue);
+    if (ok && pValue != NULL) {
+       escape = pValue;
+       escape.escapeXML();
+       if(escape.length()) {
+           output += "<svg:title>";
+           output += escape.utf8_str();
+           output += "</svg:title>";
+       }
+    }
+
+    output += "</draw:frame></text:p>";
     
     ODe_writeToFile(m_pParagraphContent, output);
 }
@@ -782,7 +899,7 @@ void ODe_Text_Listener::insertPositionedImage(const XML_Char* pImageName,
  * a "listid" and/or "level" attribute.
  */
 bool ODe_Text_Listener::_blockIsPlainParagraph(const PP_AttrProp* pAP) const {
-    const XML_Char* pValue;
+    const gchar* pValue;
     bool ok;
     
     ok = pAP->getAttribute("level", pValue);
@@ -804,7 +921,7 @@ bool ODe_Text_Listener::_blockIsPlainParagraph(const PP_AttrProp* pAP) const {
  */
 void ODe_Text_Listener::_openODListItem(const PP_AttrProp* pAP) {
     int level;
-    const XML_Char* pValue;
+    const gchar* pValue;
     bool ok;
     UT_UTF8String output;
 
@@ -828,7 +945,7 @@ void ODe_Text_Listener::_openODListItem(const PP_AttrProp* pAP) {
         ok = pAP->getAttribute("listid", pValue);
         UT_ASSERT_HARMLESS(ok && pValue!=NULL);
                 
-        if (pValue && pListLevelStyle && (UT_strcmp(pListLevelStyle->getAbiListID().utf8_str(), pValue) != 0)) {
+        if (pValue && pListLevelStyle && (strcmp(pListLevelStyle->getAbiListID().utf8_str(), pValue) != 0)) {
             // This list item belongs to a new list.
             _closeODList(); // Close the current list to start a new one later on.
         }
@@ -943,7 +1060,7 @@ void ODe_Text_Listener::_openODParagraph(const PP_AttrProp* pAP) {
     UT_UTF8String output;
     UT_UTF8String str;
     UT_UTF8String escape;
-    const XML_Char* pValue;
+    const gchar* pValue;
     bool ok;
     
     ////
