@@ -62,49 +62,49 @@ ODi_Style_Style::ODi_Style_Style(ODi_ElementStack& rElementStack) :
 /**
  * 
  */
-void ODi_Style_Style::startElement(const XML_Char* pName,
-                                  const XML_Char** ppAtts,
+void ODi_Style_Style::startElement(const gchar* pName,
+                                  const gchar** ppAtts,
                                   ODi_ListenerStateAction& rAction) {
 
-    if (!UT_strcmp("style:style", pName)) {
+    if (!strcmp("style:style", pName)) {
         
         _parse_style_style(ppAtts);
         
-    } else if (!UT_strcmp("style:paragraph-properties", pName)) {
+    } else if (!strcmp("style:paragraph-properties", pName)) {
         
         _parse_style_paragraphProperties(ppAtts);
         
-    } else if (!UT_strcmp("style:text-properties", pName)) {
+    } else if (!strcmp("style:text-properties", pName)) {
         
         _parse_style_textProperties(ppAtts);
         
-    } else if (!UT_strcmp("style:section-properties", pName)) {
+    } else if (!strcmp("style:section-properties", pName)) {
         
         _parse_style_sectionProperties(ppAtts);
         
-    } else if (!UT_strcmp("style:graphic-properties", pName)) {
+    } else if (!strcmp("style:graphic-properties", pName)) {
         
         _parse_style_graphicProperties(ppAtts);
         
-    } else if (!UT_strcmp("style:table-properties", pName)) {
+    } else if (!strcmp("style:table-properties", pName)) {
         
         _parse_style_tableProperties(ppAtts);
         
-    } else if (!UT_strcmp("style:table-column-properties", pName)) {
+    } else if (!strcmp("style:table-column-properties", pName)) {
         
         _parse_style_tableColumnProperties(ppAtts);
         
-    } else if (!UT_strcmp("style:table-row-properties", pName)) {
+    } else if (!strcmp("style:table-row-properties", pName)) {
         
         _parse_style_tableRowProperties(ppAtts);
         
-    } else if (!UT_strcmp("style:table-cell-properties", pName)) {
+    } else if (!strcmp("style:table-cell-properties", pName)) {
         
         _parse_style_tableCellProperties(ppAtts);
         
-    } else if (!UT_strcmp("style:default-style", pName)) {
+    } else if (!strcmp("style:default-style", pName)) {
         
-        const XML_Char* pAttr;
+        const gchar* pAttr;
         
         pAttr = UT_getAttribute("style:family", ppAtts);
         UT_ASSERT(pAttr);
@@ -114,9 +114,9 @@ void ODi_Style_Style::startElement(const XML_Char* pName,
         m_displayName = m_name = "Normal";
         m_parentStyleName = "None";
         
-    } else if (!UT_strcmp("style:columns", pName)) {
+    } else if (!strcmp("style:columns", pName)) {
         
-        const XML_Char* pVal;
+        const gchar* pVal;
         
         pVal = UT_getAttribute("fo:column-count", ppAtts);
         if (pVal) {
@@ -142,13 +142,13 @@ void ODi_Style_Style::startElement(const XML_Char* pName,
 /**
  * 
  */
-void ODi_Style_Style::endElement(const XML_Char* pName,
+void ODi_Style_Style::endElement(const gchar* pName,
                                 ODi_ListenerStateAction& rAction) {
                                     
-    if (!UT_strcmp("style:style", pName)) {
+    if (!strcmp("style:style", pName)) {
         rAction.popState();
         
-    } else if (!UT_strcmp("style:default-style", pName)) {
+    } else if (!strcmp("style:default-style", pName)) {
         // I'm a default style.
         rAction.popState();
     }
@@ -161,9 +161,9 @@ void ODi_Style_Style::endElement(const XML_Char* pName,
 /**
  * 
  */
-void ODi_Style_Style::_parse_style_style(const XML_Char** ppAtts) {
+void ODi_Style_Style::_parse_style_style(const gchar** ppAtts) {
     
-    const XML_Char* pAttr;
+    const gchar* pAttr;
     
     if (m_name.empty()) {
         pAttr = UT_getAttribute("style:name", ppAtts);
@@ -220,9 +220,9 @@ void ODi_Style_Style::_parse_style_style(const XML_Char** ppAtts) {
 /**
  * 
  */
-void ODi_Style_Style::_parse_style_paragraphProperties(const XML_Char** ppProps) {
+void ODi_Style_Style::_parse_style_paragraphProperties(const gchar** ppProps) {
     
-    const XML_Char* pVal;
+    const gchar* pVal;
     
     pVal = UT_getAttribute ("style:line-height-at-least", ppProps);
     if (pVal) {
@@ -245,11 +245,11 @@ void ODi_Style_Style::_parse_style_paragraphProperties(const XML_Char** ppProps)
     
     pVal = UT_getAttribute ("fo:text-align", ppProps);
     if (pVal) {
-        if (!UT_strcmp(pVal, "end")) {
+        if (!strcmp(pVal, "end")) {
             m_align = "right";
-        } else if (!UT_strcmp(pVal, "center")) {
+        } else if (!strcmp(pVal, "center")) {
             m_align = "center";
-        } else if (!UT_strcmp(pVal, "justify")) {
+        } else if (!strcmp(pVal, "justify")) {
             m_align = "justify";
         } else {
             m_align = "left";
@@ -307,7 +307,7 @@ void ODi_Style_Style::_parse_style_paragraphProperties(const XML_Char** ppProps)
     
     pVal = UT_getAttribute("fo:keep-with-next", ppProps);
     if (pVal) {
-        if ( !UT_strcmp(pVal, "always") ) {
+        if ( !strcmp(pVal, "always") ) {
             m_keepWithNext = "yes";
         } else {
             m_keepWithNext.clear();
@@ -321,7 +321,7 @@ void ODi_Style_Style::_parse_style_paragraphProperties(const XML_Char** ppProps)
 
     pVal = UT_getAttribute("style:writing-mode", ppProps);
     if (pVal) {
-        if(!UT_strcmp(pVal,"rl") || !UT_strcmp(pVal,"rl-tb") || !UT_strcmp(pVal,"tb-rl")) {
+        if(!strcmp(pVal,"rl") || !strcmp(pVal,"rl-tb") || !strcmp(pVal,"tb-rl")) {
             m_direction = "rtl";
         } else {
             m_direction = "ltr";
@@ -336,10 +336,10 @@ void ODi_Style_Style::_parse_style_paragraphProperties(const XML_Char** ppProps)
 /**
  * <style:text-properties />
  */
-void ODi_Style_Style::_parse_style_textProperties(const XML_Char** ppProps) {
+void ODi_Style_Style::_parse_style_textProperties(const gchar** ppProps) {
     
-    const XML_Char* pVal;
-    const XML_Char* pVal2;
+    const gchar* pVal = NULL;
+    const gchar* pVal2 = NULL;
     
     pVal = UT_getAttribute("fo:color", ppProps);
     if (pVal) {
@@ -347,31 +347,56 @@ void ODi_Style_Style::_parse_style_textProperties(const XML_Char** ppProps) {
     }
     
     
-    const XML_Char* undr = NULL;
-    const XML_Char* strk = NULL;
+    const gchar* undrStyle = NULL;
+    const gchar* undrType = NULL;
+    const gchar* strkStyle = NULL;
+    const gchar* strkType = NULL;
 
-    undr = const_cast<const XML_Char *>(
+    undrStyle = const_cast<const gchar *>(
         UT_getAttribute("style:text-underline-style", ppProps));
-    strk = const_cast<const XML_Char *>(
+    undrType = const_cast<const gchar *>(
+        UT_getAttribute("style:text-underline-type", ppProps));
+    strkStyle = const_cast<const gchar *>(
         UT_getAttribute("style:text-line-through-style", ppProps));
+    strkType = const_cast<const gchar *>(
+        UT_getAttribute("style:text-line-through-type", ppProps));
 
-    if (undr || strk) {
+    if (undrStyle || undrType || strkStyle || strkType) {
         // I'm not sure if "+=" works for an uninitialized string.
         m_textDecoration = "";
+        bool bUnderline = false, bStrike = false;
 
-        if(undr)
-            if (UT_strcmp(undr, "none") != 0)
+        if (undrStyle) {
+            if (strcmp(undrStyle, "none") != 0) {
                 m_textDecoration += "underline";
+                bUnderline = true;
+            }
+        }
 
-        if (undr && strk)
-            m_textDecoration += ",";
+        if (!bUnderline && undrType) { //don't append "underline" twice
+            if (strcmp(undrType, "none") != 0) {
+                m_textDecoration += "underline";
+            }
+        }
 
-        if(strk)
-            if (UT_strcmp(strk, "none") != 0)
+        if (strkStyle) {
+            if (strcmp(strkStyle, "none") != 0) {
+                if(m_textDecoration.length())
+                    m_textDecoration += " "; //separate the props with a space, not a comma
                 m_textDecoration += "line-through";
+                bStrike = true;
+            }
+        }
+
+        if (!bStrike && strkType) { //don't append "line-through" twice
+            if (strcmp(strkType, "none") != 0) {
+                if(m_textDecoration.length())
+                    m_textDecoration += " "; //separate the props with a space, not a comma
+                m_textDecoration += "line-through";
+            }
+        }
     }
-    
-    
+
     pVal = UT_getAttribute("style:text-position", ppProps);
     if(pVal) {
         if (strstr(pVal, "sub") || strstr(pVal, "-"))
@@ -397,7 +422,7 @@ void ODi_Style_Style::_parse_style_textProperties(const XML_Char** ppProps) {
     pVal2 = UT_getAttribute("fo:country", ppProps);
     if ( pVal && pVal2 ) {
             
-        if (!UT_strcmp(pVal, "none") && !UT_strcmp(pVal2, "none")) {
+        if (!strcmp(pVal, "none") && !strcmp(pVal2, "none")) {
             // AbiWord uses "-none-" instead of "none-none";
             m_lang = "-none-";
         } else {
@@ -408,7 +433,7 @@ void ODi_Style_Style::_parse_style_textProperties(const XML_Char** ppProps) {
     
     pVal = UT_getAttribute("fo:font-style", ppProps);
     if (pVal) {
-        if (!UT_strcmp(pVal, "italic") || !UT_strcmp(pVal, "normal")) {
+        if (!strcmp(pVal, "italic") || !strcmp(pVal, "normal")) {
             m_fontStyle = pVal;
         }
     }
@@ -416,7 +441,7 @@ void ODi_Style_Style::_parse_style_textProperties(const XML_Char** ppProps) {
     
     pVal = UT_getAttribute ("fo:font-weight", ppProps);
     if(pVal) {
-        if (!UT_strcmp(pVal, "bold")) {
+        if (!strcmp(pVal, "bold")) {
             m_fontWeight = "bold";
         } else {
             m_fontWeight = "normal";
@@ -437,9 +462,9 @@ void ODi_Style_Style::_parse_style_textProperties(const XML_Char** ppProps) {
 /**
  * 
  */
-void ODi_Style_Style::_parse_style_sectionProperties(const XML_Char** ppProps) {
+void ODi_Style_Style::_parse_style_sectionProperties(const gchar** ppProps) {
     
-    const XML_Char* pVal;
+    const gchar* pVal;
     
     pVal = UT_getAttribute("fo:column-count", ppProps);
     if (pVal) {
@@ -454,8 +479,8 @@ void ODi_Style_Style::_parse_style_sectionProperties(const XML_Char** ppProps) {
 /**
  * <style:graphic-properties />
  */
-void ODi_Style_Style::_parse_style_graphicProperties(const XML_Char** ppProps) {
-    const XML_Char* pVal;
+void ODi_Style_Style::_parse_style_graphicProperties(const gchar** ppProps) {
+    const gchar* pVal;
     
     pVal = UT_getAttribute("style:wrap", ppProps);
     if (pVal) {
@@ -467,8 +492,8 @@ void ODi_Style_Style::_parse_style_graphicProperties(const XML_Char** ppProps) {
 /**
  * <style:table-properties />
  */
-void ODi_Style_Style::_parse_style_tableProperties(const XML_Char** ppProps) {
-    const XML_Char* pVal;
+void ODi_Style_Style::_parse_style_tableProperties(const gchar** ppProps) {
+    const gchar* pVal;
     
     pVal = UT_getAttribute("fo:background-color", ppProps);
     if (pVal) {
@@ -480,8 +505,8 @@ void ODi_Style_Style::_parse_style_tableProperties(const XML_Char** ppProps) {
 /**
  * <style:table-column-properties />
  */
-void ODi_Style_Style::_parse_style_tableColumnProperties(const XML_Char** ppProps) {
-    const XML_Char* pVal;
+void ODi_Style_Style::_parse_style_tableColumnProperties(const gchar** ppProps) {
+    const gchar* pVal;
     
     pVal = UT_getAttribute("style:column-width", ppProps);
     if (pVal) {
@@ -493,8 +518,8 @@ void ODi_Style_Style::_parse_style_tableColumnProperties(const XML_Char** ppProp
 /**
  * <style:table-row-properties />
  */
-void ODi_Style_Style::_parse_style_tableRowProperties(const XML_Char** ppProps) {
-    const XML_Char* pVal;
+void ODi_Style_Style::_parse_style_tableRowProperties(const gchar** ppProps) {
+    const gchar* pVal;
     
     pVal = UT_getAttribute("style:min-row-height", ppProps);
     if (pVal) {
@@ -511,8 +536,8 @@ void ODi_Style_Style::_parse_style_tableRowProperties(const XML_Char** ppProps)
 /**
  * <style:table-cell-properties />
  */
-void ODi_Style_Style::_parse_style_tableCellProperties(const XML_Char** ppProps) {
-    const XML_Char* pVal;
+void ODi_Style_Style::_parse_style_tableCellProperties(const gchar** ppProps) {
+    const gchar* pVal;
     
     // If "fo:border" is defined, its value will fill all "fo:border-*"
     pVal = UT_getAttribute("fo:border", ppProps);
@@ -606,14 +631,14 @@ void ODi_Style_Style::defineAbiStyle(PD_Document* pDocument) {
      *           ...
      *           a[n] = 0 (NULL character)
      */
-    const XML_Char* pAttr[11];
+    const gchar* pAttr[11];
     UT_uint32 i = 0;
     bool ok;
     
     pAttr[i++] = "type";
-    if (!UT_strcmp("paragraph", m_family.utf8_str())) {
+    if (!strcmp("paragraph", m_family.utf8_str())) {
         pAttr[i++] = "P";
-    } else if (!UT_strcmp("text", m_family.utf8_str())) {
+    } else if (!strcmp("text", m_family.utf8_str())) {
         pAttr[i++] = "C";
     } else {
         // Really shouldn't happen
@@ -787,7 +812,7 @@ const UT_UTF8String* ODi_Style_Style::getWrap(bool local) const {
 void ODi_Style_Style::_stripColorLength(UT_UTF8String& rColor,
                                   UT_UTF8String& rLength,
                                   ODi_Style_Style::HAVE_BORDER& rHaveBorder,
-                                  const XML_Char* pString) const {
+                                  const gchar* pString) const {
                                         
     UT_uint16 i, start;
     bool hasWord;
@@ -795,7 +820,7 @@ void ODi_Style_Style::_stripColorLength(UT_UTF8String& rColor,
     rColor.clear();
     rLength.clear();
     
-    if (!UT_strcmp(pString, "none")) {
+    if (!strcmp(pString, "none")) {
         // Color and length remain empty.
         rHaveBorder = HAVE_BORDER_NO;
         return;
@@ -846,7 +871,7 @@ void ODi_Style_Style::_stripColorLength(UT_UTF8String& rColor,
  * 
  * @param length 0 for NULL terminated strings.
  */
-bool ODi_Style_Style::_isValidDimensionString(const XML_Char* pString,
+bool ODi_Style_Style::_isValidDimensionString(const gchar* pString,
                                              UT_uint32 length) const {
     UT_uint32 i;
     bool gotDecimalSeparator;
@@ -881,7 +906,7 @@ bool ODi_Style_Style::_isValidDimensionString(const XML_Char* pString,
     }
     
     
-    XML_Char dimStr[100];
+    gchar dimStr[100];
     UT_Dimension dim;
     UT_uint32 j;
     
