@@ -90,19 +90,19 @@ ODi_TextContent_ListenerState::~ODi_TextContent_ListenerState() {
  * @param pName The name of the element.
  * @param ppAtts The attributes of the parsed start tag.
  */
-void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
-                                          const XML_Char** ppAtts,
+void ODi_TextContent_ListenerState::startElement (const gchar* pName,
+                                          const gchar** ppAtts,
                                           ODi_ListenerStateAction& rAction)
 {
-    if (UT_strcmp(pName, "text:section" ) != 0 ) {
+    if (strcmp(pName, "text:section" ) != 0 ) {
         _flushPendingParagraphBreak();
     }
     
-    if (!UT_strcmp(pName, "text:section" )) {
+    if (!strcmp(pName, "text:section" )) {
 
         // OBS: AbiWord also can't have nested sections (but OpenDocument can).
 
-        const XML_Char* pStyleName = UT_getAttribute ("text:style-name", ppAtts);
+        const gchar* pStyleName = UT_getAttribute ("text:style-name", ppAtts);
         UT_ASSERT(pStyleName != NULL);
         
         const ODi_Style_Style* pStyle = m_pStyles->getSectionStyle(pStyleName,
@@ -128,15 +128,15 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
             _openAbiSection(props);
         }
 
-    } else if (!UT_strcmp(pName, "text:p" )) {
+    } else if (!strcmp(pName, "text:p" )) {
         
         // It's so big that it deserves its own function.
         _startParagraphElement(pName, ppAtts, rAction);
         
-    } else if (!UT_strcmp(pName, "text:h" )) {
+    } else if (!strcmp(pName, "text:h" )) {
 
-        const XML_Char* pStyleName;
-        const XML_Char* pOutlineLevel;
+        const gchar* pStyleName;
+        const gchar* pOutlineLevel;
         const ODi_Style_Style* pStyle;
         
         pStyleName = UT_getAttribute("text:style-name", ppAtts);
@@ -176,10 +176,10 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
         // It's so big that it deserves its own function.
         _startParagraphElement(pName, ppAtts, rAction);
         
-    } else if (!UT_strcmp(pName, "text:s")) {
+    } else if (!strcmp(pName, "text:s")) {
         // A number of consecutive white-space characters.
         
-        const XML_Char* pSpaceCount;
+        const gchar* pSpaceCount;
         UT_uint32 spaceCount, i;
         UT_UCS4String string;
         
@@ -208,7 +208,7 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
         
         m_pAbiDocument->appendSpan(string.ucs4_str(), string.size());
         
-    } else if (!UT_strcmp(pName, "text:tab")) {
+    } else if (!strcmp(pName, "text:tab")) {
         // A tab character.
 
         UT_UCS4String string = "\t";
@@ -219,7 +219,7 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
         
         m_pAbiDocument->appendSpan(string.ucs4_str(), string.size());
         
-    } else if (!UT_strcmp(pName, "text:table-of-content")) {
+    } else if (!strcmp(pName, "text:table-of-content")) {
         
         _flush ();
         _insureInBlock(NULL);
@@ -231,12 +231,12 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
             
         rAction.pushState(m_pCurrentTOCParser, false);
 
-    } else if (!UT_strcmp(pName, "text:span")) {
+    } else if (!strcmp(pName, "text:span")) {
         // Write all text that is between the last element tag and this
         // <text:span>
         _flush ();
 
-        const XML_Char* pStyleName = UT_getAttribute("text:style-name", ppAtts);
+        const gchar* pStyleName = UT_getAttribute("text:style-name", ppAtts);
         const ODi_Style_Style* pStyle;
         
         if (!pStyleName) {
@@ -248,7 +248,7 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
             
             if (pStyle) {
             
-                const XML_Char* ppStyAttr[3];
+                const gchar* ppStyAttr[3];
                 bool ok;
                 UT_UTF8String props;
                 
@@ -274,83 +274,83 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
             }
         }
         
-    } else if (!UT_strcmp(pName, "text:line-break")) {
+    } else if (!strcmp(pName, "text:line-break")) {
         
         m_charData += UCS_LF;
         _flush ();
         
-    } else if (!UT_strcmp(pName, "text:a")) {
+    } else if (!strcmp(pName, "text:a")) {
         
         _flush();
-        const XML_Char * xlink_atts[3];
+        const gchar * xlink_atts[3];
         xlink_atts[0] = "xlink:href";
         xlink_atts[1] = UT_getAttribute("xlink:href", ppAtts);
         xlink_atts[2] = 0;
         m_pAbiDocument->appendObject(PTO_Hyperlink, xlink_atts);
         
-    } else if (!UT_strcmp(pName, "text:bookmark")) {
+    } else if (!strcmp(pName, "text:bookmark")) {
         
         _flush ();
-        const XML_Char * pName = UT_getAttribute ("text:name", ppAtts);
+        const gchar * pName = UT_getAttribute ("text:name", ppAtts);
         _insertBookmark (pName, "start");
         _insertBookmark (pName, "end");
         
-    } else if (!UT_strcmp(pName, "text:date") ||
-            !UT_strcmp(pName, "text:time") ||
-            !UT_strcmp(pName, "text:page-number") ||
-            !UT_strcmp(pName, "text:page-count") ||
-            !UT_strcmp(pName, "text:file-name") ||
-            !UT_strcmp(pName, "text:paragraph-count") ||
-            !UT_strcmp(pName, "text:word-count") ||
-            !UT_strcmp(pName, "text:character-count") ||
-            !UT_strcmp(pName, "text:initial-creator") ||
-            !UT_strcmp(pName, "text:author-name") ||
-            !UT_strcmp(pName, "text:description") ||
-            !UT_strcmp(pName, "text:keywords") ||
-            !UT_strcmp(pName, "text:subject") ||
-            !UT_strcmp(pName, "text:title")) {
+    } else if (!strcmp(pName, "text:date") ||
+            !strcmp(pName, "text:time") ||
+            !strcmp(pName, "text:page-number") ||
+            !strcmp(pName, "text:page-count") ||
+            !strcmp(pName, "text:file-name") ||
+            !strcmp(pName, "text:paragraph-count") ||
+            !strcmp(pName, "text:word-count") ||
+            !strcmp(pName, "text:character-count") ||
+            !strcmp(pName, "text:initial-creator") ||
+            !strcmp(pName, "text:author-name") ||
+            !strcmp(pName, "text:description") ||
+            !strcmp(pName, "text:keywords") ||
+            !strcmp(pName, "text:subject") ||
+            !strcmp(pName, "text:title")) {
                 
         _flush ();
 
-        const XML_Char * type = "";
-        if(!UT_strcmp(pName, "text:date"))
+        const gchar * type = "";
+        if(!strcmp(pName, "text:date"))
             type = "date_ddmmyy";
-        else if(!UT_strcmp(pName, "text:time"))
+        else if(!strcmp(pName, "text:time"))
             type = "time";
-        else if(!UT_strcmp(pName, "text:page-number"))
+        else if(!strcmp(pName, "text:page-number"))
             type = "page_number";
-        else if(!UT_strcmp(pName, "text:page-count"))
+        else if(!strcmp(pName, "text:page-count"))
             type = "page_count";
-        else if(!UT_strcmp(pName, "text:file-name"))
+        else if(!strcmp(pName, "text:file-name"))
             type = "file_name";
-        else if(!UT_strcmp(pName, "text:paragraph-count"))
+        else if(!strcmp(pName, "text:paragraph-count"))
             type = "para_count";
-        else if(!UT_strcmp(pName, "text:word-count"))
+        else if(!strcmp(pName, "text:word-count"))
             type = "word_count";
-        else if(!UT_strcmp(pName, "text:character-count"))
+        else if(!strcmp(pName, "text:character-count"))
             type = "char_count";
-        else if(!UT_strcmp(pName, "text:initial-creator") || !UT_strcmp(pName, "text:author-name"))
+        else if(!strcmp(pName, "text:initial-creator") || !strcmp(pName, "text:author-name"))
             type = "meta_creator";
-        else if(!UT_strcmp(pName, "text:description"))
+        else if(!strcmp(pName, "text:description"))
             type = "meta_description";
-        else if(!UT_strcmp(pName, "text:keywords"))
+        else if(!strcmp(pName, "text:keywords"))
             type = "meta_keywords";
-        else if(!UT_strcmp(pName, "text:subject"))
+        else if(!strcmp(pName, "text:subject"))
             type = "meta_subject";
-        else if(!UT_strcmp(pName, "text:title"))
+        else if(!strcmp(pName, "text:title"))
             type = "meta_title";
 
-        const XML_Char *field_fmt[3];
+        const gchar *field_fmt[3];
         field_fmt[0] = "type";
         field_fmt[1] = type;
         field_fmt[2] = 0;
-        m_pAbiDocument->appendObject(PTO_Field, (const XML_Char**)field_fmt);
+        m_pAbiDocument->appendObject(PTO_Field, (const gchar**)field_fmt);
         m_bAcceptingText = false;
         
-    } else if (!UT_strcmp(pName, "style:header") ||
-               !UT_strcmp(pName, "style:footer") ||
-               !UT_strcmp(pName, "style:header-left") ||
-               !UT_strcmp(pName, "style:footer-left")) {
+    } else if (!strcmp(pName, "style:header") ||
+               !strcmp(pName, "style:footer") ||
+               !strcmp(pName, "style:header-left") ||
+               !strcmp(pName, "style:footer-left")) {
                 
         UT_ASSERT(m_elementParsingLevel == 0);
                 
@@ -359,16 +359,16 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
         m_inAbiSection = true;
         m_bOnContentStream = false;
         
-    } else if (!UT_strcmp(pName, "office:text")) {
+    } else if (!strcmp(pName, "office:text")) {
         UT_ASSERT(m_elementParsingLevel == 0);
         m_bOnContentStream = true;
         
-    } else if (!UT_strcmp(pName, "text:list")) {
+    } else if (!strcmp(pName, "text:list")) {
         
         if (m_pCurrentListStyle != NULL) {
             m_listLevel++;
         } else {
-            const XML_Char* pVal;
+            const gchar* pVal;
             
             pVal = UT_getAttribute("text:style-name", ppAtts);
             
@@ -380,21 +380,21 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
             m_listLevel = 1;
         }
         
-    } else if (!UT_strcmp(pName, "text:list-item")) {
+    } else if (!strcmp(pName, "text:list-item")) {
         m_alreadyDefinedAbiParagraphForList = false;
         
-    } else if (!UT_strcmp(pName, "draw:frame")) {
+    } else if (!strcmp(pName, "draw:frame")) {
         
-        if (!UT_strcmp(m_rElementStack.getStartTag(0)->getName(), "text:p") ||
-            !UT_strcmp(m_rElementStack.getStartTag(0)->getName(), "text:h")) {
+        if (!strcmp(m_rElementStack.getStartTag(0)->getName(), "text:p") ||
+            !strcmp(m_rElementStack.getStartTag(0)->getName(), "text:h")) {
             
-            const XML_Char* pVal = NULL;
+            const gchar* pVal = NULL;
             
             pVal = UT_getAttribute("text:anchor-type", ppAtts);
             UT_ASSERT(pVal);
             
-            if (pVal && (!UT_strcmp(pVal, "paragraph") ||
-                !UT_strcmp(pVal, "page"))) {
+            if (pVal && (!strcmp(pVal, "paragraph") ||
+                !strcmp(pVal, "page"))) {
                 // It's postponed because AbiWord uses frames *after* the
                 // paragraph but OpenDocument uses then inside the paragraphs,
                 // right *before* its content.
@@ -405,7 +405,7 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
                 rAction.pushState("Frame");
             }
             
-        } else if (!UT_strcmp(m_rElementStack.getStartTag(0)->getName(), "office:text")) {
+        } else if (!strcmp(m_rElementStack.getStartTag(0)->getName(), "office:text")) {
             
             // A page anchored frame.
             //
@@ -417,16 +417,16 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
             // Ignore this element
             rAction.ignoreElement();
            
-        } else if (!UT_strcmp(m_rElementStack.getStartTag(0)->getName(),
+        } else if (!strcmp(m_rElementStack.getStartTag(0)->getName(),
                               "text:span")) {
             // Must be an inlined image, otherwise we can't handle it.
             
-            const XML_Char* pVal;
+            const gchar* pVal;
             
             pVal = UT_getAttribute("text:anchor-type", ppAtts);
             UT_ASSERT(pVal);
             
-            if (pVal && (!UT_strcmp(pVal, "as-char") || !UT_strcmp(pVal, "char"))) {
+            if (pVal && (!strcmp(pVal, "as-char") || !strcmp(pVal, "char"))) {
                 _flush();
                 rAction.pushState("Frame");
             } else {
@@ -439,18 +439,18 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
             // TODO: Figure out what to do then.
         }
         
-    } else if (!UT_strcmp(pName, "draw:text-box")) {
+    } else if (!strcmp(pName, "draw:text-box")) {
         UT_ASSERT(m_elementParsingLevel == 0);
         
         // We're inside a text-box, parsing its text contents.
         m_inAbiSection = true;
         m_bOnContentStream = true;
         
-    } else if (!UT_strcmp(pName, "table:table")) {
+    } else if (!strcmp(pName, "table:table")) {
         _insureInSection();
         rAction.pushState("Table");
         
-    } else if (!UT_strcmp(pName, "table:table-cell")) {
+    } else if (!strcmp(pName, "table:table-cell")) {
         UT_ASSERT(m_elementParsingLevel == 0);
         
         // We're inside a table cell, parsing its text contents.
@@ -458,14 +458,14 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
         m_bOnContentStream = true;
         m_openedFirstAbiSection = true;
         
-    }  else if (!UT_strcmp(pName, "text:note")) {
+    }  else if (!strcmp(pName, "text:note")) {
 
         _flush();
         m_bAcceptingText = false;
         
-    } else if (!UT_strcmp(pName, "text:note-body")) {
+    } else if (!strcmp(pName, "text:note-body")) {
 
-        const XML_Char* ppAtts[10];
+        const gchar* ppAtts[10];
         bool ok;
         UT_uint32 id;
         const ODi_NotesConfiguration* pNotesConfig;
@@ -473,14 +473,14 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
         const UT_UTF8String* pCitationStyleName = NULL;
         UT_uint8 i;
         bool isFootnote;
-        const XML_Char* pNoteClass;
+        const gchar* pNoteClass;
         
         pNoteClass = m_rElementStack.getStartTag(0)->getAttributeValue("text:note-class");
         UT_ASSERT(pNoteClass != NULL);
         
-        if (!UT_strcmp(pNoteClass, "footnote")) {
+        if (!strcmp(pNoteClass, "footnote")) {
             isFootnote = true;
-        } else if (!UT_strcmp(pNoteClass, "endnote")) {
+        } else if (!strcmp(pNoteClass, "endnote")) {
             isFootnote = false;
         } else {
             UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
@@ -553,18 +553,18 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
  * 
  * @param pName The name of the element
  */
-void ODi_TextContent_ListenerState::endElement (const XML_Char* pName,
+void ODi_TextContent_ListenerState::endElement (const gchar* pName,
                                                ODi_ListenerStateAction& rAction)
 {
     UT_ASSERT(m_elementParsingLevel >= 0);
     
-    if (!UT_strcmp(pName, "text:table-of-content")) {
+    if (!strcmp(pName, "text:table-of-content")) {
         
         m_tablesOfContent.addItem( m_pCurrentTOCParser->getTOCStrux() );
         m_tablesOfContentProps.addItem( new UT_UTF8String(m_pCurrentTOCParser->getProps()) );
         DELETEP(m_pCurrentTOCParser);
         
-    } else if (!UT_strcmp(pName, "text:section" )) {
+    } else if (!strcmp(pName, "text:section" )) {
 
         if (m_currentODSection == ODI_SECTION_MAPPED) {
             // Just close the current section
@@ -572,39 +572,39 @@ void ODi_TextContent_ListenerState::endElement (const XML_Char* pName,
             m_inAbiSection = false;
         }
 
-    } else if (!UT_strcmp(pName, "text:p" ) || !UT_strcmp(pName, "text:h" )) {
+    } else if (!strcmp(pName, "text:p" ) || !strcmp(pName, "text:h" )) {
 
         _endParagraphElement(pName, rAction);
         
-    } else if (!UT_strcmp(pName, "text:span")) {
+    } else if (!strcmp(pName, "text:span")) {
         
         _flush ();
         _popInlineFmt();
         m_pAbiDocument->appendFmt(&m_vecInlineFmt);
         
-    } else if (!UT_strcmp(pName, "text:a")) {
+    } else if (!strcmp(pName, "text:a")) {
         
         _flush ();
         m_pAbiDocument->appendObject(PTO_Hyperlink, NULL);
         
-    } else if (!UT_strcmp(pName, "text:date") ||
-        !UT_strcmp(pName, "text:time") ||
-        !UT_strcmp(pName, "text:page-number") ||
-        !UT_strcmp(pName, "text:page-count") ||
-        !UT_strcmp(pName, "text:file-name") ||
-        !UT_strcmp(pName, "text:paragraph-count") ||
-        !UT_strcmp(pName, "text:word-count") ||
-        !UT_strcmp(pName, "text:character-count") ||
-        !UT_strcmp(pName, "text:initial-creator") ||
-        !UT_strcmp(pName, "text:author-name") ||
-        !UT_strcmp(pName, "text:description") ||
-        !UT_strcmp(pName, "text:keywords") ||
-        !UT_strcmp(pName, "text:subject") ||
-        !UT_strcmp(pName, "text:title")) {
+    } else if (!strcmp(pName, "text:date") ||
+        !strcmp(pName, "text:time") ||
+        !strcmp(pName, "text:page-number") ||
+        !strcmp(pName, "text:page-count") ||
+        !strcmp(pName, "text:file-name") ||
+        !strcmp(pName, "text:paragraph-count") ||
+        !strcmp(pName, "text:word-count") ||
+        !strcmp(pName, "text:character-count") ||
+        !strcmp(pName, "text:initial-creator") ||
+        !strcmp(pName, "text:author-name") ||
+        !strcmp(pName, "text:description") ||
+        !strcmp(pName, "text:keywords") ||
+        !strcmp(pName, "text:subject") ||
+        !strcmp(pName, "text:title")) {
             
         m_bAcceptingText = true;
         
-    } else if (!UT_strcmp(pName, "office:text")) {
+    } else if (!strcmp(pName, "office:text")) {
 
         UT_ASSERT(m_elementParsingLevel == 1);        
         UT_ASSERT(m_bOnContentStream);
@@ -622,10 +622,10 @@ void ODi_TextContent_ListenerState::endElement (const XML_Char* pName,
         // page-anchored frames)
         rAction.bringUpPostponedElements(false);
         
-    } else if (!UT_strcmp(pName, "style:header") ||
-               !UT_strcmp(pName, "style:footer") ||
-               !UT_strcmp(pName, "style:header-left") ||
-               !UT_strcmp(pName, "style:footer-left")) {
+    } else if (!strcmp(pName, "style:header") ||
+               !strcmp(pName, "style:footer") ||
+               !strcmp(pName, "style:header-left") ||
+               !strcmp(pName, "style:footer-left")) {
 
         UT_ASSERT(m_elementParsingLevel == 1);
         UT_ASSERT(!m_bOnContentStream);
@@ -633,34 +633,34 @@ void ODi_TextContent_ListenerState::endElement (const XML_Char* pName,
         // We were inside a <style:header/footer> element.
         rAction.popState();
         
-    } else if (!UT_strcmp(pName, "text:list")) {
+    } else if (!strcmp(pName, "text:list")) {
         m_listLevel--;
         if (m_listLevel == 0) {
             m_pCurrentListStyle = NULL;
         }
         
-    } else if (!UT_strcmp(pName, "draw:text-box")) {
+    } else if (!strcmp(pName, "draw:text-box")) {
         UT_ASSERT(m_elementParsingLevel == 1);
         
         // We were inside a <draw:text-box> element.
         rAction.popState();
         
-    } else if (!UT_strcmp(pName, "table:table-cell")) {
+    } else if (!strcmp(pName, "table:table-cell")) {
         UT_ASSERT(m_elementParsingLevel == 1);
         
         // We were inside a <table:table-cell> element.
         rAction.popState();
         
-    } else if (!UT_strcmp(pName, "text:note-body")) {
+    } else if (!strcmp(pName, "text:note-body")) {
         bool ok;
-        const XML_Char* pNoteClass;
+        const gchar* pNoteClass;
         
         pNoteClass = m_rElementStack.getStartTag(1)->getAttributeValue("text:note-class");
         UT_ASSERT(pNoteClass != NULL);
         
-        if (!UT_strcmp(pNoteClass, "footnote")) {
+        if (!strcmp(pNoteClass, "footnote")) {
             ok = m_pAbiDocument->appendStrux(PTX_EndFootnote, NULL);
-        } else if (!UT_strcmp(pNoteClass, "endnote")) {
+        } else if (!strcmp(pNoteClass, "endnote")) {
             ok = m_pAbiDocument->appendStrux(PTX_EndEndnote, NULL);
         } else {
             UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
@@ -669,7 +669,7 @@ void ODi_TextContent_ListenerState::endElement (const XML_Char* pName,
         
         UT_ASSERT(ok);
 
-    } else if (!UT_strcmp(pName, "text:note")) {
+    } else if (!strcmp(pName, "text:note")) {
         UT_ASSERT(!m_pendingNoteAnchorInsertion);
         
         m_pendingNoteAnchorInsertion = false;
@@ -687,7 +687,7 @@ void ODi_TextContent_ListenerState::endElement (const XML_Char* pName,
  * 
  */
 void ODi_TextContent_ListenerState::charData (
-                            const XML_Char* pBuffer, int length)
+                            const gchar* pBuffer, int length)
 {
     if (pBuffer && length && m_bAcceptingText) {
         m_charData += UT_UCS4String (pBuffer, length, true);
@@ -698,13 +698,13 @@ void ODi_TextContent_ListenerState::charData (
 /**
  * 
  */
-void ODi_TextContent_ListenerState::_insertBookmark (const XML_Char* pName,
-                                             const XML_Char* pType)
+void ODi_TextContent_ListenerState::_insertBookmark (const gchar* pName,
+                                             const gchar* pType)
 {
-    const XML_Char* pPropsArray[5];
-    pPropsArray[0] = (XML_Char *)"name";
+    const gchar* pPropsArray[5];
+    pPropsArray[0] = (gchar *)"name";
     pPropsArray[1] = pName;
-    pPropsArray[2] = (XML_Char *)"type";
+    pPropsArray[2] = (gchar *)"type";
     pPropsArray[3] = pType;
     pPropsArray[4] = 0;
     m_pAbiDocument->appendObject (PTO_Bookmark, pPropsArray);
@@ -726,15 +726,15 @@ void ODi_TextContent_ListenerState::_flush ()
 /**
  * 
  */
-bool ODi_TextContent_ListenerState::_pushInlineFmt(const XML_Char ** atts)
+bool ODi_TextContent_ListenerState::_pushInlineFmt(const gchar ** atts)
 {
     UT_uint32 start = m_vecInlineFmt.getItemCount()+1;
     UT_uint32 k;
-    XML_Char* p;
+    gchar* p;
     
     for (k=0; (atts[k]); k++)
     {
-        if (!UT_XML_cloneString(p,atts[k])) {
+        if (!(p = g_strdup(atts[k]))) {
             return false;
         }
         
@@ -764,11 +764,11 @@ void ODi_TextContent_ListenerState::_popInlineFmt(void)
         
     UT_uint32 k;
     UT_uint32 end = m_vecInlineFmt.getItemCount();
-    const XML_Char* p;
+    const gchar* p;
     
     for (k=end; k>=start; k--) {
         
-        p = (const XML_Char *)m_vecInlineFmt.getNthItem(k-1);
+        p = (const gchar *)m_vecInlineFmt.getNthItem(k-1);
         m_vecInlineFmt.deleteNthItem(k-1);
         
         if (p)
@@ -806,7 +806,7 @@ void ODi_TextContent_ListenerState::_insureInSection(
     pStartTag = m_rElementStack.getClosestElement("text:section");
     
     if (pStartTag!=NULL) {
-        const XML_Char* pStyleName;
+        const gchar* pStyleName;
         const ODi_Style_Style* pStyle;
         
         pStyleName = pStartTag->getAttributeValue("text:style-name");
@@ -895,7 +895,7 @@ void ODi_TextContent_ListenerState::_openAbiSection(
     allProps += rProps;
 
     
-    const XML_Char* atts[20];
+    const gchar* atts[20];
     UT_uint8 i = 0;
     atts[i++] = "props";
     atts[i++] = allProps.utf8_str();
@@ -930,7 +930,7 @@ void ODi_TextContent_ListenerState::_openAbiSection(
         _insureInBlock(NULL); //see Bug 10627 - hang on empty <section>
     }
    
-    m_pAbiDocument->appendStrux(PTX_Section, (const XML_Char**)atts);    
+    m_pAbiDocument->appendStrux(PTX_Section, (const gchar**)atts);    
     m_bOpenedBlock = false;
 
     // For some reason AbiWord can't have a page break right before a new section.
@@ -949,7 +949,7 @@ void ODi_TextContent_ListenerState::_openAbiSection(
 /**
  * 
  */
-void ODi_TextContent_ListenerState::_insureInBlock(const XML_Char ** atts)
+void ODi_TextContent_ListenerState::_insureInBlock(const gchar ** atts)
 {
     if (m_bAcceptingText)
         return;
@@ -957,7 +957,7 @@ void ODi_TextContent_ListenerState::_insureInBlock(const XML_Char ** atts)
     _insureInSection();
 
     if (!m_bAcceptingText) {
-        m_pAbiDocument->appendStrux(PTX_Block, (const XML_Char**)atts);    
+        m_pAbiDocument->appendStrux(PTX_Block, (const gchar**)atts);    
         m_bOpenedBlock = true;
         m_bAcceptingText = true;
     }
@@ -967,20 +967,20 @@ void ODi_TextContent_ListenerState::_insureInBlock(const XML_Char ** atts)
 /**
  * Process <text:p> and <text:h> startElement calls
  */
-void ODi_TextContent_ListenerState::_startParagraphElement (const XML_Char* pName,
-                                          const XML_Char** ppParagraphAtts,
+void ODi_TextContent_ListenerState::_startParagraphElement (const gchar* pName,
+                                          const gchar** ppParagraphAtts,
                                           ODi_ListenerStateAction& rAction) {
         bool bIsListParagraph = false;
-        const XML_Char* pStyleName;
-        const XML_Char *ppAtts[50];
+        const gchar* pStyleName;
+        const gchar *ppAtts[50];
         UT_uint8 i;
-        XML_Char listLevel[10];
+        gchar listLevel[10];
         bool ok;
         UT_UTF8String props;
         const ODi_Style_Style* pStyle;
         
         
-        if (!UT_strcmp(m_rElementStack.getStartTag(0)->getName(), "text:list-item")) {
+        if (!strcmp(m_rElementStack.getStartTag(0)->getName(), "text:list-item")) {
             // That's a list paragraph.
             bIsListParagraph = true;
         }
@@ -1091,7 +1091,7 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const XML_Char* pNam
                 
             ppAtts[i] = 0; // Marks the end of the attributes list.
             ok = m_pAbiDocument->appendStrux(PTX_Block,
-                                             (const XML_Char**)ppAtts);
+                                             (const gchar**)ppAtts);
             UT_ASSERT(ok);
             m_bOpenedBlock = true;
 
@@ -1158,7 +1158,7 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const XML_Char* pNam
             }
         
             ppAtts[i] = 0; // Marks the end of the attributes list.
-            m_pAbiDocument->appendStrux(PTX_Block, (const XML_Char**)ppAtts);
+            m_pAbiDocument->appendStrux(PTX_Block, (const gchar**)ppAtts);
             m_bOpenedBlock = true;
         }
 
@@ -1170,7 +1170,7 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const XML_Char* pNam
 
             UT_return_if_fail(!m_currentNoteId.empty());
             
-            const XML_Char* pNoteClass;
+            const gchar* pNoteClass;
             const ODi_StartTag* pStartTag;
         
             pStartTag = m_rElementStack.getClosestElement("text:note", 1);
@@ -1181,10 +1181,10 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const XML_Char* pNam
             UT_return_if_fail(pNoteClass != NULL);
             
             ppAtts[0] = "type";
-            if (!UT_strcmp(pNoteClass, "footnote")) {
+            if (!strcmp(pNoteClass, "footnote")) {
                 ppAtts[1] = "footnote_anchor";
                 ppAtts[2] = "footnote-id";
-            } else if (!UT_strcmp(pNoteClass, "endnote")) {
+            } else if (!strcmp(pNoteClass, "endnote")) {
                 ppAtts[1] = "endnote_anchor";
                 ppAtts[2] = "endnote-id";
             } else {
@@ -1204,10 +1204,10 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const XML_Char* pNam
  * 
  */
 void ODi_TextContent_ListenerState::_endParagraphElement (
-                                           const XML_Char* pName,
+                                           const gchar* pName,
                                            ODi_ListenerStateAction& rAction) {
                                             
-    const XML_Char* pStyleName;
+    const gchar* pStyleName;
     const ODi_Style_Style* pStyle;
     
     _flush ();
