@@ -72,7 +72,7 @@ IE_Exp_OpenWriter_Sniffer::~IE_Exp_OpenWriter_Sniffer()
  */
 bool IE_Exp_OpenWriter_Sniffer::recognizeSuffix(const char * szSuffix)
 {
-  return (!UT_stricmp(szSuffix,".sxw"));
+  return (!g_ascii_strcasecmp(szSuffix,".sxw"));
 }
 
 /*!
@@ -313,7 +313,6 @@ void OO_WriterImpl::closeSpan()
 
 void OO_StylesContainer::addSpanStyle(UT_String &key)
 {
-   const void *temp;
    //if (!m_spanStylesHash.contains(key.utf8_str(), temp)) 
    if (!m_spanStylesHash.pick(key.c_str())) 
    {
@@ -374,7 +373,6 @@ const int OO_StylesContainer::getSpanStyleNum(UT_String &key) const
 const int OO_StylesContainer::getBlockStyleNum(UT_String & styleAtts, UT_String & styleProps) const
 {
 	UT_GenericVector<const UT_String*> *keys = m_blockAttsHash.keys();
-	int num = keys->findItem(&styleProps);
 
 	for (int i = 0; i < keys->size(); i++) 
 	{
@@ -478,7 +476,9 @@ bool OO_Listener::populateStrux(PL_StruxDocHandle sdh,
    {
       _closeSpan ();
       _openBlock(pcr->getIndexAP());
+      break;
    }
+   default: break;
    }
    
    return true;
@@ -529,7 +529,7 @@ void OO_Listener::_openBlock (PT_AttrPropIndex api)
 		UT_UTF8String sa, pa, f, escape;
 		OO_StylesWriter::map(pAP, sa, pa, f);
 
-		const XML_Char * szStyle = NULL;
+		const gchar * szStyle = NULL;
 		pAP->getAttribute("style", szStyle);
 
 		if (szStyle && pa.size())
@@ -911,7 +911,7 @@ void OO_StylesWriter::addFontDecls(UT_UTF8String & buffer, OO_StylesContainer &
 	for (int i = 0; i < vecFonts->size(); i++) {
 		// FIXME ATM only variable width fonts
 		// check here by using pango?
-		const XML_Char * pitch = "variable";
+		const gchar * pitch = "variable";
 		const UT_String * font = vecFonts->getNthItem(i);
 		buffer += UT_UTF8String_sprintf("<style:font-decl style:name=\"%s\" fo:font-family=\"'%s'\" style:font-pitch=\"%s\"/>\n", 
 						font->c_str(), font->c_str(), pitch);
@@ -922,7 +922,7 @@ void OO_StylesWriter::addFontDecls(UT_UTF8String & buffer, OO_StylesContainer &
 void OO_StylesWriter::map(const PP_AttrProp * pAP, UT_UTF8String & styleAtts, UT_UTF8String & propAtts, UT_UTF8String & font) 
 {		
 	UT_UTF8String escape;
-	const XML_Char * szValue = NULL;
+	const gchar * szValue = NULL;
 	styleAtts.clear();
 	propAtts.clear();
 
@@ -934,7 +934,7 @@ void OO_StylesWriter::map(const PP_AttrProp * pAP, UT_UTF8String & styleAtts, UT
 	}
 
 	if (pAP->getAttribute("type", szValue)) 
-		if (!UT_strcmp(szValue, "P"))
+		if (!strcmp(szValue, "P"))
 		{
 			styleAtts += UT_UTF8String_sprintf("style:family=\"paragraph\" ");
 			styleAtts += UT_UTF8String_sprintf("style:class=\"text\" ");
@@ -949,7 +949,7 @@ void OO_StylesWriter::map(const PP_AttrProp * pAP, UT_UTF8String & styleAtts, UT
 	if (pAP->getAttribute("followedby", szValue)) 
 	{
 		// ignore, current style is default
-		if (UT_strcmp(szValue, "Current Settings"))
+		if (strcmp(szValue, "Current Settings"))
 		{
 			escape = szValue;
 			styleAtts += UT_UTF8String_sprintf("style:next-style-name=\"%s\" ", escape.escapeXML().utf8_str());
@@ -969,7 +969,7 @@ void OO_StylesWriter::map(const PP_AttrProp * pAP, UT_UTF8String & styleAtts, UT
 	}
 
 	if (pAP->getProperty("dom-dir", szValue)) //:ltr; 
-		if (!UT_strcmp(szValue, "rtl"))
+		if (!strcmp(szValue, "rtl"))
 		{
 			// FIXME some of these parameters are mentioned more than once
 			propAtts += UT_UTF8String_sprintf("fo:text-align", "end");
@@ -1046,11 +1046,11 @@ void OO_StylesWriter::map(const PP_AttrProp * pAP, UT_UTF8String & styleAtts, UT
 
 	if (pAP->getProperty("text-align", szValue)) //left center right -> start end left right center justify
 	{
-		if (UT_strcmp(szValue, "left")) // skip default
+		if (strcmp(szValue, "left")) // skip default
 		{
 			propAtts += UT_UTF8String_sprintf("style:justify-single-word=\"false\" ");
 
-			if (!UT_strcmp(szValue, "right"))
+			if (!strcmp(szValue, "right"))
 				propAtts += UT_UTF8String_sprintf("fo:text-align=\"end\" ");
 			else
 				propAtts += UT_UTF8String_sprintf("fo:text-align=\"%s\" ", szValue);
@@ -1077,9 +1077,9 @@ void OO_StylesWriter::map(const PP_AttrProp * pAP, UT_UTF8String & styleAtts, UT
 
 	if (pAP->getProperty("text-position", szValue))
 	{
-		if (!UT_strcmp(szValue, "superscript"))
+		if (!strcmp(szValue, "superscript"))
 			propAtts += "style:text-position=\"super 58%\" ";
-		else if (!UT_strcmp(szValue, "subscript"))
+		else if (!strcmp(szValue, "subscript"))
 			propAtts += "style:text-position=\"sub 58%\" ";
 	}
 
