@@ -73,7 +73,7 @@ public:
   * Parse attributes array and map keys and values
   * to Abi's.
   */
-  void appendPageMaster(const XML_Char * name, const XML_Char ** atts) 
+  void appendPageMaster(const gchar * name, const gchar ** atts) 
   {
     // FIXME ATM only one page setup per document can be imported
     if (m_name != "")
@@ -88,38 +88,38 @@ public:
   /*!
   * Returns the name of the current page setup style.
   */
-  const XML_Char * getName() const 
+  const gchar * getName() const 
   {
-    return reinterpret_cast<const XML_Char *>(m_name.c_str());
+    return reinterpret_cast<const gchar *>(m_name.c_str());
   }
 
   /*!
   * Returns attribute array for the <pagesize> tag.
   */
-  const XML_Char ** getAbiPageAtts(const XML_Char * masterName)
+  const gchar ** getAbiPageAtts(const gchar * masterName)
   {
-    UT_return_val_if_fail(masterName != NULL, (const XML_Char **)m_pageAtts);
+    UT_return_val_if_fail(masterName != NULL, (const gchar **)m_pageAtts);
 
-    if (UT_strcmp (m_name.c_str(), masterName))
+    if (strcmp (m_name.c_str(), masterName))
       // FIXME can there be more than one master-page?
       UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
     
-    return (const XML_Char **)m_pageAtts;
+    return (const gchar **)m_pageAtts;
   }
   
   /*!
   * Returns props string for the <section> tag.
   */
-  const XML_Char * getAbiSectionProps() const
+  const gchar * getAbiSectionProps() const
   {
-    return reinterpret_cast<const XML_Char *>(m_sectionProps.c_str());
+    return reinterpret_cast<const gchar *>(m_sectionProps.c_str());
   }
   
 private: 
 	
-  void parse (const XML_Char ** props)
+  void parse (const gchar ** props)
   {
-    const XML_Char * val = NULL;
+    const gchar * val = NULL;
     int propCtr = 0;
     double width = 0;
     double height = 0;
@@ -202,7 +202,7 @@ private:
   UT_String m_marginBottom;
   
   static const int MAX_PAGE_ATTS = 13; // 2*(width height orientation pagetype units page-scale) 0 
-  const XML_Char * m_pageAtts[MAX_PAGE_ATTS];
+  const gchar * m_pageAtts[MAX_PAGE_ATTS];
   UT_String m_sectionProps;
 }; // class OO_PageStyle
 
@@ -218,13 +218,13 @@ class OO_Style
 {
 public:
   
-  OO_Style (const XML_Char ** props, const PD_Style * pParentStyle, const bool bOpenDocument)
+  OO_Style (const gchar ** props, const PD_Style * pParentStyle, const bool bOpenDocument)
     : m_bColBreakBefore (false), m_bPageBreakBefore (false), m_pParentStyle (pParentStyle), m_bOpenDocument (bOpenDocument)
   {
     parse (props);
   }
 
-  OO_Style (const OO_Style * other, const XML_Char ** props, PD_Style * pParentStyle, const bool bOpenDocument)
+  OO_Style (const OO_Style * other, const gchar ** props, PD_Style * pParentStyle, const bool bOpenDocument)
     : m_bColBreakBefore (false), m_bPageBreakBefore (false), m_pParentStyle (pParentStyle), m_bOpenDocument (bOpenDocument)
   {
     if (other)
@@ -236,9 +236,9 @@ public:
   {
   }
   
-  const XML_Char * getAbiStyle () const
+  const gchar * getAbiStyle () const
   {
-    return reinterpret_cast<const XML_Char *>(m_styleProps.c_str());
+    return reinterpret_cast<const gchar *>(m_styleProps.c_str());
   }
   
   /*!
@@ -255,31 +255,31 @@ public:
     return m_bPageBreakBefore;
   }
 
-  void parse (const XML_Char ** props)
+  void parse (const gchar ** props)
   {
-    const XML_Char * val = NULL;
+    const gchar * val = NULL;
 
     val = UT_getAttribute ("fo:text-align", props);
     if (val)
-      if (!UT_strcmp(val, "end"))
+      if (!strcmp(val, "end"))
 	m_align = "text-align: right;";
-      else if (!UT_strcmp(val, "center"))
+      else if (!strcmp(val, "center"))
 	m_align = "text-align: center;";
-      else if (!UT_strcmp(val, "justify"))
+      else if (!strcmp(val, "justify"))
 	m_align = "text-align: justify;";
       else
 	m_align = "text-align: left;";
     
     val = UT_getAttribute ("fo:font-weight", props);
     if(val)
-      if (!UT_strcmp(val, "bold"))
+      if (!strcmp(val, "bold"))
 	m_fontWeight = "font-weight: bold;";
       else
 	m_fontWeight = "font-weight: normal;";
     
     val = UT_getAttribute("fo:font-style", props);
     if (val)
-      if (!UT_strcmp(val, "italic"))
+      if (!strcmp(val, "italic"))
 	m_fontStyle = "font-style: italic;";
       
     val = UT_getAttribute("fo:color", props);
@@ -305,7 +305,7 @@ public:
 	  }
       else if (dim == DIM_PERCENT && m_pParentStyle) {
         // calculate font-size based on parent's 
-        const XML_Char * parentFontSize = NULL;
+        const gchar * parentFontSize = NULL;
         double fontSize = 12;
 		if (m_pParentStyle->getProperty("font-size", parentFontSize)) {
           fontSize = atoi(parentFontSize) * atoi(val) / 100.0;
@@ -334,28 +334,28 @@ public:
 	m_textPos += "normal;";
     }
 
-	const XML_Char * undr = NULL;
-	const XML_Char * strk = NULL;
+	const gchar * undr = NULL;
+	const gchar * strk = NULL;
 	if (m_bOpenDocument) {
-		undr = const_cast<const XML_Char *>(UT_getAttribute("style:text-underline-style", props));
-		strk = const_cast<const XML_Char *>(UT_getAttribute("style:text-line-through-style", props));
+		undr = const_cast<const gchar *>(UT_getAttribute("style:text-underline-style", props));
+		strk = const_cast<const gchar *>(UT_getAttribute("style:text-line-through-style", props));
 	}
 	else {
-		undr = const_cast<const XML_Char *>(UT_getAttribute("style:text-underline", props));
-		strk = const_cast<const XML_Char *>(UT_getAttribute("style:text-crossing-out", props));
+		undr = const_cast<const gchar *>(UT_getAttribute("style:text-underline", props));
+		strk = const_cast<const gchar *>(UT_getAttribute("style:text-crossing-out", props));
 	}
 	if (undr || strk) {
 		m_textDecoration = "text-decoration: ";
 		
 		if(undr)
-		  if (UT_strcmp(undr, "none") != 0)
+		  if (strcmp(undr, "none") != 0)
 		    m_textDecoration += "underline";
 		
 		if (undr && strk)
 		  m_textDecoration += ",";
 		
 		if(strk)
-		  if (UT_strcmp(strk, "none") != 0)
+		  if (strcmp(strk, "none") != 0)
 		    m_textDecoration += "line-through";
 		
 		  m_textDecoration += ";";
@@ -395,11 +395,11 @@ public:
     
     val = UT_getAttribute("fo:keep-with-next", props);
     if (val)
-      m_keepWithNext = UT_String_sprintf ("keep-with-next: %s;", !UT_strcmp(val, "true") ? "yes" : "no");
+      m_keepWithNext = UT_String_sprintf ("keep-with-next: %s;", !strcmp(val, "true") ? "yes" : "no");
     
     val = UT_getAttribute("style:break-inside", props);
     if (val)
-      m_keepTogether = UT_String_sprintf ("keep-together: %s;", !UT_strcmp(val, "avoid") ? "yes" : "no" );
+      m_keepTogether = UT_String_sprintf ("keep-together: %s;", !strcmp(val, "avoid") ? "yes" : "no" );
     
     val = UT_getAttribute("fo:widows", props);
     if (val) {
@@ -511,9 +511,9 @@ public:
 
   GsfInfile * getOO () const { return m_oo; }
 
-  void defineSimpleStyle (const UT_UTF8String & name, const XML_Char **props);
-  const XML_Char* mapStyle (const XML_Char * name) const;
-  const OO_Style * mapStyleObj (const XML_Char * name) const;
+  void defineSimpleStyle (const UT_UTF8String & name, const gchar **props);
+  const gchar* mapStyle (const gchar * name) const;
+  const OO_Style * mapStyleObj (const gchar * name) const;
   OpenWriter_StylesStream_Listener * m_pSSListener;
 
 protected:
@@ -550,7 +550,7 @@ IE_Imp_OpenWriter_Sniffer::~IE_Imp_OpenWriter_Sniffer ()
 static IE_SuffixConfidence IE_Imp_OpenWriter_Sniffer__SuffixConfidence[] = {
 	{ "stw", 	UT_CONFIDENCE_PERFECT 	},
 	{ "sxw", 	UT_CONFIDENCE_PERFECT 	},
-	{ NULL, 	UT_CONFIDENCE_ZILCH 	}
+	{ "", 	UT_CONFIDENCE_ZILCH 	}
 };
 
 const IE_SuffixConfidence * IE_Imp_OpenWriter_Sniffer::getSuffixConfidence ()
@@ -582,8 +582,8 @@ UT_Confidence_t IE_Imp_OpenWriter_Sniffer::recognizeContents (GsfInput * input)
 										gsf_input_size (pInput));
 					}
 
-					if ((UT_strcmp("application/vnd.sun.xml.writer", mimetype.utf8_str()) == 0) ||
-						(UT_strcmp("application/vnd.sun.xml.writer.template", mimetype.utf8_str()) == 0))
+					if ((strcmp("application/vnd.sun.xml.writer", mimetype.utf8_str()) == 0) ||
+						(strcmp("application/vnd.sun.xml.writer.template", mimetype.utf8_str()) == 0))
 						confidence = UT_CONFIDENCE_PERFECT;
 
 					g_object_unref (G_OBJECT (pInput));
@@ -618,7 +618,7 @@ bool IE_Imp_OpenWriter_Sniffer::getDlgLabels (const char ** szDesc,
   return true;
 }
 
-void IE_Imp_OpenWriter::defineSimpleStyle (const UT_UTF8String & name, const XML_Char **props)
+void IE_Imp_OpenWriter::defineSimpleStyle (const UT_UTF8String & name, const gchar **props)
 {
   if (!name.size() || !props)
     return;
@@ -627,7 +627,7 @@ void IE_Imp_OpenWriter::defineSimpleStyle (const UT_UTF8String & name, const XML
   m_styleBucket.insert (name.utf8_str(), style);
 }
 
-const XML_Char* IE_Imp_OpenWriter::mapStyle (const XML_Char * name) const
+const gchar* IE_Imp_OpenWriter::mapStyle (const gchar * name) const
 {
   OO_Style * style = m_styleBucket.pick((const char *)name);
   if (NULL == style)
@@ -635,7 +635,7 @@ const XML_Char* IE_Imp_OpenWriter::mapStyle (const XML_Char * name) const
   return style->getAbiStyle (); 
 }
 
-const OO_Style * IE_Imp_OpenWriter::mapStyleObj (const XML_Char * name) const
+const OO_Style * IE_Imp_OpenWriter::mapStyleObj (const gchar * name) const
 {
   if (!name)
     return NULL;
@@ -649,7 +649,7 @@ const OO_Style * IE_Imp_OpenWriter::mapStyleObj (const XML_Char * name) const
  * Create a new OpenWriter importer object
  */
 IE_Imp_OpenWriter::IE_Imp_OpenWriter (PD_Document * pDocument)
-  : IE_Imp (pDocument), m_oo (0), m_pSSListener(0), m_bOpenDocument(false)
+  : IE_Imp (pDocument), m_pSSListener(0), m_oo (0), m_bOpenDocument(false)
 {
 }
 
@@ -830,27 +830,27 @@ public:
   {
   }
   
-  virtual void startElement (const XML_Char * name, const XML_Char ** atts) 
+  virtual void startElement (const gchar * name, const gchar ** atts) 
   {
     mCharData.clear ();
     mAttrib.clear ();
     
-    if (!UT_strcmp (name, "meta:user-defined"))
+    if (!strcmp (name, "meta:user-defined"))
 	{
-	  const XML_Char * attrib = UT_getAttribute ("meta:name", atts);
+	  const gchar * attrib = UT_getAttribute ("meta:name", atts);
 	  if (attrib != NULL)
 	    mAttrib = attrib;
 	}
   }
   
-  virtual void endElement (const XML_Char * name)
+  virtual void endElement (const gchar * name)
   {
     if (mCharData.size()) {
-      if (!UT_strcmp (name, "dc:language"))
+      if (!strcmp (name, "dc:language"))
 	getDocument()->setMetaDataProp (PD_META_KEY_LANGUAGE, mCharData);
-      else if (!UT_strcmp (name, "dc:date"))
+      else if (!strcmp (name, "dc:date"))
 	getDocument()->setMetaDataProp (PD_META_KEY_DATE, mCharData);
-      else if (!UT_strcmp (name, "meta:user-defined"))
+      else if (!strcmp (name, "meta:user-defined"))
 	if (mAttrib.size())
 	  getDocument()->setMetaDataProp (mAttrib.utf8_str(), mCharData);
     }
@@ -858,7 +858,7 @@ public:
     mAttrib.clear ();
   }
   
-  virtual void charData (const XML_Char * buffer, int length)
+  virtual void charData (const gchar * buffer, int length)
   {
     if (buffer && length)      
       mCharData += UT_String (buffer, length).c_str();
@@ -877,8 +877,6 @@ private:
 UT_Error IE_Imp_OpenWriter::_handleMimetype ()
 {
   UT_Error err = UT_OK;
-  guint8 const *data = NULL;
-  size_t len = 0;
 
   GsfInput * input = gsf_infile_child_by_name(m_oo, "mimetype");
 
@@ -893,8 +891,8 @@ UT_Error IE_Imp_OpenWriter::_handleMimetype ()
     mimetype.append((const char *)gsf_input_read(input, gsf_input_size (input), NULL), gsf_input_size (input));
   }
   
-  if (UT_strcmp("application/vnd.sun.xml.writer", mimetype.utf8_str()) &&
-   UT_strcmp("application/vnd.sun.xml.writer.template", mimetype.utf8_str()))
+  if (strcmp("application/vnd.sun.xml.writer", mimetype.utf8_str()) &&
+   strcmp("application/vnd.sun.xml.writer.template", mimetype.utf8_str()))
   {
 	UT_DEBUGMSG(("*** Unknown mimetype '%s'\n", mimetype.utf8_str()));  
     err = UT_ERROR;
@@ -931,15 +929,15 @@ public:
   {
   }
 
-  virtual void startElement (const XML_Char * name, const XML_Char ** atts) 
+  virtual void startElement (const gchar * name, const gchar ** atts) 
   {
   }
 
-  virtual void endElement (const XML_Char * name)
+  virtual void endElement (const gchar * name)
   {
   }
 
-  virtual void charData (const XML_Char * buffer, int length)
+  virtual void charData (const gchar * buffer, int length)
   {
   }
   
@@ -984,19 +982,19 @@ public:
       return *name;
   }
   
-  virtual void startElement (const XML_Char * name, const XML_Char ** atts) 
+  virtual void startElement (const gchar * name, const gchar ** atts) 
   {
 	/* SXW || ODT */
-    if (!UT_strcmp (name, "style:page-master") || !UT_strcmp (name, "style:page-layout")) {
+    if (!strcmp (name, "style:page-master") || !strcmp (name, "style:page-layout")) {
       m_pageMaster = UT_getAttribute("style:name", atts);
     }
-    else if (!UT_strcmp (name, "style:master-page")) {
-      const XML_Char * masterName = UT_getAttribute("style:page-master-name", atts);
-      const XML_Char ** pageAtts = m_ooPageStyle.getAbiPageAtts(masterName);
+    else if (!strcmp (name, "style:master-page")) {
+      const gchar * masterName = UT_getAttribute("style:page-master-name", atts);
+      const gchar ** pageAtts = m_ooPageStyle.getAbiPageAtts(masterName);
       getDocument()->setPageSizeFromFile(pageAtts);
     }
     else if (!strcmp (name, "style:style")) {
-      const XML_Char * attr = NULL;
+      const gchar * attr = NULL;
 
       attr = UT_getAttribute("style:name",atts);
       if (attr)
@@ -1009,7 +1007,7 @@ public:
       if (m_name != "Standard") {
 	attr = UT_getAttribute("style:parent-style-name",atts);
 	if (attr) {
-	  if (!UT_strcmp(attr, "Standard")) {
+	  if (!strcmp(attr, "Standard")) {
 	    m_parent = "Normal";
 	  } else {
 	    m_parent = attr;
@@ -1018,7 +1016,7 @@ public:
 	
 	attr = UT_getAttribute("style:next-style-name",atts);
 	if (attr) {
-	  if (!UT_strcmp(attr, "Standard")) {
+	  if (!strcmp(attr, "Standard")) {
 	    m_next = "Normal";
 	  } else {
 	    m_next = attr;
@@ -1060,16 +1058,16 @@ public:
     }
   } 
 
-  virtual void endElement (const XML_Char * name)
+  virtual void endElement (const gchar * name)
   {
-    if (!UT_strcmp (name, "style:page-master")) {
+    if (!strcmp (name, "style:page-master")) {
       m_pageMaster = NULL;
     }
     else if (!strcmp (name, "style:style")) {
       if (m_name.size ()) {
 	int propCtr = 0;
 	
-	const XML_Char * atts[11];
+	const gchar * atts[11];
 	atts[propCtr++] = "type";
 	atts[propCtr++] = (m_type == PARAGRAPH ? "P" : "C");
 
@@ -1112,13 +1110,13 @@ public:
     }
   }
   
-  virtual void charData (const XML_Char * buffer, int length)
+  virtual void charData (const gchar * buffer, int length)
   {
   }  
 
-  const XML_Char * getSectionProps() const 
+  const gchar * getSectionProps() const 
   {
-    if (!UT_strcmp (m_ooPageStyle.getName(), "")) 
+    if (!strcmp (m_ooPageStyle.getName(), "")) 
     {
       UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
       return NULL;
@@ -1136,7 +1134,7 @@ private:
   OO_Style *m_ooStyle;
   PD_Style *m_pParentStyle;
   OO_PageStyle m_ooPageStyle;
-  const XML_Char * m_pageMaster;
+  const gchar * m_pageMaster;
   const bool m_bOpenDocument;
 
   UT_GenericStringMap<UT_UTF8String *> m_styleNameMap;
@@ -1171,7 +1169,7 @@ private:
 
   UT_UTF8String m_curStyleName;
 
-  UT_GenericVector<XML_Char*>	m_vecInlineFmt;
+  UT_GenericVector<gchar*>	m_vecInlineFmt;
   UT_NumberStack		m_stackFmtStartIndex;
   const OpenWriter_StylesStream_Listener * m_pSSListener;
 
@@ -1194,23 +1192,23 @@ public:
   {
   }
 
-  virtual void startElement (const XML_Char * name, const XML_Char ** atts) 
+  virtual void startElement (const gchar * name, const gchar ** atts) 
   {
     // if we're inside a TOC, ignore the contents since SXW/ODT include a copy of the TOC
     if (m_bInTOC)
       return;
 
-    if (!UT_strcmp(name, "office:body"))
+    if (!strcmp(name, "office:body"))
       {
       }
-    else if (!UT_strcmp(name, "text:section" ))
+    else if (!strcmp(name, "text:section" ))
       {	
-	const XML_Char * oo_sty = UT_getAttribute ("text:style-name", atts);
-	const XML_Char * abi_sty = _mapStyle(oo_sty);
+	const gchar * oo_sty = UT_getAttribute ("text:style-name", atts);
+	const gchar * abi_sty = _mapStyle(oo_sty);
 
 	_insureInSection(abi_sty);
       }
-    else if (!UT_strcmp(name, "text:p" ) || !UT_strcmp(name, "text:h" ))
+    else if (!strcmp(name, "text:p" ) || !strcmp(name, "text:h" ))
       {
 	UT_UTF8String oo_sty;
 	const OO_Style * abi_sty = _mapStyleObj (UT_getAttribute ("text:style-name", atts), oo_sty);
@@ -1223,33 +1221,33 @@ public:
 	    getDocument()->appendSpan (&ucs, 1);
 	  }
 	  
-	  const XML_Char * props[3];
+	  const gchar * props[3];
 	  props[0] = "props";
 	  props[1] = abi_sty->getAbiStyle ();
 	  props[2] = 0;
 	  
-	  _insureInBlock((const XML_Char **)props);
+	  _insureInBlock((const gchar **)props);
 	}
 	else if (oo_sty.size()) {
-	  const XML_Char * props[3];
+	  const gchar * props[3];
 	  props[0] = "style";
 	  props[1] = oo_sty.utf8_str();
 	  props[2] = 0;
 
-	  _insureInBlock((const XML_Char **)props);
+	  _insureInBlock((const gchar **)props);
 	}
 	else
 	  _insureInBlock(NULL);
 	m_bAcceptingText = true;
       }
-    else if (!UT_strcmp(name, "text:span"))
+    else if (!strcmp(name, "text:span"))
       {
 	_flush ();
 
-	const XML_Char * oo_sty = UT_getAttribute ("text:style-name", atts);
-	const XML_Char * abi_sty = _mapStyle(oo_sty);
+	const gchar * oo_sty = UT_getAttribute ("text:style-name", atts);
+	const gchar * abi_sty = _mapStyle(oo_sty);
 
-	const XML_Char * props[3];
+	const gchar * props[3];
 
 	if(abi_sty && *abi_sty) {
 	  props[0] = "props";
@@ -1262,19 +1260,19 @@ public:
 	_pushInlineFmt(props);
 	getDocument()->appendFmt(&m_vecInlineFmt);
       }
-    else if (!UT_strcmp(name, "text:line-break"))
+    else if (!strcmp(name, "text:line-break"))
       {
 	m_charData += UCS_LF;
 	_flush ();
       }
-    else if (!UT_strcmp(name, "text:ordered-list") || !UT_strcmp(name, "text:unordered-list"))
+    else if (!strcmp(name, "text:ordered-list") || !strcmp(name, "text:unordered-list"))
       {
-	const XML_Char * list_atts[15];
+	const gchar * list_atts[15];
 	UT_uint32 iOffset = 0;
 
 	// list type
 	list_atts[iOffset++] = "type";
-	if (!UT_strcmp(name, "text:ordered-list"))
+	if (!strcmp(name, "text:ordered-list"))
 	  list_atts[iOffset++] = "Numbered List";
 	else
 	  list_atts[iOffset++] = "Bullet List";
@@ -1289,35 +1287,35 @@ public:
 
 	UT_DEBUGMSG(("DOM: appended a list\n"));
       }
-    else if (!UT_strcmp(name, "style:style"))
+    else if (!strcmp(name, "style:style"))
       {
 	m_curStyleName.clear ();
 	m_curStyleName = UT_getAttribute ("style:name", atts);
       }
     else if (/* SXW */
-			!UT_strcmp(name, "style:properties") || 
-			!UT_strcmp(name, "style:columns") ||
+			!strcmp(name, "style:properties") || 
+			!strcmp(name, "style:columns") ||
 			/* ODT */
-			!UT_strcmp(name, "style:text-properties"))
+			!strcmp(name, "style:text-properties"))
       {
 	_defineSimpleStyle (atts);
       }
-    else if (!UT_strcmp(name, "text:a"))
+    else if (!strcmp(name, "text:a"))
       {
-	const XML_Char * xlink_atts[3];
+	const gchar * xlink_atts[3];
 	xlink_atts[0] = "xlink:href";
 	xlink_atts[1] = UT_getAttribute("xlink:href", atts);
 	xlink_atts[2] = 0;
 	getDocument()->appendObject(PTO_Hyperlink, xlink_atts);
       }
-    else if (!UT_strcmp(name, "text:bookmark"))
+    else if (!strcmp(name, "text:bookmark"))
     {
       _flush ();
-      const XML_Char * name = UT_getAttribute ("text:name", atts);
+      const gchar * name = UT_getAttribute ("text:name", atts);
       _insertBookmark (name, "start");
       _insertBookmark (name, "end");
     }
-    else if (!UT_strcmp(name, "text:table-of-content"))
+    else if (!strcmp(name, "text:table-of-content"))
     {
       _flush ();
       _insureInBlock(NULL);
@@ -1327,147 +1325,147 @@ public:
 
       m_bInTOC = true;
     }
-    else if (!UT_strcmp(name, "draw:image"))
+    else if (!strcmp(name, "draw:image"))
       {
 	_flush ();
 	_insureInBlock(NULL);
 	_insertImage (atts);
       }
-    else if (!UT_strcmp(name, "table:table"))
+    else if (!strcmp(name, "table:table"))
       {
 	_insureInSection(NULL);
 	_openTable (atts);
       }
-    else if (!UT_strcmp(name, "table:table-column"))
+    else if (!strcmp(name, "table:table-column"))
       {
 	_openColumn (atts);
       }
-    else if (!UT_strcmp(name, "table:table-row"))
+    else if (!strcmp(name, "table:table-row"))
       {
 	_openRow (atts);
       }
-    else if (!UT_strcmp(name, "table:table-cell"))
+    else if (!strcmp(name, "table:table-cell"))
       {
 	_openCell (atts);
       }
-    else if (!UT_strcmp(name, "text:date") ||
-	     !UT_strcmp(name, "text:time") || 
-	     !UT_strcmp(name, "text:page-number") ||
-	     !UT_strcmp(name, "text:page-count") || 
-	     !UT_strcmp(name, "text:file-name") ||
-	     !UT_strcmp(name, "text:paragraph-count") ||
-	     !UT_strcmp(name, "text:word-count") ||
-	     !UT_strcmp(name, "text:character-count") ||
-	     !UT_strcmp(name, "text:initial-creator") ||
-	     !UT_strcmp(name, "text:author-name") ||
-	     !UT_strcmp(name, "text:description") ||
-	     !UT_strcmp(name, "text:keywords") ||
-	     !UT_strcmp(name, "text:subject") ||
-	     !UT_strcmp(name, "text:title"))
+    else if (!strcmp(name, "text:date") ||
+	     !strcmp(name, "text:time") || 
+	     !strcmp(name, "text:page-number") ||
+	     !strcmp(name, "text:page-count") || 
+	     !strcmp(name, "text:file-name") ||
+	     !strcmp(name, "text:paragraph-count") ||
+	     !strcmp(name, "text:word-count") ||
+	     !strcmp(name, "text:character-count") ||
+	     !strcmp(name, "text:initial-creator") ||
+	     !strcmp(name, "text:author-name") ||
+	     !strcmp(name, "text:description") ||
+	     !strcmp(name, "text:keywords") ||
+	     !strcmp(name, "text:subject") ||
+	     !strcmp(name, "text:title"))
     {
       _flush ();
 
-      const XML_Char * type = "";
-      if(!UT_strcmp(name, "text:date"))
+      const gchar * type = "";
+      if(!strcmp(name, "text:date"))
 	type = "date_ddmmyy";
-      else if(!UT_strcmp(name, "text:time"))
+      else if(!strcmp(name, "text:time"))
 	type = "time";
-      else if(!UT_strcmp(name, "text:page-number"))
+      else if(!strcmp(name, "text:page-number"))
 	type = "page_number";
-      else if(!UT_strcmp(name, "text:page-count"))
+      else if(!strcmp(name, "text:page-count"))
 	type = "page_count";
-      else if(!UT_strcmp(name, "text:file-name"))
+      else if(!strcmp(name, "text:file-name"))
 	type = "file_name";
-      else if(!UT_strcmp(name, "text:paragraph-count"))
+      else if(!strcmp(name, "text:paragraph-count"))
 	type = "para_count";
-      else if(!UT_strcmp(name, "text:word-count"))
+      else if(!strcmp(name, "text:word-count"))
 	type = "word_count";
-      else if(!UT_strcmp(name, "text:character-count"))
+      else if(!strcmp(name, "text:character-count"))
 	type = "char_count";
-      else if(!UT_strcmp(name, "text:initial-creator") || !UT_strcmp(name, "text:author-name"))
+      else if(!strcmp(name, "text:initial-creator") || !strcmp(name, "text:author-name"))
 	type = "meta_creator";
-      else if(!UT_strcmp(name, "text:description"))
+      else if(!strcmp(name, "text:description"))
 	type = "meta_description";
-      else if(!UT_strcmp(name, "text:keywords"))
+      else if(!strcmp(name, "text:keywords"))
 	type = "meta_keywords";
-      else if(!UT_strcmp(name, "text:subject"))
+      else if(!strcmp(name, "text:subject"))
 	type = "meta_subject";
-      else if(!UT_strcmp(name, "text:title"))
+      else if(!strcmp(name, "text:title"))
 	type = "meta_title";
 
-      const XML_Char *field_fmt[3];
+      const gchar *field_fmt[3];
       field_fmt[0] = "type";
       field_fmt[1] = type;
       field_fmt[2] = 0;
-      getDocument()->appendObject(PTO_Field, (const XML_Char**)field_fmt);
+      getDocument()->appendObject(PTO_Field, (const gchar**)field_fmt);
       m_bAcceptingText = false;
     }
   }
 
-  virtual void endElement (const XML_Char * name)
+  virtual void endElement (const gchar * name)
   {
-    if (!UT_strcmp(name, "text:section" ))
+    if (!strcmp(name, "text:section" ))
       {
 	m_bInSection = false;
       }
-    else if (!UT_strcmp(name, "text:p" ) || !UT_strcmp(name, "text:h" ))
+    else if (!strcmp(name, "text:p" ) || !strcmp(name, "text:h" ))
       {
 	_flush ();
 	m_bAcceptingText = false;
       }
-    else if (!UT_strcmp(name, "text:span"))
+    else if (!strcmp(name, "text:span"))
       {
 	_flush ();
 	_popInlineFmt();
 	getDocument()->appendFmt(&m_vecInlineFmt);
       }
-    else if (!UT_strcmp(name, "text:ordered-list") || !UT_strcmp(name, "text:unordered-list"))
+    else if (!strcmp(name, "text:ordered-list") || !strcmp(name, "text:unordered-list"))
       {
       }
-    else if (!UT_strcmp(name, "text:a"))
+    else if (!strcmp(name, "text:a"))
       {
 	_flush ();
 	getDocument()->appendObject(PTO_Hyperlink, NULL);
       }
-    else if (!UT_strcmp(name, "text:table-of-content")) {
+    else if (!strcmp(name, "text:table-of-content")) {
       m_bInTOC = false;
     }
-    else if (!UT_strcmp(name, "table:table"))
+    else if (!strcmp(name, "table:table"))
       {
 	_closeTable ();
       }
-    else if (!UT_strcmp(name, "table:table-column"))
+    else if (!strcmp(name, "table:table-column"))
       {
 	_closeColumn ();
       }
-    else if (!UT_strcmp(name, "table:table-row"))
+    else if (!strcmp(name, "table:table-row"))
       {
 	_closeRow ();
       }
-    else if (!UT_strcmp(name, "table:table-cell"))
+    else if (!strcmp(name, "table:table-cell"))
       {
 	_closeCell ();
       }
-    else if (!UT_strcmp(name, "text:date") ||
-	     !UT_strcmp(name, "text:time") || 
-	     !UT_strcmp(name, "text:page-number") ||
-	     !UT_strcmp(name, "text:page-count") || 
-	     !UT_strcmp(name, "text:file-name") ||
-	     !UT_strcmp(name, "text:paragraph-count") ||
-	     !UT_strcmp(name, "text:word-count") ||
-	     !UT_strcmp(name, "text:character-count") ||
-	     !UT_strcmp(name, "text:initial-creator") ||
-	     !UT_strcmp(name, "text:author-name") ||
-	     !UT_strcmp(name, "text:description") ||
-	     !UT_strcmp(name, "text:keywords") ||
-	     !UT_strcmp(name, "text:subject") ||
-	     !UT_strcmp(name, "text:title"))
+    else if (!strcmp(name, "text:date") ||
+	     !strcmp(name, "text:time") || 
+	     !strcmp(name, "text:page-number") ||
+	     !strcmp(name, "text:page-count") || 
+	     !strcmp(name, "text:file-name") ||
+	     !strcmp(name, "text:paragraph-count") ||
+	     !strcmp(name, "text:word-count") ||
+	     !strcmp(name, "text:character-count") ||
+	     !strcmp(name, "text:initial-creator") ||
+	     !strcmp(name, "text:author-name") ||
+	     !strcmp(name, "text:description") ||
+	     !strcmp(name, "text:keywords") ||
+	     !strcmp(name, "text:subject") ||
+	     !strcmp(name, "text:title"))
     {
       m_bAcceptingText = true;
     }
   }
 
-  virtual void charData (const XML_Char * buffer, int length)
+  virtual void charData (const gchar * buffer, int length)
   {
     if (buffer && length && m_bAcceptingText && !m_bInTOC)
       m_charData += UT_UCS4String (buffer, length, true);
@@ -1475,12 +1473,12 @@ public:
 
 private:
 
-  void _insertImage (const XML_Char ** atts)
+  void _insertImage (const gchar ** atts)
   {
     UT_Error error		= UT_OK;
-    const XML_Char * width  = UT_getAttribute ("svg:width", atts);
-    const XML_Char * height = UT_getAttribute ("svg:height", atts);
-    const XML_Char * href   = UT_getAttribute ("xlink:href", atts);
+    const gchar * width  = UT_getAttribute ("svg:width", atts);
+    const gchar * height = UT_getAttribute ("svg:height", atts);
+    const gchar * href   = UT_getAttribute ("xlink:href", atts);
 
     if (width == NULL || height == NULL || href == NULL)
         return; //don't crash on invalid images
@@ -1505,7 +1503,7 @@ private:
     if (error != UT_OK)
       return;
 
-    const char * mimetype 	= UT_strdup ("image/png");
+    const char * mimetype 	= g_strdup ("image/png");
     FG_Graphic* pFG		= 0;
     UT_ByteBuf * pictData       = 0;
     
@@ -1538,11 +1536,11 @@ private:
     UT_String_sprintf(propBuffer, "width:%s; height:%s", width, height);    
     UT_String_sprintf(propsName, "image%d", m_imgCnt);
 
-    const XML_Char* propsArray[5];
-    propsArray[0] = (XML_Char *)"props";
-    propsArray[1] = (XML_Char *)propBuffer.c_str();
-    propsArray[2] = (XML_Char *)"dataid";
-    propsArray[3] = (XML_Char *)propsName.c_str();
+    const gchar* propsArray[5];
+    propsArray[0] = (gchar *)"props";
+    propsArray[1] = (gchar *)propBuffer.c_str();
+    propsArray[2] = (gchar *)"dataid";
+    propsArray[3] = (gchar *)propsName.c_str();
     propsArray[4] = 0;
     
     if (!getDocument()->appendObject (PTO_Image, propsArray))
@@ -1559,7 +1557,7 @@ private:
     
   }
 
-  void _insureInBlock(const XML_Char ** atts)
+  void _insureInBlock(const gchar ** atts)
   {
     if (m_bAcceptingText)
       return;
@@ -1567,12 +1565,12 @@ private:
     _insureInSection(NULL);
 
     if (!m_bAcceptingText) {
-      getDocument()->appendStrux(PTX_Block, (const XML_Char**)atts);	
+      getDocument()->appendStrux(PTX_Block, (const gchar**)atts);	
       m_bAcceptingText = true;
     }
   }
 
-  void _insureInSection(const XML_Char * props) 
+  void _insureInSection(const gchar * props) 
   {
     if (m_bInSection)
       return;
@@ -1580,22 +1578,22 @@ private:
     UT_String allProps(props);
     allProps += m_pSSListener->getSectionProps();
 
-    const XML_Char * atts[3];
+    const gchar * atts[3];
     atts[0] = "props";
     atts[1] = allProps.c_str();
     atts[2] = 0;
-    getDocument()->appendStrux(PTX_Section, (const XML_Char**)atts);	
+    getDocument()->appendStrux(PTX_Section, (const gchar**)atts);	
 
     m_bInSection = true;
     m_bAcceptingText = false;
   }
   
-  void _insertBookmark (const XML_Char * name, const XML_Char * type)
+  void _insertBookmark (const gchar * name, const gchar * type)
     {
-	const XML_Char* propsArray[5];
-	propsArray[0] = (XML_Char *)"name";
+	const gchar* propsArray[5];
+	propsArray[0] = (gchar *)"name";
 	propsArray[1] = name;
-	propsArray[2] = (XML_Char *)"type";
+	propsArray[2] = (gchar *)"type";
 	propsArray[3] = type;
 	propsArray[4] = 0;
 	getDocument()->appendObject (PTO_Bookmark, propsArray);
@@ -1610,22 +1608,22 @@ private:
       }	
   }
 
-  void _openTable (const XML_Char ** props)
+  void _openTable (const gchar ** props)
   {
     getDocument()->appendStrux(PTX_SectionTable,NULL);
   }
 
-  void _openColumn (const XML_Char ** props)
+  void _openColumn (const gchar ** props)
   {
     m_col++;
   }
 
-  void _openRow (const XML_Char ** props)
+  void _openRow (const gchar ** props)
   {
     m_row++; m_cel = 0;
   }
 
-  void _openCell (const XML_Char ** props)
+  void _openCell (const gchar ** props)
   {
     UT_String attach;
 
@@ -1633,7 +1631,7 @@ private:
 
     m_cel++;
 
-    const XML_Char *cell_props[3];
+    const gchar *cell_props[3];
     cell_props[0] = "props";
     cell_props[1] = attach.c_str();
     cell_props[2] = 0;
@@ -1663,32 +1661,32 @@ private:
     getDocument()->appendStrux(PTX_EndCell,NULL);
   }
   
-  void _defineSimpleStyle (const XML_Char **props)
+  void _defineSimpleStyle (const gchar **props)
   {
     getImporter ()->defineSimpleStyle (m_curStyleName, props);
   }
 
-  const XML_Char* _mapStyle (const XML_Char * name) const
+  const gchar* _mapStyle (const gchar * name) const
   {
     UT_UTF8String styleName = m_pSSListener->getStyleName(name);
     return getImporter ()->mapStyle(styleName.utf8_str());
   }
 
-  const OO_Style * _mapStyleObj (const XML_Char * name, UT_UTF8String & oo_sty) const
+  const OO_Style * _mapStyleObj (const gchar * name, UT_UTF8String & oo_sty) const
   {
     oo_sty = m_pSSListener->getStyleName(name);
     return getImporter ()->mapStyleObj (oo_sty.utf8_str());
   }
 
-  bool _pushInlineFmt(const XML_Char ** atts)
+  bool _pushInlineFmt(const gchar ** atts)
   {
     UT_uint32 start = m_vecInlineFmt.getItemCount()+1;
     UT_uint32 k;
     
     for (k=0; (atts[k]); k++)
       {
-	XML_Char * p;
-	if (!UT_XML_cloneString(p,atts[k]))
+	gchar * p;
+	if (!(p = g_strdup(atts[k])))
 	  return false;
 	if (m_vecInlineFmt.addItem(p)!=0)
 	  return false;
@@ -1707,7 +1705,7 @@ private:
     UT_uint32 end = m_vecInlineFmt.getItemCount();
     for (k=end; k>=start; k--)
       {
-	const XML_Char * p = (const XML_Char *)m_vecInlineFmt.getNthItem(k-1);
+	const gchar * p = (const gchar *)m_vecInlineFmt.getNthItem(k-1);
 	m_vecInlineFmt.deleteNthItem(k-1);
 	if (p)
 	  free((void *)p);
