@@ -51,7 +51,7 @@ IE_Imp_DocBook_Sniffer::IE_Imp_DocBook_Sniffer (const char * name) :
 static IE_SuffixConfidence IE_Imp_DocBook_Sniffer__SuffixConfidence[] = {
 	{ "dbk", 	UT_CONFIDENCE_PERFECT 	},
 	{ "xml", 	UT_CONFIDENCE_PERFECT 	},
-	{ NULL, 	UT_CONFIDENCE_ZILCH 	}
+	{ "", 	UT_CONFIDENCE_ZILCH 	}
 };
 
 const IE_SuffixConfidence * IE_Imp_DocBook_Sniffer::getSuffixConfidence ()
@@ -357,8 +357,8 @@ static struct xmlToIdMapping s_Tokens[] =
 /*****************************************************************/
 /*****************************************************************/
 
-void IE_Imp_DocBook::startElement(const XML_Char *name,
-				   const XML_Char **atts)
+void IE_Imp_DocBook::startElement(const gchar *name,
+				   const gchar **atts)
 {
 	UT_DEBUGMSG(("DocBook import: startElement: %s\n", name));
 
@@ -386,9 +386,9 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 		/* starts the document */
 		X_VerifyParseState(_PS_Init);
 		m_parseState = _PS_Doc;
-		X_CheckError(appendStrux(PTX_Section,static_cast<const XML_Char **>(NULL)));
+		X_CheckError(appendStrux(PTX_Section,static_cast<const gchar **>(NULL)));
 
-		const XML_Char ** condition = getCondition(atts);
+		const gchar ** condition = getCondition(atts);
 
 		if(condition)
 		{
@@ -436,28 +436,28 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 		m_iSectionDepth++;
 		m_iTitleDepth++;
 
-		const XML_Char *p_val = NULL;
-		p_val = _getXMLPropValue(static_cast<const XML_Char *>("role"), atts);
+		const gchar *p_val = NULL;
+		p_val = _getXMLPropValue(static_cast<const gchar *>("role"), atts);
 		m_bMustNumber = false;
 
 		if(!p_val)
 			break;
 
-		if(!UT_strcmp(p_val,"abi-frame"))
+		if(!strcmp(p_val,"abi-frame"))
 		{
-			const XML_Char ** condition = getCondition(atts);
+			const gchar ** condition = getCondition(atts);
 			X_CheckError(appendStrux(PTX_SectionFrame, condition));
 			DELETEPV(condition);
 
 			m_iTitleDepth--;
 			m_bInFrame = true;
 		}
-		else if(!UT_strcmp(p_val,"abi-toc"))
+		else if(!strcmp(p_val,"abi-toc"))
 		{
 			m_iTitleDepth--;
 			m_bInTOC = true;  //so we can ignore the TOC title
 		}
-		else if(!UT_strcmp(p_val,"numbered")) // for backward compatibility
+		else if(!strcmp(p_val,"numbered")) // for backward compatibility
 		{
 			m_bMustNumber = true;
 		}
@@ -751,7 +751,7 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 		{
 			m_parseState = _PS_Block;
 
-			const XML_Char ** condition = getCondition(atts);
+			const gchar ** condition = getCondition(atts);
 			X_CheckError(appendStrux(PTX_Block, condition));
 			DELETEPV(condition);
 
@@ -770,21 +770,21 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 		m_parseState = _PS_Block;
 		m_iBlockDepth++;
 
-		XML_Char *buf[3];
+		gchar *buf[3];
 		buf[2] = NULL;
 
-		const XML_Char *p_val = NULL;
-		p_val = _getXMLPropValue(static_cast<const XML_Char *>("renderas"), atts);
-		XML_Char style_att[10] = "Heading a";
+		const gchar *p_val = NULL;
+		p_val = _getXMLPropValue(static_cast<const gchar *>("renderas"), atts);
+		gchar style_att[10] = "Heading a";
 
 		if(p_val)
 		{
-			if(!UT_strcmp(p_val, "sect1") || !UT_strcmp(p_val, "sect2") || !UT_strcmp(p_val, "sect3") || !UT_strcmp(p_val, "sect4"))
+			if(!strcmp(p_val, "sect1") || !strcmp(p_val, "sect2") || !strcmp(p_val, "sect3") || !strcmp(p_val, "sect4"))
 			{
 				char num = p_val[4];
 				style_att[8] = num;
 			}
-			else if(!UT_strcmp(p_val, "sect5"))
+			else if(!strcmp(p_val, "sect5"))
 			{
 				char num = '4';
 				style_att[8] = num; // Heading 5 doesn't exist in AbiWord; use Heading 4 instead
@@ -803,8 +803,8 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 
 		X_CheckError(appendStrux(PTX_Block, NULL));
 		buf[0] = PT_STYLE_ATTRIBUTE_NAME;
-		buf[1] = UT_strdup(style_att);
-		X_CheckError(appendFmt(const_cast<const XML_Char **>(buf)));
+		buf[1] = g_strdup(style_att);
+		X_CheckError(appendFmt(const_cast<const gchar **>(buf)));
 		FREEP(buf[1]);
 
 		break;
@@ -851,13 +851,13 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 		m_parseState = _PS_Block;
 		m_iBlockDepth++;
 
-		XML_Char *buf[3];
+		gchar *buf[3];
 		buf[0] = PT_STYLE_ATTRIBUTE_NAME;
 		buf[1] = "Block Text";
 		buf[2] = NULL;
 
 		X_CheckError(appendStrux(PTX_Block, NULL));
-		X_CheckError(appendFmt(const_cast<const XML_Char **>(buf)));
+		X_CheckError(appendFmt(const_cast<const gchar **>(buf)));
 		break;
 	}
 
@@ -866,12 +866,12 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 		m_parseState = _PS_Block;
 		m_iBlockDepth++;
 
-		XML_Char *buf[3];
+		gchar *buf[3];
 		buf[0] = PT_STYLE_ATTRIBUTE_NAME;
 		buf[1] = "Plain Text";
 		buf[2] = NULL;
 
-		X_CheckError(appendStrux(PTX_Block, const_cast<const XML_Char **>(buf)));
+		X_CheckError(appendStrux(PTX_Block, const_cast<const gchar **>(buf)));
 		m_bWhiteSignificant = true;
 		break;
 	}
@@ -880,43 +880,49 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 	{
 		X_VerifyParseState(_PS_Block);
 
-		const XML_Char *p_val = NULL;
-		p_val = _getXMLPropValue(static_cast<const XML_Char *>("role"), atts);
+		const gchar *p_val = NULL;
+		p_val = _getXMLPropValue(static_cast<const gchar *>("role"), atts);
 
-		XML_Char *buf[5];
+		gchar *buf[7];
+		buf[0] = NULL;
+		buf[1] = NULL;
 		buf[2] = NULL;
 		buf[3] = NULL;
 		buf[4] = NULL;
+		buf[5] = NULL;
+		buf[6] = NULL;
 
 		if(p_val)
 		{
-			if(!UT_strcmp(p_val, "strong"))
+			if(!strcmp(p_val, "strong"))
 			{
 				buf[0] = PT_PROPS_ATTRIBUTE_NAME;
 				buf[1] = "font-weight:bold";
-				X_CheckError(_pushInlineFmt(const_cast<const XML_Char **>(buf)));
+				X_CheckError(_pushInlineFmt(const_cast<const gchar **>(buf)));
 				X_CheckError(appendFmt(&m_vecInlineFmt));
 				m_bWroteBold = true;
 			}
 			else  //possible field
 			{
-				if(!UT_strcmp(p_val, "footnote_ref"))
+				if(!strcmp(p_val, "footnote_ref"))
 				{
 					break; //handled with TT_FOOTNOTEREF
 				}
-				else if(!UT_strcmp(p_val, "footnote_anchor"))
+				else if(!strcmp(p_val, "footnote_anchor"))
 				{
 					X_CheckError(m_bInNote);
 					UT_UTF8String noteID;
 					UT_UTF8String_sprintf(noteID,"%i",m_iNoteID);
 
 					buf[2] = "footnote-id";
-					buf[3] = (XML_Char*)UT_strdup(noteID.utf8_str());
+					buf[3] = (gchar*)g_strdup(noteID.utf8_str());
+					buf[4] = PT_PROPS_ATTRIBUTE_NAME;
+					buf[5] = "text-position:superscript";
 				}
 				buf[0] = PT_TYPE_ATTRIBUTE_NAME;
-				buf[1] = (XML_Char*)p_val;
+				buf[1] = (gchar*)p_val;
 
-				X_CheckError(appendObject(PTO_Field,const_cast<const XML_Char **>(buf)));
+				X_CheckError(appendObject(PTO_Field,const_cast<const gchar **>(buf)));
 				m_parseState = _PS_Field;
 				FREEP(buf[3]);
 			}
@@ -931,8 +937,9 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 	{
 		X_VerifyParseState(_PS_Block);
 
-		XML_Char *buf[3];
+		gchar *buf[3];
 		buf[0] = PT_PROPS_ATTRIBUTE_NAME;
+		buf[1] = NULL;
 		buf[2] = NULL;
 
 		switch(tokenIndex)
@@ -947,11 +954,11 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 				buf[1] = "text-position:subscript";
 			    break;
 			default:
-				UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+				UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
 				break;
 		}
 		
-		X_CheckError(_pushInlineFmt(const_cast<const XML_Char **>(buf)));
+		X_CheckError(_pushInlineFmt(const_cast<const gchar **>(buf)));
 		X_CheckError(appendFmt(&m_vecInlineFmt));
 		break;
 	}
@@ -1011,7 +1018,7 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 		}
 		else
 		{
-			UT_ASSERT(UT_TODO);
+			UT_ASSERT_HARMLESS(UT_TODO);
 		}
 		break;
 	}
@@ -1034,21 +1041,21 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 
 	case TT_ULINK:  //an external link
 	{
-		XML_Char *buf[3];
+		gchar *buf[3];
 		buf[2] = NULL;
 
-		const XML_Char *p_val = NULL;
-		p_val = _getXMLPropValue(static_cast<const XML_Char *>("url"), atts);
+		const gchar *p_val = NULL;
+		p_val = _getXMLPropValue(static_cast<const gchar *>("url"), atts);
 
 		if(p_val)
 		{
 			buf[0] = "xlink:href";
-			buf[1] = (XML_Char*)p_val;
-			X_CheckError(appendObject(PTO_Hyperlink, const_cast<const XML_Char **>(buf)));
+			buf[1] = (gchar*)p_val;
+			X_CheckError(appendObject(PTO_Hyperlink, const_cast<const gchar **>(buf)));
 		}
 		else
 		{
-			UT_ASSERT(UT_TODO);
+			UT_ASSERT_HARMLESS(UT_TODO);
 		}
 
 		break;
@@ -1056,11 +1063,11 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 	
 	case TT_LINK:  //an internal link
 	{
-		XML_Char *buf[3];
+		gchar *buf[3];
 		buf[2] = NULL;
 
-		const XML_Char *p_val = NULL;
-		p_val = _getXMLPropValue(static_cast<const XML_Char *>("linkend"), atts);
+		const gchar *p_val = NULL;
+		p_val = _getXMLPropValue(static_cast<const gchar *>("linkend"), atts);
 
 		if(p_val)
 		{
@@ -1068,12 +1075,12 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 			link += p_val;
 
 			buf[0] = "xlink:href";
-			buf[1] = (XML_Char*)link.utf8_str();
-			X_CheckError(appendObject(PTO_Hyperlink, const_cast<const XML_Char **>(buf)));
+			buf[1] = (gchar*)link.utf8_str();
+			X_CheckError(appendObject(PTO_Hyperlink, const_cast<const gchar **>(buf)));
 		}
 		else
 		{
-			UT_ASSERT(UT_TODO);
+			UT_ASSERT_HARMLESS(UT_TODO);
 		}
 		break;
 	}
@@ -1089,25 +1096,25 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 	case TT_BOOKMARK:
 	{
 		X_VerifyParseState(_PS_Block);
-		XML_Char *buf[5];
+		gchar *buf[5];
 		buf[4] = NULL;
 
-		const XML_Char *p_val = NULL;
-		p_val = _getXMLPropValue(static_cast<const XML_Char *>("id"), atts);
+		const gchar *p_val = NULL;
+		p_val = _getXMLPropValue(static_cast<const gchar *>("id"), atts);
 
 		if(p_val)
 		{
 			buf[0] = PT_TYPE_ATTRIBUTE_NAME;
 			buf[1] = "start";
 			buf[2] = PT_NAME_ATTRIBUTE_NAME;
-			buf[3] = (XML_Char*)p_val;
-			X_CheckError(appendObject(PTO_Bookmark, const_cast<const XML_Char **>(buf)));
+			buf[3] = (gchar*)p_val;
+			X_CheckError(appendObject(PTO_Bookmark, const_cast<const gchar **>(buf)));
 			buf[1] = "end";
-			X_CheckError(appendObject(PTO_Bookmark, const_cast<const XML_Char **>(buf)));
+			X_CheckError(appendObject(PTO_Bookmark, const_cast<const gchar **>(buf)));
 		}
 		else
 		{
-			UT_ASSERT(UT_TODO);
+			UT_ASSERT_HARMLESS(UT_TODO);
 		}
 		break;
 	}
@@ -1119,32 +1126,34 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 		m_bInNote = true;
 		m_iFootnotes++;
 
-		XML_Char *buf[3];
+		gchar *buf[3];
 		UT_UTF8String noteID;
 
 		if(m_iNoteID == -1)
 		{
 			UT_UTF8String id;
 
-			XML_Char *ref[5];
-			ref[0] = PT_TYPE_ATTRIBUTE_NAME;
-			ref[1] = "footnote_ref";
 			m_iNoteID = m_iFootnotes;
 			UT_UTF8String_sprintf(id,"%i",m_iNoteID);
 
+			gchar *ref[7];
+			ref[0] = PT_TYPE_ATTRIBUTE_NAME;
+			ref[1] = "footnote_ref";
 			ref[2] = "footnote-id";
-			ref[3] = (XML_Char*)UT_strdup(id.utf8_str());
-			ref[4] = NULL;
-			X_CheckError(appendObject(PTO_Field,const_cast<const XML_Char **>(ref)));
+			ref[3] = (gchar*)g_strdup(id.utf8_str());
+			ref[4] = PT_PROPS_ATTRIBUTE_NAME;
+			ref[5] = "text-position:superscript";
+			ref[6] = NULL;
+			X_CheckError(appendObject(PTO_Field,const_cast<const gchar **>(ref)));
 			FREEP(ref[3]);
 		}
 
 		UT_UTF8String_sprintf(noteID,"%i",m_iNoteID);
 		buf[0] = "footnote-id";
-		buf[1] = (XML_Char*)UT_strdup(noteID.utf8_str());
+		buf[1] = (gchar*)g_strdup(noteID.utf8_str());
 		buf[2] = NULL;
 
-		X_CheckError(appendStrux(PTX_SectionFootnote,const_cast<const XML_Char **>(buf)));
+		X_CheckError(appendStrux(PTX_SectionFootnote,const_cast<const gchar **>(buf)));
 		FREEP(buf[1]);
 
 		break;
@@ -1155,12 +1164,17 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 		X_CheckError((m_parseState == _PS_Block) || (m_parseState == _PS_Field) || (m_parseState == _PS_Cell));
 		m_parseState = _PS_Field;
 
-		XML_Char *buf[5];
+		gchar *buf[7];
 		buf[0] = PT_TYPE_ATTRIBUTE_NAME;
 		buf[1] = "footnote_ref";
-		
-		const XML_Char *p_val = NULL;
-		p_val = _getXMLPropValue(static_cast<const XML_Char *>("linkend"), atts);
+		buf[2] = NULL;
+		buf[3] = NULL;
+		buf[4] = NULL;
+		buf[5] = NULL;
+		buf[6] = NULL;
+
+		const gchar *p_val = NULL;
+		p_val = _getXMLPropValue(static_cast<const gchar *>("linkend"), atts);
 
 		if(p_val)
 		{
@@ -1175,13 +1189,15 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 			m_iNoteID = atoi(p_val);
 
 			buf[2] = "footnote-id";
-			buf[3] = (XML_Char*)p_val;
-			buf[4] = NULL;
-			X_CheckError(appendObject(PTO_Field,const_cast<const XML_Char **>(buf)));
+			buf[3] = (gchar*)p_val;
+			buf[4] = PT_PROPS_ATTRIBUTE_NAME;
+			buf[5] = "text-position:superscript";
+			buf[6] = NULL;
+			X_CheckError(appendObject(PTO_Field,const_cast<const gchar **>(buf)));
 		}
 		else
 		{
-			UT_ASSERT(UT_TODO);
+			UT_ASSERT_HARMLESS(UT_TODO);
 		}
 		break;
 	}
@@ -1193,7 +1209,7 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 		X_VerifyParseState(_PS_Sec);
 		requireBlock();
 
-		const XML_Char ** condition = getCondition(atts);
+		const gchar ** condition = getCondition(atts);
 		X_CheckError(appendStrux(PTX_SectionTOC, condition));
 		DELETEPV(condition);
 
@@ -1225,7 +1241,7 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 
 	case TT_INDEXTERM:
 	{
-		UT_ASSERT(UT_TODO);
+		UT_ASSERT_HARMLESS(UT_TODO);
 		break;
 	}
 
@@ -1276,7 +1292,7 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 		m_parseState = _PS_Cell;
 
 		//TODO: handle non-abi cells
-		const XML_Char ** condition = getCondition(atts);
+		const gchar ** condition = getCondition(atts);
 		X_CheckError(appendStrux(PTX_SectionCell, condition));
 		DELETEPV(condition);
 
@@ -1286,10 +1302,10 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 	case TT_ENTRYTBL: //nested table
 	{
 		X_VerifyParseState(_PS_Table);
-		X_CheckError(appendStrux(PTX_SectionCell,static_cast<const XML_Char **>(NULL)));
+		X_CheckError(appendStrux(PTX_SectionCell,static_cast<const gchar **>(NULL)));
 		requireBlock();
 
-		const XML_Char ** condition = getCondition(atts);
+		const gchar ** condition = getCondition(atts);
 		X_CheckError(appendStrux(PTX_SectionTable, condition));
 		DELETEPV(condition);
 
@@ -1431,8 +1447,8 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 		m_parseState = _PS_DataItem;
 		m_iDataDepth++;
 
-		const XML_Char *p_val = NULL;
-		p_val = _getXMLPropValue(static_cast<const XML_Char *>("fileref"), atts);
+		const gchar *p_val = NULL;
+		p_val = _getXMLPropValue(static_cast<const gchar *>("fileref"), atts);
 
 		if(p_val)
 			createImage (p_val, atts);
@@ -1489,8 +1505,8 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 		m_parseState = _PS_DataItem;
 		m_iDataDepth++;
 
-		const XML_Char *p_val = NULL;
-		p_val = _getXMLPropValue(static_cast<const XML_Char *>("fileref"), atts);
+		const gchar *p_val = NULL;
+		p_val = _getXMLPropValue(static_cast<const gchar *>("fileref"), atts);
 
 		if(p_val)
 			createImage (p_val, atts);
@@ -1500,7 +1516,7 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 	  
 	case TT_OTHER:
 	default:
-		UT_ASSERT(UT_TODO);
+		UT_ASSERT_HARMLESS(UT_TODO);
 	    UT_DEBUGMSG(("Unknown or knowingly unhandled tag [%s]\n",name));
 	    break;
 	}
@@ -1512,7 +1528,7 @@ void IE_Imp_DocBook::startElement(const XML_Char *name,
 	}
 }
 
-void IE_Imp_DocBook::endElement(const XML_Char *name)
+void IE_Imp_DocBook::endElement(const gchar *name)
 {
   
     UT_DEBUGMSG(("DocBook import: endElement: %s\n", name));
@@ -2045,7 +2061,7 @@ void IE_Imp_DocBook::endElement(const XML_Char *name)
 		}
 		else
 		{
-			UT_ASSERT(UT_TODO);
+			UT_ASSERT_HARMLESS(UT_TODO);
 		}
 		break;
 	}
@@ -2069,7 +2085,7 @@ void IE_Imp_DocBook::endElement(const XML_Char *name)
 	case TT_FOOTNOTE:
 	{
 		X_CheckError((m_parseState == _PS_Block) || (m_parseState == _PS_Cell));
-		X_CheckError(appendStrux(PTX_EndFootnote,static_cast<const XML_Char **>(NULL)));
+		X_CheckError(appendStrux(PTX_EndFootnote,static_cast<const gchar **>(NULL)));
 
 		if(m_bInTable)
 			m_parseState = _PS_Cell;
@@ -2105,8 +2121,8 @@ void IE_Imp_DocBook::endElement(const XML_Char *name)
 		}
 
 		X_VerifyParseState(_PS_Sec);
-		X_CheckError(appendStrux(PTX_EndTOC,static_cast<const XML_Char **>(NULL)));
-		X_CheckError(appendStrux(PTX_Block,static_cast<const XML_Char **>(NULL)));
+		X_CheckError(appendStrux(PTX_EndTOC,static_cast<const gchar **>(NULL)));
+		X_CheckError(appendStrux(PTX_Block,static_cast<const gchar **>(NULL)));
 		break;
 	}
 
@@ -2140,7 +2156,7 @@ void IE_Imp_DocBook::endElement(const XML_Char *name)
 	case TT_SEEALSO:
 	case TT_TERTIARY:
 	{
-		UT_ASSERT(UT_TODO);
+		UT_ASSERT_HARMLESS(UT_TODO);
 		break;
 	}
 
@@ -2161,7 +2177,7 @@ void IE_Imp_DocBook::endElement(const XML_Char *name)
 	case TT_TABLE:
 	{
 		X_VerifyParseState(_PS_Table);
-		X_CheckError(appendStrux(PTX_EndTable,static_cast<const XML_Char **>(NULL)));
+		X_CheckError(appendStrux(PTX_EndTable,static_cast<const gchar **>(NULL)));
 
 		if(m_bRequiredBlock)
 		{
@@ -2470,7 +2486,7 @@ void IE_Imp_DocBook::endElement(const XML_Char *name)
  * if not, we skip the heading.
  * then, it calls its parent's charData.
  */
-void IE_Imp_DocBook::charData(const XML_Char *s, int len)
+void IE_Imp_DocBook::charData(const gchar *s, int len)
 {
 	if (m_bMustAddTitle && (len > 0))
 	{
@@ -2499,7 +2515,7 @@ void IE_Imp_DocBook::charData(const XML_Char *s, int len)
 			case TT_OTHERNAME:
 			case TT_SURNAME:
 			{
-				UT_ASSERT(UT_TODO);
+				UT_ASSERT_HARMLESS(UT_TODO);
 				break;
 			}
 
@@ -2540,7 +2556,7 @@ void IE_Imp_DocBook::charData(const XML_Char *s, int len)
 					updatedProp = metaProp;
 				}
 				updatedProp += s;
-				getDoc()->setMetaDataProp("dc.description",(XML_Char*)updatedProp.utf8_str());
+				getDoc()->setMetaDataProp("dc.description",(gchar*)updatedProp.utf8_str());
 				break;
 			}
 
@@ -2601,15 +2617,15 @@ void IE_Imp_DocBook::charData(const XML_Char *s, int len)
 	{
 		if(tagTop() == TT_EMAIL)
 		{
-			XML_Char *buf[3];
+			gchar *buf[3];
 			buf[2] = NULL;
 
 			UT_UTF8String link = "mailto:";
 			link += s;
 
 			buf[0] = "xlink:href";
-			buf[1] = (XML_Char*)link.utf8_str();
-			X_CheckError(appendObject(PTO_Hyperlink, const_cast<const XML_Char **>(buf)));
+			buf[1] = (gchar*)link.utf8_str();
+			X_CheckError(appendObject(PTO_Hyperlink, const_cast<const gchar **>(buf)));
 		}
 	}
 
@@ -2628,14 +2644,14 @@ void IE_Imp_DocBook :: createTitle (void)
 
 	if (m_parseState == _PS_DataSec)
 	{
-		UT_ASSERT(UT_TODO);
+		UT_ASSERT_HARMLESS(UT_TODO);
 		return;
 	}
 
 	m_parseState = _PS_Block;
 
 	/* list of attributes */
-	XML_Char *buf[11];
+	gchar *buf[11];
 	memset(buf, 0, sizeof(buf));
 
 	if(m_iTitleDepth > m_utvTitles.getItemCount())
@@ -2648,16 +2664,16 @@ void IE_Imp_DocBook :: createTitle (void)
 	if(m_sectionRole.length())
 	{
 		foundStyle = true;
-		if(!UT_strcmp(m_sectionRole.utf8_str(), "Heading 1") || !UT_strcmp(m_sectionRole.utf8_str(), "Heading 2") ||
-			!UT_strcmp(m_sectionRole.utf8_str(), "Heading 3") || !UT_strcmp(m_sectionRole.utf8_str(), "Heading 4") ||
-			!UT_strcmp(m_sectionRole.utf8_str(), "Section Heading"))
+		if(!strcmp(m_sectionRole.utf8_str(), "Heading 1") || !strcmp(m_sectionRole.utf8_str(), "Heading 2") ||
+			!strcmp(m_sectionRole.utf8_str(), "Heading 3") || !strcmp(m_sectionRole.utf8_str(), "Heading 4") ||
+			!strcmp(m_sectionRole.utf8_str(), "Section Heading"))
 		{
-			buf[1] = UT_strdup(m_sectionRole.utf8_str());
+			buf[1] = g_strdup(m_sectionRole.utf8_str());
 		}
-		else if(!UT_strcmp(m_sectionRole.utf8_str(), "Numbered Heading 1") || !UT_strcmp(m_sectionRole.utf8_str(), "Numbered Heading 2") ||
-				!UT_strcmp(m_sectionRole.utf8_str(), "Numbered Heading 3") || !UT_strcmp(m_sectionRole.utf8_str(), "Chapter Heading"))
+		else if(!strcmp(m_sectionRole.utf8_str(), "Numbered Heading 1") || !strcmp(m_sectionRole.utf8_str(), "Numbered Heading 2") ||
+				!strcmp(m_sectionRole.utf8_str(), "Numbered Heading 3") || !strcmp(m_sectionRole.utf8_str(), "Chapter Heading"))
 		{
-			buf[1] = UT_strdup(m_sectionRole.utf8_str());
+			buf[1] = g_strdup(m_sectionRole.utf8_str());
 			m_bMustNumber = true;
 		}
 		else
@@ -2782,7 +2798,7 @@ void IE_Imp_DocBook :: createTitle (void)
 		else
 			val = "1";
 
-		buf[3] = (XML_Char *)UT_strdup(val.utf8_str());
+		buf[3] = (gchar *)g_strdup(val.utf8_str());
 		buf[4] = PT_LISTID_ATTRIBUTE_NAME;
 
 		if(m_utvTitles[m_iTitleDepth - 1])
@@ -2790,7 +2806,7 @@ void IE_Imp_DocBook :: createTitle (void)
 		else
 			UT_UTF8String_sprintf (val, "%d", ++m_iCurListID);
 
-		buf[5] = (XML_Char *)UT_strdup(val.utf8_str());
+		buf[5] = (gchar *)g_strdup(val.utf8_str());
 		buf[6] = PT_PARENTID_ATTRIBUTE_NAME;
 
 		if(m_utvTitles[m_iTitleDepth - 1])
@@ -2798,7 +2814,7 @@ void IE_Imp_DocBook :: createTitle (void)
 		else
 			val = "0";
 
-		buf[7] = (XML_Char *)UT_strdup(val.utf8_str());
+		buf[7] = (gchar *)g_strdup(val.utf8_str());
 
 	}
 
@@ -2807,22 +2823,22 @@ void IE_Imp_DocBook :: createTitle (void)
 	if(buf[1] == NULL) //preventive code for appendStrux() below
 		buf[0] = NULL;
 
-	X_CheckError(appendStrux(PTX_Block, const_cast<const XML_Char **>(buf)));
+	X_CheckError(appendStrux(PTX_Block, const_cast<const gchar **>(buf)));
 	if (m_bMustNumber)
 	{
 		/* adds field */
-		XML_Char * buf2 [3];
+		gchar * buf2 [3];
 		buf2[0] = PT_TYPE_ATTRIBUTE_NAME;
 		buf2[1] = "list_label";
 		buf2[2] = NULL;
 
-		X_CheckError ( appendObject (PTO_Field, const_cast<const XML_Char **>(buf2)));
-		X_CheckError ( appendFmt (const_cast<const XML_Char **>(buf2)));
+		X_CheckError ( appendObject (PTO_Field, const_cast<const gchar **>(buf2)));
+		X_CheckError ( appendFmt (const_cast<const gchar **>(buf2)));
 		UT_UCSChar ucs = UCS_TAB;
 		appendSpan(&ucs,1);
 		_popInlineFmt();
 	}
-	X_CheckError ( appendFmt (static_cast<const XML_Char **>(NULL)));
+	X_CheckError ( appendFmt (static_cast<const gchar **>(NULL)));
 
 	m_bMustAddTitle = false;
 	m_bTitleAdded = true;
@@ -2861,7 +2877,7 @@ void IE_Imp_DocBook :: createList (void)
 		}
 	}
 
-	XML_Char * lDelim = "";
+	gchar * lDelim = "";
 
 	if(m_iTitleDepth == 1)
 		lDelim = "Chapter %L.";
@@ -2876,8 +2892,8 @@ void IE_Imp_DocBook :: createList (void)
 			pid,
 			NUMBERED_LIST,
 			1,
-			(const XML_Char *)lDelim,
-			(const XML_Char *)"",
+			(const gchar *)lDelim,
+			(const gchar *)"",
 			getDoc (),
 			NULL
 		);
@@ -2885,7 +2901,7 @@ void IE_Imp_DocBook :: createList (void)
 
 	/* register it in the vector */
 	if(m_utvTitles.setNthItem((m_iTitleDepth - 1), an, NULL) == -1)
-		UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+		UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
 
 	/* increment the id counter, so that it is unique */
 	m_iCurListID++;
@@ -2896,7 +2912,7 @@ void IE_Imp_DocBook :: createList (void)
 /*
  * this function creates a new image in the document
  */
-void IE_Imp_DocBook :: createImage (const char *name, const XML_Char **atts)
+void IE_Imp_DocBook :: createImage (const char *name, const gchar **atts)
 {
 	char * relative_file = UT_go_url_resolve_relative(m_szFileName, name);
 	if(!relative_file)
@@ -2915,19 +2931,19 @@ void IE_Imp_DocBook :: createImage (const char *name, const XML_Char **atts)
 	UT_UTF8String dataid;
 	UT_UTF8String_sprintf (dataid, "image%u", static_cast<unsigned int>(m_iImages++));
 
-	const char *mime = UT_strdup("image/png");
+	const char *mime = g_strdup("image/png");
 	X_CheckError (getDoc()->createDataItem (dataid.utf8_str(), false, pBB, reinterpret_cast<void *>(const_cast<char *>(mime)), NULL));
 
-	XML_Char *buf[5];
+	gchar *buf[5];
 	buf[0] = "dataid";
-	buf[1] = (XML_Char*)dataid.utf8_str();
+	buf[1] = (gchar*)dataid.utf8_str();
 	buf[2] = NULL;
 	buf[4] = NULL;
 
 	UT_UTF8String props;
-	const XML_Char *p_val = NULL;
+	const gchar *p_val = NULL;
 
-	p_val = _getXMLPropValue(static_cast<const XML_Char *>("depth"), atts);
+	p_val = _getXMLPropValue(static_cast<const gchar *>("depth"), atts);
 
 	if(p_val)
 	{
@@ -2935,7 +2951,7 @@ void IE_Imp_DocBook :: createImage (const char *name, const XML_Char **atts)
 		props+= p_val;
 	}
 
-	p_val = _getXMLPropValue(static_cast<const XML_Char *>("width"), atts);
+	p_val = _getXMLPropValue(static_cast<const gchar *>("width"), atts);
 
 	if(p_val)
 	{
@@ -2949,26 +2965,26 @@ void IE_Imp_DocBook :: createImage (const char *name, const XML_Char **atts)
 	if(props.length())
 	{
 		buf[2] = PT_PROPS_ATTRIBUTE_NAME;
-		buf[3] = (XML_Char*)props.utf8_str();
+		buf[3] = (gchar*)props.utf8_str();
 	}
 
-	X_CheckError(appendObject(PTO_Image, const_cast<const XML_Char **>(buf)));
+	X_CheckError(appendObject(PTO_Image, const_cast<const gchar **>(buf)));
 	DELETEP(pfg);
 }
 /*****************************************************************************/
 
-const XML_Char ** IE_Imp_DocBook :: getCondition (const XML_Char **atts)
+const gchar ** IE_Imp_DocBook :: getCondition (const gchar **atts)
 {
-	const XML_Char **buf = new const XML_Char*[3];
+	const gchar **buf = new const gchar*[3];
 	buf[2] = NULL;
 
-	const XML_Char *p_val = NULL;
-	p_val = _getXMLPropValue(static_cast<const XML_Char *>("condition"), atts);
+	const gchar *p_val = NULL;
+	p_val = _getXMLPropValue(static_cast<const gchar *>("condition"), atts);
 
 	if(p_val)
 	{
 		buf[0] = PT_PROPS_ATTRIBUTE_NAME;
-		buf[1] = (XML_Char*)p_val;
+		buf[1] = (gchar*)p_val;
 	}
 	else
 	{
@@ -2979,7 +2995,7 @@ const XML_Char ** IE_Imp_DocBook :: getCondition (const XML_Char **atts)
 		return buf;
 
 	DELETEPV(buf);
-	return (const XML_Char **)NULL;
+	return (const gchar **)NULL;
 }
 
 UT_uint32 IE_Imp_DocBook::tagTop(void)
@@ -2996,7 +3012,7 @@ void IE_Imp_DocBook::requireBlock(void)
 	if(!m_iBlockDepth)
 	{
 		m_iBlockDepth = 1;
-		X_CheckError(appendStrux(PTX_Block,static_cast<const XML_Char **>(NULL)));
+		X_CheckError(appendStrux(PTX_Block,static_cast<const gchar **>(NULL)));
 
 		if(m_parseState == _PS_Cell)
 			m_bWroteEntryPara = true;
