@@ -761,7 +761,7 @@ static IE_SuffixConfidence IE_ImpGraphicWin32Native_Sniffer__SuffixConfidence[]
 	{ "jpg", 	UT_CONFIDENCE_PERFECT 	},
 	{ "jpeg", 	UT_CONFIDENCE_PERFECT 	},
 	{ "wmf", 	UT_CONFIDENCE_PERFECT 	},
-	{ NULL, 	UT_CONFIDENCE_ZILCH 	}
+	{ "", 	UT_CONFIDENCE_ZILCH 	}
 };
 
 // supported mimetypes
@@ -773,7 +773,7 @@ static IE_MimeConfidence IE_ImpGraphicWin32_Sniffer__MimeConfidence[] = {
     { IE_MIME_MATCH_FULL,   "image/jpeg",       UT_CONFIDENCE_PERFECT  },
     { IE_MIME_MATCH_FULL,   "windows/metafile", UT_CONFIDENCE_PERFECT  },
     { IE_MIME_MATCH_FULL,   "image/x-wmf",      UT_CONFIDENCE_PERFECT  },
-    { IE_MIME_MATCH_BOGUS,  NULL,               UT_CONFIDENCE_ZILCH    }
+    { IE_MIME_MATCH_BOGUS,  "",               UT_CONFIDENCE_ZILCH    }
 };
 
 class IE_ImpGraphicWin32Native_Sniffer : public IE_ImpGraphicSniffer
