@@ -124,7 +124,7 @@ IE_Imp_MSWrite_Sniffer::IE_Imp_MSWrite_Sniffer () :
 // supported suffixes
 static IE_SuffixConfidence IE_Imp_MSWrite_Sniffer__SuffixConfidence[] = {
 	{ "wri", 	UT_CONFIDENCE_PERFECT 	},
-	{ NULL, 	UT_CONFIDENCE_ZILCH 	}
+	{ "", 	UT_CONFIDENCE_ZILCH 	}
 };
 
 const IE_SuffixConfidence * IE_Imp_MSWrite_Sniffer::getSuffixConfidence ()
@@ -286,7 +286,7 @@ int IE_Imp_MSWrite::read_pap ()
     unsigned char pap_page[0x80];
     static const char *text_align[] = { "left", "center", "right", "justify" };
 
-    XML_Char* pProps = "props";
+    gchar* pProps = "props";
     UT_String propBuffer;
     UT_String tempBuffer;
 	
@@ -403,7 +403,7 @@ int IE_Imp_MSWrite::read_pap ()
 
 				// end of formatting
 
-				const XML_Char* propsArray[3];
+				const gchar* propsArray[3];
 				propsArray[0] = pProps;
 				propsArray[1] = propBuffer.c_str();
 				propsArray[2] = NULL;
@@ -433,7 +433,7 @@ int IE_Imp_MSWrite::read_char (int fcFirst2, int fcLim2) {
     int fcLim, fcMac;
     unsigned char char_page[0x80];
 
-	XML_Char* pProps = "props";
+	gchar* pProps = "props";
 	UT_String propBuffer;
 	UT_String tempBuffer;
 	
@@ -513,7 +513,7 @@ int IE_Imp_MSWrite::read_char (int fcFirst2, int fcLim2) {
 					fcFirst2++;
 				}
 				
-				const XML_Char* propsArray[3];
+				const gchar* propsArray[3];
 				propsArray[0] = pProps;
 				propsArray[1] = propBuffer.c_str();
 				propsArray[2] = NULL;
