@@ -45,7 +45,7 @@
  * Auxiliary functions *
  ***********************/
 
-static const XML_Char *global_listid = "1000";
+static const gchar *global_listid = "1000";
 
 /*!
  * Translate the stylename in UCS2 to a sanitized UTF8 string.
@@ -55,10 +55,10 @@ static const XML_Char *global_listid = "1000";
  * \return NULL if input is NULL or something went horribly wrong, the
  * UTF8 string otherwise.
  */
-static XML_Char *prepare_style_name(const psiconv_string_t input)
+static gchar *prepare_style_name(const psiconv_string_t input)
 {
 	psiconv_string_t input_copy;
-	XML_Char *result;
+	gchar *result;
 	UT_uint32 i,read,written;
 	
 	if (!(input_copy = psiconv_unicode_strdup(input)))
@@ -169,7 +169,7 @@ ERROR1:
  */
 static IE_SuffixConfidence IE_Imp_Psion_Word_Sniffer__SuffixConfidence[] = {
 	{ "psiword", 	UT_CONFIDENCE_PERFECT 	},
-	{ NULL, 		UT_CONFIDENCE_ZILCH 		}
+	{ "", 		UT_CONFIDENCE_ZILCH 		}
 };
 
 const IE_SuffixConfidence * IE_Imp_Psion_Word_Sniffer::getSuffixConfidence ()
@@ -332,7 +332,7 @@ UT_Error IE_Imp_Psion::applyStyles(const psiconv_word_styles_section style_sec)
 	UT_UTF8String props;
 
 	int i;
-	XML_Char *stylename;
+	gchar *stylename;
 	psiconv_word_style style;
 	UT_Error res;
 
@@ -362,7 +362,7 @@ UT_Error IE_Imp_Psion::applyStyles(const psiconv_word_styles_section style_sec)
 
 		// Get the style name.
 		if (i == -1)
-			stylename = (XML_Char *) strdup("Normal");
+			stylename = (gchar *) strdup("Normal");
 		else 
 			stylename = prepare_style_name(style->name);
 		if (!stylename)
@@ -371,15 +371,15 @@ UT_Error IE_Imp_Psion::applyStyles(const psiconv_word_styles_section style_sec)
 		UT_DEBUGMSG(("PSION: Importing style %s\n",stylename));
 		UT_DEBUGMSG(("PSION: Style attributes: %s\n",props.utf8_str()));
 
-		const XML_Char* propsArray[7];
-		propsArray[0] = (const XML_Char *) "props";
-		propsArray[1] = (const XML_Char *) props.utf8_str();
-		propsArray[2] = (const XML_Char *) "name";
+		const gchar* propsArray[7];
+		propsArray[0] = (const gchar *) "props";
+		propsArray[1] = (const gchar *) props.utf8_str();
+		propsArray[2] = (const gchar *) "name";
 		propsArray[3] = stylename;
 		// All Psion styles are based upon the Normal style
-		propsArray[4] = (const XML_Char *) "basedon";
-		propsArray[5] = (const XML_Char *) "Normal";
-		propsArray[6] = (const XML_Char *) NULL;
+		propsArray[4] = (const gchar *) "basedon";
+		propsArray[5] = (const gchar *) "Normal";
+		propsArray[6] = (const gchar *) NULL;
 
 		if (!(getDoc()->appendStyle(propsArray))) {
 			UT_DEBUGMSG(("PSION: AppendStyle failed...\n"));
@@ -404,7 +404,7 @@ UT_Error IE_Imp_Psion::applyPageAttributes(const psiconv_page_layout_section lay
 	UT_return_val_if_fail(layout != NULL, true /* perhaps should be false, but we want loading to proceed */);
 
 	UT_UTF8String props,buffer;
-	const XML_Char* propsArray[11];
+	const gchar* propsArray[11];
 	UT_Error res;
 	int i;
 
@@ -419,26 +419,26 @@ UT_Error IE_Imp_Psion::applyPageAttributes(const psiconv_page_layout_section lay
 		          psiconv_list_length(layout->footer->text->paragraphs);
 	
 	// Page width
-	propsArray[0] = (const XML_Char *) "width";
+	propsArray[0] = (const gchar *) "width";
 	UT_UTF8String_sprintf(buffer,"%6.3f",layout->page_width);
-	propsArray[1] = (const XML_Char *) (buffer.utf8_str());
+	propsArray[1] = (const gchar *) (buffer.utf8_str());
 	
 	// Page height
-	propsArray[2] = (const XML_Char *) "height";
+	propsArray[2] = (const gchar *) "height";
 	UT_UTF8String_sprintf(buffer,"%6.3f",layout->page_width);
-	propsArray[3] = (const XML_Char *) (buffer.utf8_str());
+	propsArray[3] = (const gchar *) (buffer.utf8_str());
 	
 	// Units of width/height
-	propsArray[4] = (const XML_Char *) "units";
-	propsArray[5] = (const XML_Char *) "cm";
+	propsArray[4] = (const gchar *) "units";
+	propsArray[5] = (const gchar *) "cm";
 	
 	// Orientation
-	propsArray[6] = (const XML_Char *) "orientation";
-	propsArray[7] = (const XML_Char *) (layout->landscape?"landscape":"portrait");
+	propsArray[6] = (const gchar *) "orientation";
+	propsArray[7] = (const gchar *) (layout->landscape?"landscape":"portrait");
 	
 	// Page type (we should check for common ones here!)
-	propsArray[8] = (const XML_Char *) "pagetype";
-	propsArray[9] = (const XML_Char *) "Custom";
+	propsArray[8] = (const gchar *) "pagetype";
+	propsArray[9] = (const gchar *) "Custom";
 	
 	propsArray[10] = NULL;
 	
@@ -474,18 +474,18 @@ UT_Error IE_Imp_Psion::applyPageAttributes(const psiconv_page_layout_section lay
 	
 	// Now actually append the properties in a PTX_Section strux to the document
 	UT_DEBUGMSG(("PSION: Page: %s\n",props.utf8_str()));
-	propsArray[0] = (const XML_Char *) "props";
-	propsArray[1] = (const XML_Char *) props.utf8_str();
+	propsArray[0] = (const gchar *) "props";
+	propsArray[1] = (const gchar *) props.utf8_str();
 	i = 2;
 	if (with_header) {
-		propsArray[i++] = (const XML_Char *) "header";
-		propsArray[i++] = (const XML_Char *) "1";
+		propsArray[i++] = (const gchar *) "header";
+		propsArray[i++] = (const gchar *) "1";
 	}
 	if (with_footer) {
-		propsArray[i++] = (const XML_Char *) "footer";
-		propsArray[i++] = (const XML_Char *) "2";
+		propsArray[i++] = (const gchar *) "footer";
+		propsArray[i++] = (const gchar *) "2";
 	}
-	propsArray[i] = (const XML_Char *) NULL;
+	propsArray[i] = (const gchar *) NULL;
 	if (!(appendStrux(PTX_Section,propsArray)))
 		return UT_IE_IMPORTERROR;
 	return UT_OK;
@@ -494,15 +494,15 @@ UT_Error IE_Imp_Psion::applyPageAttributes(const psiconv_page_layout_section lay
 UT_Error IE_Imp_Psion::processHeaderFooter(const psiconv_page_layout_section layout,
                                            bool with_header, bool with_footer)
 {
-	const XML_Char* propsArray[5];
+	const gchar* propsArray[5];
 	UT_Error res;
 	
 	// Header
 	if (with_header) {
-		propsArray[0] = (const XML_Char *) "id";
-		propsArray[1] = (const XML_Char *) "1";
-		propsArray[2] = (const XML_Char *) "type";
-		propsArray[3] = (const XML_Char *) "header";
+		propsArray[0] = (const gchar *) "id";
+		propsArray[1] = (const gchar *) "1";
+		propsArray[2] = (const gchar *) "type";
+		propsArray[3] = (const gchar *) "header";
 		propsArray[4] = NULL;
 		if (!appendStrux(PTX_SectionHdrFtr,propsArray))
 			return UT_IE_IMPORTERROR;
@@ -512,10 +512,10 @@ UT_Error IE_Imp_Psion::processHeaderFooter(const psiconv_page_layout_section lay
 	
 	// Footer
 	if (with_footer) {
-		propsArray[0] = (const XML_Char *) "id";
-		propsArray[1] = (const XML_Char *) "2";
-		propsArray[2] = (const XML_Char *) "type";
-		propsArray[3] = (const XML_Char *) "footer";
+		propsArray[0] = (const gchar *) "id";
+		propsArray[1] = (const gchar *) "2";
+		propsArray[2] = (const gchar *) "type";
+		propsArray[3] = (const gchar *) "footer";
 		propsArray[4] = NULL;
 		if (!appendStrux(PTX_SectionHdrFtr,propsArray))
 			return UT_IE_IMPORTERROR;
@@ -668,12 +668,12 @@ UT_Error IE_Imp_Psion::getParagraphAttributes(const psiconv_paragraph_layout lay
  * bullets.
  */
 UT_Error IE_Imp_Psion::applyParagraphAttributes(const psiconv_paragraph_layout layout,
-                      const XML_Char *stylename)
+                      const gchar *stylename)
 {
 	UT_return_val_if_fail(layout != NULL, true /* perhaps should be false, but we want loading to proceed */);
 
 	UT_UTF8String props;
-	const XML_Char* propsArray[13];
+	const gchar* propsArray[13];
 	UT_Error res;
 
 	// Get all attributes into prop
@@ -692,36 +692,36 @@ UT_Error IE_Imp_Psion::applyParagraphAttributes(const psiconv_paragraph_layout l
 		// black magickish...
 		if (!list) {
 			list = true;
-			propsArray[0] = (const XML_Char *) "id";
+			propsArray[0] = (const gchar *) "id";
 			propsArray[1] = global_listid;
-			propsArray[2] = (const XML_Char *) "parentid";
-			propsArray[3] = (const XML_Char *) "0";
-			propsArray[4] = (const XML_Char *) "type";
-			propsArray[5] = (const XML_Char *) "5";
-			propsArray[6] = (const XML_Char *) "start-value";
-			propsArray[7] = (const XML_Char *) "0";
-			propsArray[8] = (const XML_Char *) "list-delim";
-			propsArray[9] = (const XML_Char *) "%L";
-			propsArray[10] = (const XML_Char *) "list-decimal";
-			propsArray[11] = (const XML_Char *) "NULL";
-			propsArray[12] =(const XML_Char *)  NULL;
+			propsArray[2] = (const gchar *) "parentid";
+			propsArray[3] = (const gchar *) "0";
+			propsArray[4] = (const gchar *) "type";
+			propsArray[5] = (const gchar *) "5";
+			propsArray[6] = (const gchar *) "start-value";
+			propsArray[7] = (const gchar *) "0";
+			propsArray[8] = (const gchar *) "list-delim";
+			propsArray[9] = (const gchar *) "%L";
+			propsArray[10] = (const gchar *) "list-decimal";
+			propsArray[11] = (const gchar *) "NULL";
+			propsArray[12] =(const gchar *)  NULL;
 			getDoc()->appendList(propsArray);
 		}
 	}
 
 	// Prepare the properties for this paragraph strux
 	UT_DEBUGMSG(("PSION: Paragraph: %s\n",props.utf8_str()));
-	propsArray[0] = (const XML_Char *) "props";
-	propsArray[1] = (const XML_Char *) props.utf8_str();
-	propsArray[2] = (const XML_Char *) "style";
+	propsArray[0] = (const gchar *) "props";
+	propsArray[1] = (const gchar *) props.utf8_str();
+	propsArray[2] = (const gchar *) "style";
 	propsArray[3] = stylename;
-	propsArray[4] = (const XML_Char *) NULL;
+	propsArray[4] = (const gchar *) NULL;
 
 	// Bullets need the listid too.
 	if (layout->bullet->on) {
-		propsArray[4] = (const XML_Char *) "listid";
+		propsArray[4] = (const gchar *) "listid";
 		propsArray[5] = global_listid;
-		propsArray[6] = (const XML_Char *) NULL;
+		propsArray[6] = (const gchar *) NULL;
 	}
 
 	if (!(appendStrux(PTX_Block,propsArray)))
@@ -736,9 +736,9 @@ UT_Error IE_Imp_Psion::applyParagraphAttributes(const psiconv_paragraph_layout l
 
 	// We need to append a field and some other stuff...
 	if (layout->bullet->on) {
-		propsArray[0] = (const XML_Char *) "type";
-		propsArray[1] = (const XML_Char *) "list_label";
-		propsArray[2] = (const XML_Char *) NULL;
+		propsArray[0] = (const gchar *) "type";
+		propsArray[1] = (const gchar *) "list_label";
+		propsArray[2] = (const gchar *) NULL;
 		if (!(appendObject(PTO_Field,propsArray)))
 			return UT_IE_IMPORTERROR;
 
@@ -866,9 +866,9 @@ UT_Error IE_Imp_Psion::applyCharacterAttributes(const psiconv_character_layout l
 	UT_DEBUGMSG(("PSION: Character: %s\n",props.utf8_str()));
 
 	// Propare the Fmt properties
-	const XML_Char* propsArray[3];
-	propsArray[0] = (const XML_Char *) "props";
-	propsArray[1] = (const XML_Char *) props.utf8_str();
+	const gchar* propsArray[3];
+	propsArray[0] = (const gchar *) "props";
+	propsArray[1] = (const gchar *) props.utf8_str();
 	propsArray[2] = NULL;
 
 	if (!(appendFmt(propsArray)))
@@ -935,7 +935,7 @@ UT_Error IE_Imp_Psion::insertImage(const psiconv_in_line_layout in_line)
 	UT_ByteBuf image_buffer;
 	png_byte *row;
 	UT_UTF8String props,iname,buffer;
-	const XML_Char* propsArray[13];
+	const gchar* propsArray[13];
 	int x,y,xsize,ysize;
 	char *mimetype;
 	UT_uint32 iid;
@@ -1021,14 +1021,14 @@ UT_Error IE_Imp_Psion::insertImage(const psiconv_in_line_layout in_line)
 	// Set the properties
 	// Note that we both have to add a Data Item (containing the image) and 
 	// the object (just a reference to the Data Item).
-	propsArray[0] = (const XML_Char *) "dataid";
-	propsArray[1] = (const XML_Char *) (iname.utf8_str());
-	propsArray[2] = (const XML_Char *) "props";
-	propsArray[3] = (const XML_Char *) (props.utf8_str());
+	propsArray[0] = (const gchar *) "dataid";
+	propsArray[1] = (const gchar *) (iname.utf8_str());
+	propsArray[2] = (const gchar *) "props";
+	propsArray[3] = (const gchar *) (props.utf8_str());
 	propsArray[4] = NULL;
 	if (!(getDoc()->appendObject(PTO_Image,propsArray)))
 		return UT_IE_IMPORTERROR;
-	if (!(mimetype = UT_strdup("image/png")))
+	if (!(mimetype = g_strdup("image/png")))
 		return UT_IE_NOMEMORY;
 	if (!(getDoc()->createDataItem(iname.utf8_str(),false,&image_buffer,
 		 (const void*) mimetype,NULL)))
@@ -1067,7 +1067,7 @@ UT_Error IE_Imp_Psion::readParagraphs(const psiconv_text_and_layout psiontext,
 	psiconv_in_line_layout in_line;
 	UT_UCS4String text;
 	psiconv_word_style style;
-	const XML_Char *stylename;
+	const gchar *stylename;
 	UT_Error res;
 
 	// Iterate through all paragraphs
@@ -1085,7 +1085,7 @@ UT_Error IE_Imp_Psion::readParagraphs(const psiconv_text_and_layout psiontext,
 		    !(style = psiconv_get_style(style_sec,paragraph->base_style)) ||
 			(!style->name) || 
 		  	!(stylename = prepare_style_name(style->name)))
-			stylename = (const XML_Char *) strdup("Normal");
+			stylename = (const gchar *) strdup("Normal");
 		if (!stylename)
 			return UT_IE_NOMEMORY;
 		UT_DEBUGMSG(("PSION: paragraph %d: style %s\n",i,stylename));
