@@ -460,7 +460,7 @@ IE_Imp_StarOffice_Sniffer::IE_Imp_StarOffice_Sniffer () :
 // supported suffixes
 static IE_SuffixConfidence IE_Imp_StarOffice_Sniffer__SuffixConfidence[] = {
 	{ "sdw", 	UT_CONFIDENCE_PERFECT 	},
-	{ NULL, 	UT_CONFIDENCE_ZILCH 	}
+	{ "", 	UT_CONFIDENCE_ZILCH 	}
 };
 
 const IE_SuffixConfidence * IE_Imp_StarOffice_Sniffer::getSuffixConfidence ()
@@ -474,7 +474,7 @@ static IE_MimeConfidence IE_Imp_StarOffice_Sniffer__MimeConfidence[] = {
 	{ IE_MIME_MATCH_FULL, 	"application/x-staroffice-word", 		UT_CONFIDENCE_GOOD 	},	/* aliases */
 	{ IE_MIME_MATCH_FULL, 	"application/x-staroffice-words", 		UT_CONFIDENCE_GOOD 	},
 	{ IE_MIME_MATCH_FULL, 	"application/x-starwriter", 			UT_CONFIDENCE_GOOD 	},
-	{ IE_MIME_MATCH_BOGUS, 	NULL, 									UT_CONFIDENCE_ZILCH }
+	{ IE_MIME_MATCH_BOGUS, 	"", 									UT_CONFIDENCE_ZILCH }
 };
 
 const IE_MimeConfidence * IE_Imp_StarOffice_Sniffer::getMimeConfidence ()
@@ -773,14 +773,14 @@ UT_Error IE_Imp_StarOffice::_loadFile(GsfInput * input) UT_THROWS(()) {
 										return UT_IE_BOGUSDOCUMENT;
 								}
 
-								static XML_Char* attributes[3] = {
+								static gchar* attributes[3] = {
 									"props",
 									NULL,
 									NULL
 								};
-								attributes[1] = const_cast<XML_Char*>(reinterpret_cast<const XML_Char*>(pAttrs.c_str()));
+								attributes[1] = const_cast<gchar*>(reinterpret_cast<const gchar*>(pAttrs.c_str()));
 								// first, insert the paragraph
-								if (!appendStrux(PTX_Block, (const XML_Char**)attributes))
+								if (!appendStrux(PTX_Block, (const gchar**)attributes))
 									return UT_IE_NOMEMORY;
 
 								UT_String pca(attrs); // character attributes for the whole paragraph
@@ -816,9 +816,9 @@ UT_Error IE_Imp_StarOffice::_loadFile(GsfInput * input) UT_THROWS(()) {
 											doInsert = true;
 									}
 									if (doInsert || i == (len - 1)) {
-										attributes[1] = const_cast<XML_Char*>(reinterpret_cast<const XML_Char*>(attrs.c_str()));
+										attributes[1] = const_cast<gchar*>(reinterpret_cast<const gchar*>(attrs.c_str()));
 										UT_DEBUGMSG(("SDW: Going to appendFmt with %s\n", attributes[1]));
-										if (!appendFmt((const XML_Char **) attributes))
+										if (!appendFmt((const gchar **) attributes))
 											return UT_IE_NOMEMORY; /* leave cast alone! */
 										UT_DEBUGMSG(("SDW: About to insert %lu-%lu\n", lastInsPos, i));
 										size_t spanLen = i - lastInsPos;
@@ -946,9 +946,12 @@ UT_Error IE_Imp_StarOffice::_loadFile(GsfInput * input) UT_THROWS(()) {
 						if (id == IDX_NOCONV_FF) {
 							UT_ASSERT_HARMLESS(UT_NOT_IMPLEMENTED);
 						}
+						// FIXME: find a way to not have to copy and free 
+						// the result of UT_convert_cd.... --hub
 						UT_DEBUGMSG(("SDW: StringPool: found 0x%04x <-> %.*s\n", id, len, str));
 						UT_UCS4Char* convertedString = reinterpret_cast<UT_UCS4Char*>(UT_convert_cd(str, len, cd, NULL, NULL));
-						mStringPool.insert(id, convertedString);
+						mStringPool.insert(stringpool_map::value_type(id, convertedString));
+						FREEP(convertedString);
                         delete [] str;
 					}
                     UT_iconv_close(cd);
