@@ -119,7 +119,7 @@ static IE_SuffixConfidence IE_Imp_T602_Sniffer__SuffixConfidence[] = {
 	{ "602", 	UT_CONFIDENCE_PERFECT 	},
 	{ "t602", 	UT_CONFIDENCE_PERFECT 	},
 	{ "txt", 	UT_CONFIDENCE_POOR 		},
-	{ NULL, 	UT_CONFIDENCE_ZILCH 	}
+	{ "", 	UT_CONFIDENCE_ZILCH 	}
 };
 
 const IE_SuffixConfidence * IE_Imp_T602_Sniffer::getSuffixConfidence ()
@@ -325,7 +325,7 @@ UT_Error IE_Imp_T602::_writeTP()
 {
   UT_DEBUGMSG(("T602: Append text properties\n"));
   UT_String buff;
-  const XML_Char* pps[3];
+  const gchar* pps[3];
   UT_String_sprintf(buff,"font-family: %s; font-size: %dpt; color:%s; font-weight: %s; "
 		    "font-style: %s; text-decoration: %s; text-position: %s",
 		    m_family.c_str(), m_size, m_color.c_str(),
@@ -347,7 +347,7 @@ UT_Error IE_Imp_T602::_writePP()
 {
   UT_DEBUGMSG(("T602: Append paragraph properties\n"));
   UT_String buff;
-  const XML_Char* pps[3];
+  const gchar* pps[3];
 
   // Don't put %1.1f here!! Locales could fuck it...
   UT_String_sprintf(buff,"line-height: %d.%d",
@@ -364,7 +364,7 @@ UT_DEBUGMSG(("T602: par-prop:\"%s\"]\n",buff.c_str()));
 UT_Error IE_Imp_T602::_writeSP()
 {
   UT_DEBUGMSG(("T602: Append section\n"));
-  const XML_Char* sps[7];
+  const gchar* sps[7];
   UT_String bf1, bf2, buff;
   int i=2;
 
@@ -385,14 +385,14 @@ UT_Error IE_Imp_T602::_writeSP()
   {
     sps[i]="header";
    UT_String_sprintf(bf1,"%d",m_header);
-   sps[i+1]=static_cast<const XML_Char *>(bf1.c_str());
+   sps[i+1]=static_cast<const gchar *>(bf1.c_str());
    i=2;
   }
   if (m_footer)
   {
    sps[i]="footer";
    UT_String_sprintf(bf2,"%d",m_footer);
-   sps[i+1]=static_cast<const XML_Char *>(bf2.c_str());
+   sps[i+1]=static_cast<const gchar *>(bf2.c_str());
    i+=2;
   }
   sps[i]=NULL;
@@ -404,8 +404,8 @@ UT_Error IE_Imp_T602::_writeSP()
 UT_Error IE_Imp_T602::_write_fh(UT_String & fh, UT_uint32 id, bool hea)
 {
   UT_DEBUGMSG(("T602: Append footer/header section\n"));
-  const XML_Char* fhps[5];
-  const XML_Char* fps[5];
+  const gchar* fhps[5];
+  const gchar* fps[5];
   UT_String bf1;
   UT_String buff;
   int i = 0;
@@ -413,7 +413,7 @@ UT_Error IE_Imp_T602::_write_fh(UT_String & fh, UT_uint32 id, bool hea)
 
   UT_String_sprintf(bf1,"%d",id);
   fhps[0]="id";
-  fhps[1]=static_cast<const XML_Char *>(bf1.c_str());
+  fhps[1]=static_cast<const gchar *>(bf1.c_str());
   fhps[2]="type";
   fhps[3]=(hea?"header":"footer");
   fhps[4]=NULL;
