@@ -59,7 +59,7 @@ IE_Imp_WML_Sniffer::IE_Imp_WML_Sniffer (const char * name) :
 // supported suffixes
 static IE_SuffixConfidence IE_Imp_WML_Sniffer__SuffixConfidence[] = {
 	{ "wml", 	UT_CONFIDENCE_PERFECT 	},
-	{ NULL, 	UT_CONFIDENCE_ZILCH 	}
+	{ "",   	UT_CONFIDENCE_ZILCH 	}
 };
 
 const IE_SuffixConfidence * IE_Imp_WML_Sniffer::getSuffixConfidence ()
@@ -113,10 +113,10 @@ IE_Imp_WML::~IE_Imp_WML()
 
 IE_Imp_WML::IE_Imp_WML (PD_Document * pDocument) :
 	IE_Imp_XML(pDocument,false),
-	m_TableHelperStack(new IE_Imp_TableHelperStack()),
 	m_iColumns(0),
 	m_iImages(0),
-	m_iOpenedColumns(0)
+	m_iOpenedColumns(0),
+	m_TableHelperStack(new IE_Imp_TableHelperStack())
 {
 }
 
@@ -228,9 +228,9 @@ static struct xmlToIdMapping s_Tokens[] =
 /*****************************************************************/
 /*****************************************************************/
 
-void IE_Imp_WML::openTable(const XML_Char **atts)
+void IE_Imp_WML::openTable(const gchar **atts)
 {
-	const XML_Char * wml_columns = 0;
+	const gchar * wml_columns = 0;
 	wml_columns = _getXMLPropValue ("columns", atts);
 
 	if (wml_columns)
@@ -246,7 +246,7 @@ void IE_Imp_WML::closeTable(void)
 	X_CheckError(m_TableHelperStack->tableEnd());
 }
 
-void IE_Imp_WML::openRow(const XML_Char **atts)
+void IE_Imp_WML::openRow(const gchar **atts)
 {
 	X_CheckError(m_TableHelperStack->trStart(NULL));
 }
@@ -257,13 +257,13 @@ void IE_Imp_WML::closeRow(void)
 
 	while(m_iColumns > m_iOpenedColumns)
 	{
-		const XML_Char ** empty = NULL;
+		const gchar ** empty = NULL;
 		openCell(empty);
 		closeCell();
 	}
 }
 
-void IE_Imp_WML::openCell(const XML_Char **atts)
+void IE_Imp_WML::openCell(const gchar **atts)
 {
 	// Note: there's no rowspan or colspan in WML 1.1
 
@@ -279,8 +279,8 @@ void IE_Imp_WML::closeCell(void)
 /*****************************************************************/
 /*****************************************************************/
 
-void IE_Imp_WML::startElement(const XML_Char *name,
-			       const XML_Char **atts)
+void IE_Imp_WML::startElement(const gchar *name,
+			       const gchar **atts)
 {
 	UT_DEBUGMSG(("WML import: startElement: %s\n", name));
 
@@ -305,7 +305,7 @@ void IE_Imp_WML::startElement(const XML_Char *name,
 		
 		// Keep this appendStrux() call here to support files with more
 		// than one <card>
-		X_CheckError(appendStrux(PTX_Section,static_cast<const XML_Char **>(NULL)));
+		X_CheckError(appendStrux(PTX_Section,static_cast<const gchar **>(NULL)));
 		return;
 	}
 
@@ -321,55 +321,55 @@ void IE_Imp_WML::startElement(const XML_Char *name,
 		X_VerifyParseState(_PS_MetaData);
 		m_parseState = _PS_Meta;
 
-		const XML_Char *name = NULL, *content = NULL;
+		const gchar *name = NULL, *content = NULL;
 
-		name = static_cast<const XML_Char*>(_getXMLPropValue("name", atts));
-		content = static_cast<const XML_Char*>(_getXMLPropValue("content", atts));
+		name = static_cast<const gchar*>(_getXMLPropValue("name", atts));
+		content = static_cast<const gchar*>(_getXMLPropValue("content", atts));
 
 		if(!name || !content)
 			return;
 
-		if(!UT_strcmp("title", name))
+		if(!strcmp("title", name))
 		{
 			getDoc()->setMetaDataProp("dc.title",content);
 		}
-		else if(!UT_strcmp("author", name))
+		else if(!strcmp("author", name))
 		{
 			getDoc()->setMetaDataProp("dc.creator",content);
 		}
-		else if(!UT_strcmp("subject", name))
+		else if(!strcmp("subject", name))
 		{
 			getDoc()->setMetaDataProp("dc.subject",content);
 		}
-		else if(!UT_strcmp("description", name))
+		else if(!strcmp("description", name))
 		{
 			getDoc()->setMetaDataProp("dc.description",content);
 		}
-		else if(!UT_strcmp("publisher", name))
+		else if(!strcmp("publisher", name))
 		{
 			getDoc()->setMetaDataProp("dc.publisher",content);
 		}
-		else if(!UT_strcmp("contributor", name))
+		else if(!strcmp("contributor", name))
 		{
 			getDoc()->setMetaDataProp("dc.contributor",content);
 		}
-		else if(!UT_strcmp("source", name))
+		else if(!strcmp("source", name))
 		{
 			getDoc()->setMetaDataProp("dc.source",content);
 		}
-		else if(!UT_strcmp("relation", name))
+		else if(!strcmp("relation", name))
 		{
 			getDoc()->setMetaDataProp("dc.relation",content);
 		}
-		else if(!UT_strcmp("coverage", name))
+		else if(!strcmp("coverage", name))
 		{
 			getDoc()->setMetaDataProp("dc.coverage",content);
 		}
-		else if(!UT_strcmp("rights", name))
+		else if(!strcmp("rights", name))
 		{
 			getDoc()->setMetaDataProp("dc.rights",content);
 		}
-		else if(!UT_strcmp("keywords", name))
+		else if(!strcmp("keywords", name))
 		{
 			getDoc()->setMetaDataProp("abiword.keywords",content);
 		}
@@ -382,15 +382,15 @@ void IE_Imp_WML::startElement(const XML_Char *name,
 		X_VerifyParseState(_PS_Sec);
 		m_parseState = _PS_Block;
 
-		const XML_Char *p_val = NULL;
-		XML_Char *buf[3];
+		const gchar *p_val = NULL;
+		gchar *buf[3];
 		bool left = false;
 
 		buf[0] = "props";
 		buf[1] = NULL;
 		buf[2] = NULL;
 
-		p_val = static_cast<const XML_Char*>(_getXMLPropValue("align", atts));
+		p_val = static_cast<const gchar*>(_getXMLPropValue("align", atts));
 		if(!p_val || !atts)
 		{
 			UT_DEBUGMSG(("WML: got <p> with no props\n"));
@@ -398,11 +398,11 @@ void IE_Imp_WML::startElement(const XML_Char *name,
 		}
 		else
 		{
-			if(!UT_strcmp(p_val, "center"))
+			if(!strcmp(p_val, "center"))
 			{
 				buf[1] = "text-align:center";
 			}
-			else if(!UT_strcmp(p_val, "right"))
+			else if(!strcmp(p_val, "right"))
 			{
 				buf[1] = "text-align:right";
 			}
@@ -412,7 +412,7 @@ void IE_Imp_WML::startElement(const XML_Char *name,
 			}
 		}
 
-		X_CheckError(appendStrux(PTX_Block, (left ? NULL : const_cast<const XML_Char **>(buf))));
+		X_CheckError(appendStrux(PTX_Block, (left ? NULL : const_cast<const gchar **>(buf))));
 		return;
 	}
 		
@@ -423,8 +423,8 @@ void IE_Imp_WML::startElement(const XML_Char *name,
 		if(m_parseState == _PS_Sec)
 			X_CheckError(appendStrux(PTX_Block,NULL));
 
-		const XML_Char *p_val = NULL;
-		p_val = _getXMLPropValue(static_cast<const XML_Char *>("src"), atts);
+		const gchar *p_val = NULL;
+		p_val = _getXMLPropValue(static_cast<const gchar *>("src"), atts);
 
 		if(p_val)
 			createImage (p_val, atts);
@@ -454,8 +454,8 @@ void IE_Imp_WML::startElement(const XML_Char *name,
 	{
 		X_CheckError((m_parseState == _PS_Block) || (m_parseState == _PS_Cell));
 
-		const XML_Char **p_atts;
-		XML_Char *buf[3];
+		const gchar **p_atts;
+		gchar *buf[3];
 		buf[0] = "props";
 		buf[1] = NULL;
 	    buf[2] = NULL;
@@ -502,7 +502,7 @@ void IE_Imp_WML::startElement(const XML_Char *name,
 			}
 		}
 
-		p_atts = const_cast<const XML_Char **>(buf);
+		p_atts = const_cast<const gchar **>(buf);
 		X_CheckError(_pushInlineFmt(p_atts));
 		X_CheckError(appendFmt(&m_vecInlineFmt));
 		return;
@@ -536,21 +536,21 @@ void IE_Imp_WML::startElement(const XML_Char *name,
 	case TT_ANCHOR:
 	{
 		X_CheckError((m_parseState == _PS_Block) || (m_parseState == _PS_Cell));
-		XML_Char *buf[5];
+		gchar *buf[5];
 		buf[4] = NULL;
 
-		const XML_Char *p_val = NULL;
-		p_val = _getXMLPropValue(static_cast<const XML_Char *>("id"), atts);
+		const gchar *p_val = NULL;
+		p_val = _getXMLPropValue(static_cast<const gchar *>("id"), atts);
 
 		if(p_val)
 		{
 			buf[0] = PT_TYPE_ATTRIBUTE_NAME;
 			buf[1] = "start";
 			buf[2] = PT_NAME_ATTRIBUTE_NAME;
-			buf[3] = (XML_Char*)p_val;
-			X_CheckError(appendObject(PTO_Bookmark, const_cast<const XML_Char **>(buf)));
+			buf[3] = (gchar*)p_val;
+			X_CheckError(appendObject(PTO_Bookmark, const_cast<const gchar **>(buf)));
 			buf[1] = "end";
-			X_CheckError(appendObject(PTO_Bookmark, const_cast<const XML_Char **>(buf)));
+			X_CheckError(appendObject(PTO_Bookmark, const_cast<const gchar **>(buf)));
 		}
 		return;
 	}
@@ -559,17 +559,17 @@ void IE_Imp_WML::startElement(const XML_Char *name,
 	{
 		X_CheckError((m_parseState == _PS_Block) || (m_parseState == _PS_Cell));
 
-		XML_Char *buf[3];
+		gchar *buf[3];
 		buf[2] = NULL;
 
-		const XML_Char *p_val = NULL;
-		p_val = _getXMLPropValue(static_cast<const XML_Char *>("href"), atts);
+		const gchar *p_val = NULL;
+		p_val = _getXMLPropValue(static_cast<const gchar *>("href"), atts);
 
 		if(p_val)
 		{
 			buf[0] = "xlink:href";
-			buf[1] = (XML_Char*)p_val;
-			X_CheckError(appendObject(PTO_Hyperlink, const_cast<const XML_Char **>(buf)));
+			buf[1] = (gchar*)p_val;
+			X_CheckError(appendObject(PTO_Hyperlink, const_cast<const gchar **>(buf)));
 		}
 		else //href is required, bail out
 		{
@@ -603,7 +603,7 @@ void IE_Imp_WML::startElement(const XML_Char *name,
 
 }
 
-void IE_Imp_WML::endElement(const XML_Char *name)
+void IE_Imp_WML::endElement(const gchar *name)
 {
 	UT_DEBUGMSG(("WML import: endElement: %s\n", name));
 
@@ -747,7 +747,7 @@ void IE_Imp_WML::endElement(const XML_Char *name)
 	}
 }
 
-void IE_Imp_WML::createImage(const char *name, const XML_Char **atts)
+void IE_Imp_WML::createImage(const char *name, const gchar **atts)
 {
 	char * relative_file = UT_go_url_resolve_relative(m_szFileName, name);
 	if(!relative_file)
@@ -767,27 +767,28 @@ void IE_Imp_WML::createImage(const char *name, const XML_Char **atts)
 	UT_UTF8String_sprintf (dataid, "image%u", static_cast<unsigned int>(m_iImages++));
 
 	UT_UTF8String alt;
-	const XML_Char *p_val = NULL;
+	const gchar *p_val = NULL;
 
-	p_val = _getXMLPropValue(static_cast<const XML_Char *>("alt"), atts);
+	p_val = _getXMLPropValue(static_cast<const gchar *>("alt"), atts);
 	if (p_val)
 		alt += p_val;
 
-	const char *mime = UT_strdup("image/png");
+	const char *mime = g_strdup("image/png");
+	X_CheckError (mime);
 	X_CheckError (getDoc()->createDataItem (dataid.utf8_str(), false, pBB, reinterpret_cast<void *>(const_cast<char *>(mime)), NULL));
 
-	XML_Char *buf[7];
+	gchar *buf[7];
 	buf[0] = "dataid";
-	buf[1] = (XML_Char*)dataid.utf8_str();
+	buf[1] = (gchar*)dataid.utf8_str();
 	buf[2] = "alt";
-	buf[3] = (XML_Char*)alt.utf8_str();
+	buf[3] = (gchar*)alt.utf8_str();
 	buf[4] = NULL;
 	buf[5] = NULL;
 	buf[6] = NULL;
 
 	UT_UTF8String props;
 
-	p_val = _getXMLPropValue(static_cast<const XML_Char *>("height"), atts);
+	p_val = _getXMLPropValue(static_cast<const gchar *>("height"), atts);
 
 	if(p_val)
 	{
@@ -795,7 +796,7 @@ void IE_Imp_WML::createImage(const char *name, const XML_Char **atts)
 		props += UT_UTF8String_sprintf("%fin", UT_convertDimToInches(UT_convertDimensionless(p_val), DIM_PX));
 	}
 
-	p_val = _getXMLPropValue(static_cast<const XML_Char *>("width"), atts);
+	p_val = _getXMLPropValue(static_cast<const gchar *>("width"), atts);
 
 	if(p_val)
 	{
@@ -806,17 +807,28 @@ void IE_Imp_WML::createImage(const char *name, const XML_Char **atts)
 		props += UT_UTF8String_sprintf("%fin", UT_convertDimToInches(UT_convertDimensionless(p_val), DIM_PX));
 	}
 
+	p_val = _getXMLPropValue(static_cast<const gchar *>("xml:lang"), atts);
+
+	if(p_val)
+	{
+		if(props.length())
+			props+= "; ";
+		props+= "lang:";
+		props+= p_val;
+	}
+
+
 	if(props.length())
 	{
 		buf[4] = PT_PROPS_ATTRIBUTE_NAME;
-		buf[5] = (XML_Char*)props.utf8_str();
+		buf[5] = (gchar*)props.utf8_str();
 	}
 
-	X_CheckError(appendObject(PTO_Image, const_cast<const XML_Char **>(buf)));
+	X_CheckError(appendObject(PTO_Image, const_cast<const gchar **>(buf)));
 	DELETEP(pfg);
 }
 
-void IE_Imp_WML::charData(const XML_Char *s, int len)
+void IE_Imp_WML::charData(const gchar *s, int len)
 {
 	if(m_parseState == _PS_Cell)
 	{
