@@ -42,7 +42,7 @@ IE_Exp_WordPerfect_Sniffer::~IE_Exp_WordPerfect_Sniffer()
 bool IE_Exp_WordPerfect_Sniffer::recognizeSuffix (const char * szSuffix)
 {
 	// We can only write word documents, not templates
-  return ( !UT_stricmp(szSuffix,".wpd") || !UT_stricmp(szSuffix, ".wp") ) ;
+  return ( !g_ascii_strcasecmp(szSuffix,".wpd") || !g_ascii_strcasecmp(szSuffix, ".wp") ) ;
 }
 
 UT_Error IE_Exp_WordPerfect_Sniffer::constructExporter (PD_Document * pDocument,
@@ -434,24 +434,24 @@ void WordPerfect_Listener::_openBlock(PT_AttrPropIndex api)
 	
 	if (bHaveProp && pAP)
 	{
-		const XML_Char * szValue;
+		const gchar * szValue;
 		char oldJustification = m_paragraphJustification; // remember the old setting to only change it if it has really changed
 		
 		if (pAP->getProperty("text-align", szValue))
 		{
-			if (!UT_strcmp("left", szValue))
+			if (!strcmp("left", szValue))
 			{
 				m_paragraphJustification = WP_PARAGRAPH_GROUP_JUSTIFICATION_LEFT;
 			} 
-			else if (!UT_strcmp("right", szValue))
+			else if (!strcmp("right", szValue))
 			{
 				m_paragraphJustification = WP_PARAGRAPH_GROUP_JUSTIFICATION_RIGHT;
 			}
-			else if (!UT_strcmp("center", szValue))
+			else if (!strcmp("center", szValue))
 			{
 				m_paragraphJustification = WP_PARAGRAPH_GROUP_JUSTIFICATION_CENTER;
 			}
-			else if (!UT_strcmp("justify", szValue))
+			else if (!strcmp("justify", szValue))
 			{
 				m_paragraphJustification = WP_PARAGRAPH_GROUP_JUSTIFICATION_FULL;
 			}
@@ -486,11 +486,11 @@ void WordPerfect_Listener::_openSpan(PT_AttrPropIndex api)
 
 	if (bHaveProp && pAP)
 	{
-		const XML_Char * szValue;
+		const gchar * szValue;
 		
 		if (
 			(pAP->getProperty("text-position", szValue))
-			&& !UT_strcmp(szValue, "superscript")
+			&& !strcmp(szValue, "superscript")
 			)
 		{
 			_handleAttributeOn((char) 5);  // FIXME: use defines
@@ -498,7 +498,7 @@ void WordPerfect_Listener::_openSpan(PT_AttrPropIndex api)
 
 		if (
 			(pAP->getProperty("text-position", szValue))
-			&& !UT_strcmp(szValue, "subscript")
+			&& !strcmp(szValue, "subscript")
 			)
 		{
 			_handleAttributeOn((char) 6);  // FIXME: use defines
@@ -506,7 +506,7 @@ void WordPerfect_Listener::_openSpan(PT_AttrPropIndex api)
 		
 		if (
 			(pAP->getProperty("font-style", szValue))
-			&& !UT_strcmp(szValue, "italic")
+			&& !strcmp(szValue, "italic")
 			)
 		{
 			_handleAttributeOn((char) 8);  // FIXME: use defines
@@ -514,7 +514,7 @@ void WordPerfect_Listener::_openSpan(PT_AttrPropIndex api)
 		
 		if (
 			(pAP->getProperty("font-weight", szValue))
-			&& !UT_strcmp(szValue, "bold")
+			&& !strcmp(szValue, "bold")
 			)
 		{
 			_handleAttributeOn((char) 12);  // FIXME: use defines
@@ -524,20 +524,20 @@ void WordPerfect_Listener::_openSpan(PT_AttrPropIndex api)
 			(pAP->getProperty("text-decoration", szValue))
 			)
 		{
-			const XML_Char* pszDecor = szValue;
+			const gchar* pszDecor = szValue;
 
-			XML_Char* p;
-			if (!UT_cloneString((char *&)p, pszDecor))
+			gchar* p;
+			if (!(p = g_strdup(pszDecor)))
 			{
 				// TODO outofmem
 			}
 
 			UT_return_if_fail(p || !pszDecor);
-			XML_Char*	q = strtok(p, " ");
+			gchar*	q = strtok(p, " ");
 
 			while (q)
 			{
-				if (0 == UT_strcmp(q, "line-through"))
+				if (0 == strcmp(q, "line-through"))
 				{
 					_handleAttributeOn((char) 13);  // FIXME: use defines
 				}
@@ -552,20 +552,20 @@ void WordPerfect_Listener::_openSpan(PT_AttrPropIndex api)
 			(pAP->getProperty("text-decoration", szValue))
 			)
 		{
-			const XML_Char* pszDecor = szValue;
+			const gchar* pszDecor = szValue;
 
-			XML_Char* p;
-			if (!UT_cloneString((char *&)p, pszDecor))
+			gchar* p;
+			if (!(p = g_strdup(pszDecor)))
 			{
 				// TODO outofmem
 			}
 
 			UT_return_if_fail(p || !pszDecor);
-			XML_Char*	q = strtok(p, " ");
+			gchar*	q = strtok(p, " ");
 
 			while (q)
 			{
-				if (0 == UT_strcmp(q, "underline"))
+				if (0 == strcmp(q, "underline"))
 				{
 					_handleAttributeOn((char) 14);  // FIXME: use defines
 				}
@@ -583,10 +583,10 @@ void WordPerfect_Listener::_openSpan(PT_AttrPropIndex api)
 			|| (pAP->getProperty("bgcolor", szValue))
 			)
 		{
-			const XML_Char* pszColor = NULL;
-			const XML_Char* pszBgColor = NULL;
-			const XML_Char* pszFontSize = NULL;
-			const XML_Char* pszFontFamily = NULL;
+			const gchar* pszColor = NULL;
+			const gchar* pszBgColor = NULL;
+			const gchar* pszFontSize = NULL;
+			const gchar* pszFontFamily = NULL;
 
 			pAP->getProperty("color", pszColor);
 			pAP->getProperty("font-size", pszFontSize);
@@ -625,11 +625,11 @@ void WordPerfect_Listener::_closeSpan()
 
 	if (pAP)
 	{
-		const XML_Char * szValue;
+		const gchar * szValue;
 		
 		if (
 			(pAP->getProperty("text-position", szValue))
-			&& !UT_strcmp(szValue, "superscript")
+			&& !strcmp(szValue, "superscript")
 			)
 		{
 			_handleAttributeOff((char) 5);  // FIXME: use defines
@@ -637,7 +637,7 @@ void WordPerfect_Listener::_closeSpan()
 
 		if (
 			(pAP->getProperty("text-position", szValue))
-			&& !UT_strcmp(szValue, "subscript")
+			&& !strcmp(szValue, "subscript")
 			)
 		{
 			_handleAttributeOff((char) 6);  // FIXME: use defines
@@ -645,7 +645,7 @@ void WordPerfect_Listener::_closeSpan()
 		
 		if (
 			(pAP->getProperty("font-style", szValue))
-			&& !UT_strcmp(szValue, "italic")
+			&& !strcmp(szValue, "italic")
 			)
 		{
 			_handleAttributeOff((char) 8);  // FIXME: use defines
@@ -653,7 +653,7 @@ void WordPerfect_Listener::_closeSpan()
 
 		if (
 			(pAP->getProperty("font-weight", szValue))
-			&& !UT_strcmp(szValue, "bold")
+			&& !strcmp(szValue, "bold")
 			)
 		{
 			_handleAttributeOff((char) 12); // FIXME: use defines
@@ -663,20 +663,20 @@ void WordPerfect_Listener::_closeSpan()
 			(pAP->getProperty("text-decoration", szValue))
 			)
 		{
-			const XML_Char* pszDecor = szValue;
+			const gchar* pszDecor = szValue;
 
-			XML_Char* p;
-			if (!UT_cloneString((char *&)p, pszDecor))
+			gchar* p;
+			if (!(p = g_strdup(pszDecor)))
 			{
 				// TODO outofmem
 			}
 
 			UT_return_if_fail(p || !pszDecor);
-			XML_Char*	q = strtok(p, " ");
+			gchar*	q = strtok(p, " ");
 
 			while (q)
 			{
-				if (0 == UT_strcmp(q, "line-through"))
+				if (0 == strcmp(q, "line-through"))
 				{
 					_handleAttributeOff((char) 13);  // FIXME: use defines
 				}
@@ -691,20 +691,20 @@ void WordPerfect_Listener::_closeSpan()
 			(pAP->getProperty("text-decoration", szValue))
 			)
 		{
-			const XML_Char* pszDecor = szValue;
+			const gchar* pszDecor = szValue;
 
-			XML_Char* p;
-			if (!UT_cloneString((char *&)p, pszDecor))
+			gchar* p;
+			if (!(p = g_strdup(pszDecor)))
 			{
 				// TODO outofmem
 			}
 
 			UT_return_if_fail(p || !pszDecor);
-			XML_Char*	q = strtok(p, " ");
+			gchar*	q = strtok(p, " ");
 
 			while (q)
 			{
-				if (0 == UT_strcmp(q, "underline"))
+				if (0 == strcmp(q, "underline"))
 				{
 					_handleAttributeOff((char) 14);  // FIXME: use defines
 				}
