@@ -246,7 +246,7 @@ IE_Imp_WordPerfect_Sniffer::~IE_Imp_WordPerfect_Sniffer()
 static IE_SuffixConfidence IE_Imp_WordPerfect_Sniffer__SuffixConfidence[] = {
 	{ "wpd", 	UT_CONFIDENCE_PERFECT 	},
 	{ "wp", 	UT_CONFIDENCE_PERFECT 	},
-	{ NULL, 	UT_CONFIDENCE_ZILCH 	}
+	{ "", 	UT_CONFIDENCE_ZILCH 	}
 };
 
 const IE_SuffixConfidence * IE_Imp_WordPerfect_Sniffer::getSuffixConfidence ()
@@ -420,7 +420,7 @@ void IE_Imp_WordPerfect::openHeader(const WPXPropertyList &propList)
 			break;
 	}
  
-	const XML_Char* propsArray[3];
+	const gchar* propsArray[3];
 	propsArray[0] = "props";
 	propsArray[1] = propBuffer.c_str();
 	propsArray[2] = NULL;	
@@ -540,7 +540,7 @@ void IE_Imp_WordPerfect::openParagraph(const WPXPropertyList &propList, const WP
 	
 
 	UT_DEBUGMSG(("AbiWordPerfect: Appending paragraph properties: %s\n", propBuffer.c_str()));
-	const XML_Char* propsArray[3];
+	const gchar* propsArray[3];
 	propsArray[0] = "props";
 	propsArray[1] = propBuffer.c_str();
 	propsArray[2] = NULL;
@@ -566,7 +566,7 @@ void IE_Imp_WordPerfect::openSpan(const WPXPropertyList &propList)
 	if (m_bHdrFtrOpenCount) return; // HACK
 	UT_DEBUGMSG(("AbiWordPerfect: Appending current text properties\n"));
 	
-	XML_Char* pProps = "props";
+	gchar* pProps = "props";
 	UT_String propBuffer;
 	UT_String tempBuffer;
 	
@@ -624,7 +624,7 @@ void IE_Imp_WordPerfect::openSpan(const WPXPropertyList &propList)
 	}
 
 	UT_DEBUGMSG(("AbiWordPerfect: Appending span format: %s\n", propBuffer.c_str()));
-	const XML_Char* propsArray[5];
+	const gchar* propsArray[5];
 	
 	propsArray[0] = pProps;
 	propsArray[1] = propBuffer.c_str();
@@ -832,7 +832,7 @@ void IE_Imp_WordPerfect::openListElement(const WPXPropertyList &propList, const
 		UT_String_sprintf(szParentID,"0"); 
 	UT_String_sprintf(szLevel,"%d", m_iCurrentListLevel);
 	
-	const XML_Char* listAttribs[PT_MAX_ATTRIBUTES*2 + 1];
+	const gchar* listAttribs[PT_MAX_ATTRIBUTES*2 + 1];
 	UT_uint32 attribsCount=0;
 	
 	listAttribs[attribsCount++] = PT_LISTID_ATTRIBUTE_NAME;
@@ -890,7 +890,7 @@ void IE_Imp_WordPerfect::openListElement(const WPXPropertyList &propList, const
 	UT_DEBUGMSG(("WordPerfect: LISTS - Appended a list tag def'n (character props)\n"));
 	
 	// append a list field label
-	const XML_Char* fielddef[5];
+	const gchar* fielddef[5];
 	fielddef[0] ="type";
 	fielddef[1] = "list_label";
 	fielddef[2] = NULL;
@@ -906,12 +906,12 @@ void IE_Imp_WordPerfect::openFootnote(const WPXPropertyList &propList)
 {
 	if (m_bHdrFtrOpenCount) return; // HACK
 
-	const XML_Char** propsArray = NULL;
+	const gchar** propsArray = NULL;
 	
 	UT_String footnoteId;
 	UT_String_sprintf(footnoteId,"%i",UT_rand());	
 	
-	propsArray = static_cast<const XML_Char **>(UT_calloc(7, sizeof(XML_Char *)));
+	propsArray = static_cast<const gchar **>(UT_calloc(7, sizeof(gchar *)));
 	propsArray [0] = "type";
 	propsArray [1] = "footnote_ref";
 	propsArray [2] = "footnote-id";
@@ -921,12 +921,12 @@ void IE_Imp_WordPerfect::openFootnote(const WPXPropertyList &propList)
 	propsArray [6] = NULL;
 	X_CheckDocumentError(appendObject(PTO_Field, propsArray));
 
-	const XML_Char * attribs[3] ={"footnote-id", footnoteId.c_str(), NULL};
+	const gchar * attribs[3] ={"footnote-id", footnoteId.c_str(), NULL};
 	X_CheckDocumentError(appendStrux(PTX_SectionFootnote,attribs));
 	
 	X_CheckDocumentError(appendStrux(PTX_Block,NULL));
 
-	propsArray = static_cast<const XML_Char **>(UT_calloc(7, sizeof(XML_Char *)));
+	propsArray = static_cast<const gchar **>(UT_calloc(7, sizeof(gchar *)));
 	propsArray [0] = "type";
 	propsArray [1] = "footnote_anchor";
 	propsArray [2] = "footnote-id";
@@ -946,12 +946,12 @@ void IE_Imp_WordPerfect::closeFootnote()
 void IE_Imp_WordPerfect::openEndnote(const WPXPropertyList &propList)
 {
 	if (m_bHdrFtrOpenCount) return; // HACK
-	const XML_Char** propsArray = NULL;
+	const gchar** propsArray = NULL;
 	
 	UT_String endnoteId;
 	UT_String_sprintf(endnoteId,"%i",UT_rand());	
 	
-	propsArray = static_cast<const XML_Char **>(UT_calloc(7, sizeof(XML_Char *)));
+	propsArray = static_cast<const gchar **>(UT_calloc(7, sizeof(gchar *)));
 	propsArray [0] = "type";
 	propsArray [1] = "endnote_ref";
 	propsArray [2] = "endnote-id";
@@ -961,12 +961,12 @@ void IE_Imp_WordPerfect::openEndnote(const WPXPropertyList &propList)
 	propsArray [6] = NULL;
 	X_CheckDocumentError(appendObject(PTO_Field, propsArray));
 
-	const XML_Char * attribs[3] ={"endnote-id", endnoteId.c_str(), NULL};
+	const gchar * attribs[3] ={"endnote-id", endnoteId.c_str(), NULL};
 	X_CheckDocumentError(appendStrux(PTX_SectionEndnote,attribs));
 	
 	X_CheckDocumentError(appendStrux(PTX_Block,NULL));
 
-	propsArray = static_cast<const XML_Char **>(UT_calloc(7, sizeof(XML_Char *)));
+	propsArray = static_cast<const gchar **>(UT_calloc(7, sizeof(gchar *)));
 	propsArray [0] = "type";
 	propsArray [1] = "endnote_anchor";
 	propsArray [2] = "endnote-id";
@@ -1018,7 +1018,7 @@ void IE_Imp_WordPerfect::openTable(const WPXPropertyList &propList, const WPXPro
 		propBuffer += tmpBuffer;
 	}
 
-	const XML_Char* propsArray[3];
+	const gchar* propsArray[3];
 	propsArray[0] = "props";
 	propsArray[1] = propBuffer.c_str();
 	propsArray[2] = NULL;
@@ -1093,7 +1093,7 @@ void IE_Imp_WordPerfect::openTableCell(const WPXPropertyList &propList)
 	
 	UT_DEBUGMSG(("AbiWordPerfect: Inserting a Cell definition: %s\n", propBuffer.c_str()));
 	
-	const XML_Char* propsArray[3];
+	const gchar* propsArray[3];
 	propsArray[0] = "props";
 	propsArray[1] = propBuffer.c_str();
 	propsArray[2] = NULL;
@@ -1128,11 +1128,11 @@ UT_Error IE_Imp_WordPerfect::_appendSection(int numColumns, const float marginLe
 	UT_LocaleTransactor lt(LC_NUMERIC, "C");
 	myProps += UT_String_sprintf("columns:%d; page-margin-left:%.4fin; page-margin-right:%.4fin", numColumns, marginLeft, marginRight);
 	
-	XML_Char * propsArray[3];
+	gchar * propsArray[3];
 	propsArray[0] = "props";
-	propsArray[1] = const_cast<XML_Char*>(reinterpret_cast<const XML_Char*>(myProps.c_str()));
+	propsArray[1] = const_cast<gchar*>(reinterpret_cast<const gchar*>(myProps.c_str()));
 	propsArray[2] = NULL ;
-	X_CheckDocumentError(appendStrux(PTX_Section, (const XML_Char**)propsArray));
+	X_CheckDocumentError(appendStrux(PTX_Section, (const gchar**)propsArray));
 	
 	m_bInSection = true;
 
@@ -1166,7 +1166,7 @@ UT_Error IE_Imp_WordPerfect::_updateDocumentOrderedListDefinition(ABI_ListDefini
 								   pListDefinition->getListID((iLevel-1)), 
 								   pListDefinition->getListType(1), 
 								   iStartingNumber, 
-								   const_cast<XML_Char*>(reinterpret_cast<const XML_Char*>("%L")), 
+								   const_cast<gchar*>(reinterpret_cast<const gchar*>("%L")), 
 								   ".", 
 								   getDoc(), 
 								   NULL);
@@ -1181,7 +1181,7 @@ UT_Error IE_Imp_WordPerfect::_updateDocumentOrderedListDefinition(ABI_ListDefini
 			sNumberingString += sTextAfterNumber;
 	
 			pAuto = new fl_AutoNum(pListDefinition->getListID(iLevel), 0, pListDefinition->getListType(iLevel), iStartingNumber, 
-								   const_cast<XML_Char*>(reinterpret_cast<const XML_Char*>(sNumberingString.utf8_str())), ".", getDoc(), NULL);
+								   const_cast<gchar*>(reinterpret_cast<const gchar*>(sNumberingString.utf8_str())), ".", getDoc(), NULL);
 		}
 		getDoc()->addList(pAuto);
 	}
@@ -1209,11 +1209,11 @@ UT_Error IE_Imp_WordPerfect::_updateDocumentUnorderedListDefinition(ABI_ListDefi
 		if (iLevel > 1) 
 		{	
 			pAuto = new fl_AutoNum(pListDefinition->getListID(iLevel), pListDefinition->getListID((iLevel-1)), 
-								   pListDefinition->getListType(1), 0, const_cast<XML_Char*>(reinterpret_cast<const XML_Char*>("%L")), ".", getDoc(), NULL);
+								   pListDefinition->getListType(1), 0, const_cast<gchar*>(reinterpret_cast<const gchar*>("%L")), ".", getDoc(), NULL);
 		}   
 		else
 			pAuto = new fl_AutoNum(pListDefinition->getListID(iLevel), 0, pListDefinition->getListType(iLevel), 0, 
-								   const_cast<XML_Char*>(reinterpret_cast<const XML_Char*>("%L")), ".", getDoc(), NULL);
+								   const_cast<gchar*>(reinterpret_cast<const gchar*>("%L")), ".", getDoc(), NULL);
 		  
 		getDoc()->addList(pAuto);
 	}
@@ -1276,7 +1276,7 @@ IE_Imp_MSWorks_Sniffer::~IE_Imp_MSWorks_Sniffer()
 // supported suffixes
 static IE_SuffixConfidence IE_Imp_MSWorks_Sniffer__SuffixConfidence[] = {
 	{ "wps", 	UT_CONFIDENCE_PERFECT 	},
-	{ NULL, 	UT_CONFIDENCE_ZILCH 	}
+	{ "", 	UT_CONFIDENCE_ZILCH 	}
 };
 
 const IE_SuffixConfidence * IE_Imp_MSWorks_Sniffer::getSuffixConfidence ()
