@@ -65,7 +65,7 @@ IE_Exp_XSL_FO_Sniffer::IE_Exp_XSL_FO_Sniffer (const char * name) :
 
 bool IE_Exp_XSL_FO_Sniffer::recognizeSuffix(const char * szSuffix)
 {
-	return (!UT_stricmp(szSuffix, ".fo"));
+	return (!g_ascii_strcasecmp(szSuffix, ".fo"));
 }
 
 UT_Error IE_Exp_XSL_FO_Sniffer::constructExporter(PD_Document * pDocument,
@@ -626,11 +626,11 @@ void s_XSL_FO_Listener::_handleBookmark(PT_AttrPropIndex api)
 {
 	const PP_AttrProp * pAP = NULL;
 	bool bHaveProp = m_pDocument->getAttrProp(api,&pAP);
-	const XML_Char* szValue = NULL;
+	const gchar* szValue = NULL;
 
 	if(bHaveProp && pAP && pAP->getAttribute("type", szValue) && szValue)
 	{
-		if(!UT_strcmp(szValue, "start") && pAP->getAttribute("name", szValue) && szValue)
+		if(!strcmp(szValue, "start") && pAP->getAttribute("name", szValue) && szValue)
 		{
 			UT_UTF8String buf, anchor = szValue;
 			anchor.escapeXML();
@@ -650,7 +650,7 @@ void s_XSL_FO_Listener::_handleEmbedded(PT_AttrPropIndex api)
 {
 	const PP_AttrProp * pAP = NULL;
 	bool bHaveProp = m_pDocument->getAttrProp(api,&pAP);
-	const XML_Char* szValue = NULL;
+	const gchar* szValue = NULL;
 
 	UT_return_if_fail(bHaveProp && pAP && pAP->getAttribute("dataid", szValue) && szValue);
 
@@ -659,7 +659,7 @@ void s_XSL_FO_Listener::_handleEmbedded(PT_AttrPropIndex api)
 	buf = "snapshot-png-";
 	buf += szValue;
 	buf.escapeXML();
-	char* dataid = UT_strdup(buf.utf8_str());
+	char* dataid = g_strdup(buf.utf8_str());
 	m_utvDataIDs.push_back(dataid);
 
 	url = UT_go_basename(m_pie->getFileName());
@@ -700,14 +700,14 @@ void s_XSL_FO_Listener::_handleField(const PX_ChangeRecord_Object * pcro, PT_Att
 	
 	if (bHaveProp && pAP)
 	{
-		const XML_Char* szValue = NULL;
+		const gchar* szValue = NULL;
 		if (pAP->getAttribute("type", szValue) && szValue)
 		{
 			fd_Field * field = pcro->getField();
 
 			m_pie->populateFields ();
 
-			if((_tagTop() == TT_LISTBLOCK) && !UT_strcmp(static_cast<const char*>(szValue), "list_label"))
+			if((_tagTop() == TT_LISTBLOCK) && !strcmp(static_cast<const char*>(szValue), "list_label"))
 			{
 				m_pie->write("\n");
 
@@ -716,7 +716,7 @@ void s_XSL_FO_Listener::_handleField(const PX_ChangeRecord_Object * pcro, PT_Att
 				_tagOpen(TT_BLOCK, "block", false);
 
 				UT_UTF8String label = "";
-				for(int i = 0; i < m_Lists.getItemCount(); i++)
+				for(UT_uint32 i = 0; i < m_Lists.getItemCount(); i++)
 				{
 					ListHelper * lh = m_Lists[i];
 					if(lh && ((*lh).retrieveID() == m_iListID))
@@ -737,7 +737,7 @@ void s_XSL_FO_Listener::_handleField(const PX_ChangeRecord_Object * pcro, PT_Att
 				m_iBlockDepth++;
 				m_bWroteListField = true;
 			}
-			else if(!UT_strcmp(szValue, "footnote_ref"))
+			else if(!strcmp(szValue, "footnote_ref"))
 			{
 				UT_UTF8String buf = field->getValue();
 				buf.escapeXML();
@@ -766,7 +766,7 @@ void s_XSL_FO_Listener::_handleFrame(PT_AttrPropIndex api)
 {
 	const PP_AttrProp * pAP = NULL;
 	bool bHaveProp = m_pDocument->getAttrProp(api,&pAP);
-	const XML_Char * szValue = NULL;
+	const gchar * szValue = NULL;
 
 	if(pAP && bHaveProp && (pAP->getAttribute("strux-image-dataid", szValue)) && szValue)
 	{
@@ -781,7 +781,7 @@ void s_XSL_FO_Listener::_handleHyperlink(PT_AttrPropIndex api)
 {
 	const PP_AttrProp * pAP = NULL;
 	bool bHaveProp = m_pDocument->getAttrProp(api,&pAP);
-	const XML_Char* szValue = NULL;
+	const gchar* szValue = NULL;
 
 	if(bHaveProp && pAP && pAP->getAttribute("xlink:href", szValue) && szValue)
 	{
@@ -822,11 +822,11 @@ void s_XSL_FO_Listener::_handleImage(PT_AttrPropIndex api)
 {
 	const PP_AttrProp * pAP = NULL;
 	bool bHaveProp = m_pDocument->getAttrProp(api,&pAP);
-	const XML_Char* szValue = NULL;
+	const gchar* szValue = NULL;
 
 	UT_return_if_fail(bHaveProp && pAP && pAP->getAttribute("dataid", szValue) && szValue);
 
-	char * dataid = UT_strdup(const_cast<char*>(szValue));
+	char * dataid = g_strdup(const_cast<char*>(szValue));
 	m_utvDataIDs.push_back(dataid);
 
 	UT_UTF8String buf, img, url;
@@ -868,11 +868,11 @@ void s_XSL_FO_Listener::_handlePositionedImage(PT_AttrPropIndex api)
 
 	const PP_AttrProp * pAP = NULL;
 	bool bHaveProp = m_pDocument->getAttrProp(api,&pAP);
-	const XML_Char* szValue = NULL;
+	const gchar* szValue = NULL;
 
 	UT_return_if_fail(bHaveProp && pAP && pAP->getAttribute("strux-image-dataid", szValue) && szValue);
 
-	char * dataid = UT_strdup(const_cast<char*>(szValue));
+	char * dataid = g_strdup(const_cast<char*>(szValue));
 	m_utvDataIDs.push_back(dataid);
 
 	UT_UTF8String buf, img, url;
@@ -912,7 +912,7 @@ void s_XSL_FO_Listener::_handleMath(PT_AttrPropIndex api)
 {
 	const PP_AttrProp * pAP = NULL;
 	bool bHaveProp = m_pDocument->getAttrProp(api,&pAP);
-	const XML_Char* szValue = NULL;
+	const gchar* szValue = NULL;
 
 	UT_return_if_fail(bHaveProp && pAP && pAP->getAttribute("dataid", szValue) && szValue);
 
@@ -923,7 +923,7 @@ void s_XSL_FO_Listener::_handleMath(PT_AttrPropIndex api)
 	buf = "snapshot-png-";
 	buf += szValue;
 	buf.escapeXML();
-	char * dataid = UT_strdup(buf.utf8_str());
+	char * dataid = g_strdup(buf.utf8_str());
 	m_utvDataIDs.push_back(dataid);
 
 	url = UT_go_basename(m_pie->getFileName());
@@ -1067,11 +1067,11 @@ bool s_XSL_FO_Listener::populateStrux(PL_StruxDocHandle sdh,
 		const PP_AttrProp* pAP = NULL;
 		if (m_pDocument->getAttrProp(api, &pAP) && pAP)
 		{
-			const XML_Char* pszSectionType = NULL;
+			const gchar* pszSectionType = NULL;
 			pAP->getAttribute("type", pszSectionType);
 			if (
 				!pszSectionType
-				|| (0 == UT_strcmp(pszSectionType, "doc"))
+				|| (0 == strcmp(pszSectionType, "doc"))
 				)
 			{
 				_openSection(pcr->getIndexAP());
@@ -1294,7 +1294,7 @@ void s_XSL_FO_Listener::_handlePageSize(PT_AttrPropIndex api)
 	// todo - validate these and make sure they all make sense
 	if (bHaveProp && pAP)
 	{
-		const XML_Char * szValue = NULL;
+		const gchar * szValue = NULL;
 
 		szValue = PP_evalProperty("page-margin-top",
 								  NULL, NULL, pAP, m_pDocument, true);
@@ -1367,7 +1367,7 @@ void s_XSL_FO_Listener::_handleDataItems(void)
 		UT_sint32 loc = -1;
 		for (UT_uint32 i = 0; i < m_utvDataIDs.getItemCount(); i++)
 		{
-			if(UT_strcmp(const_cast<char*>(reinterpret_cast<const char*>(m_utvDataIDs[i])), szName) == 0)
+			if(strcmp(const_cast<char*>(reinterpret_cast<const char*>(m_utvDataIDs[i])), szName) == 0)
 			{
 				loc = i;
 				break;
@@ -1381,9 +1381,9 @@ void s_XSL_FO_Listener::_handleDataItems(void)
 			UT_UTF8String_sprintf(fname, "%s_data", m_pie->getFileName());
 			UT_go_directory_create(fname.utf8_str(), 0750, NULL);
 
-			if (!UT_strcmp(szMimeType, "image/svg+xml"))
+			if (!strcmp(szMimeType, "image/svg+xml"))
 				UT_UTF8String_sprintf(fname, "%s/%d.svg", fname.utf8_str(), loc);
-			if (!UT_strcmp(szMimeType, "application/mathml+xml"))
+			if (!strcmp(szMimeType, "application/mathml+xml"))
 				UT_UTF8String_sprintf(fname, "%s/%d.mathml", fname.utf8_str(), loc);
 			else // PNG Image
 			{  
@@ -1439,7 +1439,7 @@ void s_XSL_FO_Listener::_openBlock(PT_AttrPropIndex api)
 	UT_UTF8String buf;
 	const PP_AttrProp* pAP = 0;
 	bool bHaveProp = m_pDocument->getAttrProp(api, &pAP), bList = false;
-	const XML_Char* szValue = NULL;
+	const gchar* szValue = NULL;
 
 	if(bHaveProp && pAP && pAP->getAttribute("level", szValue) && szValue)
 	{
@@ -1544,7 +1544,7 @@ void s_XSL_FO_Listener::_openSpan(PT_AttrPropIndex api)
 	// query and output properties
 	if (bHaveProp && pAP)
 	{
-		const XML_Char * szValue = NULL;
+		const gchar * szValue = NULL;
 
 		if (pAP->getProperty("bgcolor", szValue) && szValue)
 		{
