@@ -61,7 +61,7 @@ IE_Imp_XSL_FO_Sniffer::IE_Imp_XSL_FO_Sniffer (const char * name) :
 // supported suffixes
 static IE_SuffixConfidence IE_Imp_XSL_FO_Sniffer__SuffixConfidence[] = {
 	{ "fo", 	UT_CONFIDENCE_PERFECT 	},
-	{ NULL, 	UT_CONFIDENCE_ZILCH 	}
+	{ "", 	UT_CONFIDENCE_ZILCH 	}
 };
 
 const IE_SuffixConfidence * IE_Imp_XSL_FO_Sniffer::getSuffixConfidence ()
@@ -137,8 +137,12 @@ IE_Imp_XSL_FO::IE_Imp_XSL_FO(PD_Document * pDocument)
 	  m_iListDepth(0),
 	  m_iListBlockDepth(0),
 	  m_iTableDepth(0),
+	  m_iFootnotes(0),
 	  m_iImages(0),
 	  m_bOpenedLink(false),
+	  m_bPendingFootnote(false),
+	  m_bInFootnote(false),
+	  m_bIgnoreFootnoteBlock(false),
 	  m_TableHelperStack(new IE_Imp_TableHelperStack())
 {
 }
@@ -202,8 +206,8 @@ static struct xmlToIdMapping s_Tokens[] =
 
 #define USED() do {if(used) sBuf+="; "; else used = true;} while (0)
 
-void IE_Imp_XSL_FO::startElement(const XML_Char *name,
-								  const XML_Char **atts)
+void IE_Imp_XSL_FO::startElement(const gchar *name,
+								  const gchar **atts)
 {
 	UT_DEBUGMSG(("XSL-FO import: startElement: %s\n", name));
 
@@ -213,13 +217,13 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 	UT_uint32 tokenIndex = _mapNameToToken (name, s_Tokens, TokenTableSize);
 	m_utnsTagStack.push(tokenIndex);
 
-    const XML_Char * buf[3];
-    const XML_Char ** p_atts;
-	buf[0] = static_cast<const XML_Char *>("props");
+    const gchar * buf[3];
+    const gchar ** p_atts;
+	buf[0] = static_cast<const gchar *>("props");
 	buf[2] = NULL;
 	
 	UT_UTF8String sBuf;
-	const XML_Char * pVal = NULL;
+	const gchar * pVal = NULL;
 	
 	bool used = false;
 
@@ -236,17 +240,21 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 		{
 			X_VerifyParseState(_PS_Doc);
 			m_parseState = _PS_Sec;
-			X_CheckError(appendStrux(PTX_Section,static_cast<const XML_Char **>(NULL)));
+			X_CheckError(appendStrux(PTX_Section,static_cast<const gchar **>(NULL)));
 			break;
 		}
 
 		case TT_BLOCK:
 		{
 			X_CheckError((m_parseState == _PS_Sec) || (m_parseState == _PS_Block) || (m_parseState == _PS_List)); //blocks can be nested
+
+			if(m_bIgnoreFootnoteBlock)
+				break; // we want to ignore the first <fo:block> in <fo:footnote-body> because it appends an unwanted "break" before the footnote text
+
 			m_parseState = _PS_Block;
 			m_iBlockDepth++;
 
-			pVal = static_cast<const XML_Char*>(_getXMLPropValue("background-color", atts));
+			pVal = static_cast<const gchar*>(_getXMLPropValue("background-color", atts));
 			if (pVal)
 			{
 				USED();
@@ -254,7 +262,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 				sBuf += static_cast<const char *>(pVal);
 			}
 
-			pVal = static_cast<const XML_Char*>(_getXMLPropValue("color", atts));
+			pVal = static_cast<const gchar*>(_getXMLPropValue("color", atts));
 			if (pVal)
 			{
 				USED();
@@ -262,7 +270,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 				sBuf += static_cast<const char *>(pVal);
 			}
 
-			pVal = static_cast<const XML_Char*>(_getXMLPropValue("language", atts));
+			pVal = static_cast<const gchar*>(_getXMLPropValue("language", atts));
 			if (pVal)
 			{
 				USED();
@@ -270,7 +278,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 				sBuf += static_cast<const char *>(pVal);
 			}
 
-			pVal = static_cast<const XML_Char*>(_getXMLPropValue("font-size", atts));
+			pVal = static_cast<const gchar*>(_getXMLPropValue("font-size", atts));
 			if (pVal)
 			{
 				USED();
@@ -278,7 +286,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 				sBuf += static_cast<const char *>(pVal);
 			}
 			
-			pVal = static_cast<const XML_Char*>(_getXMLPropValue("font-family", atts));
+			pVal = static_cast<const gchar*>(_getXMLPropValue("font-family", atts));
 			if (pVal)
 			{
 				USED();
@@ -286,7 +294,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 				sBuf += static_cast<const char *>(pVal);
 			}
 
-			pVal = static_cast<const XML_Char*>(_getXMLPropValue("font-weight", atts));
+			pVal = static_cast<const gchar*>(_getXMLPropValue("font-weight", atts));
 			if (pVal)
 			{
 				USED();
@@ -294,7 +302,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 				sBuf += static_cast<const char *>(pVal);
 			}
 
-			pVal = static_cast<const XML_Char*>(_getXMLPropValue("font-style", atts));
+			pVal = static_cast<const gchar*>(_getXMLPropValue("font-style", atts));
 			if (pVal)
 			{
 				USED();
@@ -302,7 +310,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 				sBuf += static_cast<const char *>(pVal);
 			}
 
-			pVal = static_cast<const XML_Char*>(_getXMLPropValue("font-stretch", atts));
+			pVal = static_cast<const gchar*>(_getXMLPropValue("font-stretch", atts));
 			if (pVal)
 			{
 				USED();
@@ -310,7 +318,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 				sBuf += static_cast<const char *>(pVal);
 			}
 
-			pVal = static_cast<const XML_Char*>(_getXMLPropValue("keep-together", atts));
+			pVal = static_cast<const gchar*>(_getXMLPropValue("keep-together", atts));
 			if (pVal)
 			{
 				USED();
@@ -318,7 +326,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 				sBuf += static_cast<const char *>(pVal);
 			}
 
-			pVal = static_cast<const XML_Char*>(_getXMLPropValue("keep-with-next", atts));
+			pVal = static_cast<const gchar*>(_getXMLPropValue("keep-with-next", atts));
 			if (pVal)
 			{
 				USED();
@@ -326,7 +334,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 				sBuf += static_cast<const char *>(pVal);
 			}
 
-			pVal = static_cast<const XML_Char*>(_getXMLPropValue("line-height", atts));
+			pVal = static_cast<const gchar*>(_getXMLPropValue("line-height", atts));
 			if (pVal)
 			{
 				USED();
@@ -334,7 +342,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 				sBuf += static_cast<const char *>(pVal);
 			}
 
-			pVal = static_cast<const XML_Char*>(_getXMLPropValue("margin-bottom", atts));
+			pVal = static_cast<const gchar*>(_getXMLPropValue("margin-bottom", atts));
 			if (pVal)
 			{
 				USED();
@@ -342,7 +350,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 				sBuf += static_cast<const char *>(pVal);
 			}
 
-			pVal = static_cast<const XML_Char*>(_getXMLPropValue("margin-top", atts));
+			pVal = static_cast<const gchar*>(_getXMLPropValue("margin-top", atts));
 			if (pVal)
 			{
 				USED();
@@ -350,7 +358,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 				sBuf += static_cast<const char *>(pVal);
 			}
 
-			pVal = static_cast<const XML_Char*>(_getXMLPropValue("margin-left", atts));
+			pVal = static_cast<const gchar*>(_getXMLPropValue("margin-left", atts));
 			if (pVal)
 			{
 				USED();
@@ -358,7 +366,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 				sBuf += static_cast<const char *>(pVal);
 			}
 
-			pVal = static_cast<const XML_Char*>(_getXMLPropValue("margin-right", atts));
+			pVal = static_cast<const gchar*>(_getXMLPropValue("margin-right", atts));
 			if (pVal)
 			{
 				USED();
@@ -366,7 +374,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 				sBuf += static_cast<const char *>(pVal);
 			}
 
-			pVal = static_cast<const XML_Char*>(_getXMLPropValue("text-align", atts));
+			pVal = static_cast<const gchar*>(_getXMLPropValue("text-align", atts));
 			if (pVal)
 			{
 				USED();
@@ -374,7 +382,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 				sBuf += static_cast<const char *>(pVal);
 			}
 
-			pVal = static_cast<const XML_Char*>(_getXMLPropValue("widows", atts));
+			pVal = static_cast<const gchar*>(_getXMLPropValue("widows", atts));
 			if (pVal)
 			{
 				USED();
@@ -400,12 +408,55 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 		case TT_FOOTNOTE:
 		{
 			X_CheckError((m_parseState == _PS_Sec) || (m_parseState == _PS_Block) || (m_parseState == _PS_List));
+			UT_return_if_fail(m_bPendingFootnote == false);
+
+			UT_UTF8String id = UT_UTF8String_sprintf("%d", ++m_iFootnotes);
+
+			gchar *buf[7];
+			buf[0] = PT_TYPE_ATTRIBUTE_NAME;
+			buf[1] = "footnote_ref";
+			buf[2] = "footnote-id";
+			buf[3] = (gchar*)id.utf8_str();
+			buf[4] = PT_PROPS_ATTRIBUTE_NAME;
+			buf[5] = "text-position:superscript";
+			buf[6] = NULL;
+			X_CheckError(appendObject(PTO_Field,const_cast<const gchar **>(buf)));
+
+			m_bPendingFootnote = true;
+
 			break;
 		}
 
 		case TT_FOOTNOTEBODY:
 		{
 			X_CheckError((m_parseState == _PS_Sec) || (m_parseState == _PS_Block) || (m_parseState == _PS_List));
+			X_CheckError(m_bPendingFootnote);
+			m_bPendingFootnote = false;
+
+			UT_UTF8String id = UT_UTF8String_sprintf("%d", m_iFootnotes);			
+			char * val = g_strdup(id.utf8_str());
+			X_CheckError(val);
+
+			gchar *notebuf[3];
+			notebuf[0] = "footnote-id";
+			notebuf[1] = (gchar*)val;
+			notebuf[2] = NULL;
+			X_CheckError(appendStrux(PTX_SectionFootnote,const_cast<const gchar **>(notebuf)));
+
+			gchar *anchorbuf[7];
+			anchorbuf[0] = PT_TYPE_ATTRIBUTE_NAME;
+			anchorbuf[1] = "footnote_anchor";
+			anchorbuf[2] = "footnote-id";
+			anchorbuf[3] = (gchar*)val;
+			anchorbuf[4] = PT_PROPS_ATTRIBUTE_NAME;
+			anchorbuf[5] = "text-position:superscript";
+			anchorbuf[6] = NULL;
+			X_CheckError(appendObject(PTO_Field,const_cast<const gchar **>(anchorbuf)));
+
+			FREEP(val);
+			m_bInFootnote = true;
+			m_bIgnoreFootnoteBlock = true;
+
 			break;
 		}
 
@@ -415,8 +466,11 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 		case TT_INLINE:
 		{
 			X_VerifyParseState(_PS_Block);
+			if(m_bPendingFootnote)
+				break;
+
 			{
-				pVal = static_cast<const XML_Char*>(_getXMLPropValue("background-color", atts));
+				pVal = static_cast<const gchar*>(_getXMLPropValue("background-color", atts));
 				if (pVal)
 				{
 					USED();
@@ -424,7 +478,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 					sBuf += static_cast<const char *>(pVal);
 				}
 
-				pVal = static_cast<const XML_Char*>(_getXMLPropValue("color", atts));
+				pVal = static_cast<const gchar*>(_getXMLPropValue("color", atts));
 				if (pVal)
 				{
 					USED();
@@ -432,7 +486,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 					sBuf += static_cast<const char *>(pVal);
 				}
 
-				pVal = static_cast<const XML_Char*>(_getXMLPropValue("language", atts));
+				pVal = static_cast<const gchar*>(_getXMLPropValue("language", atts));
 				if (pVal)
 				{
 					USED();
@@ -440,7 +494,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 					sBuf += static_cast<const char *>(pVal);
 				}
 
-				pVal = static_cast<const XML_Char*>(_getXMLPropValue("font-size", atts));
+				pVal = static_cast<const gchar*>(_getXMLPropValue("font-size", atts));
 				if (pVal)
 				{
 					USED();
@@ -448,7 +502,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 					sBuf += static_cast<const char *>(pVal);
 				}
 				
-				pVal = static_cast<const XML_Char*>(_getXMLPropValue("font-family", atts));
+				pVal = static_cast<const gchar*>(_getXMLPropValue("font-family", atts));
 				if (pVal)
 				{
 					USED();
@@ -456,7 +510,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 					sBuf += static_cast<const char *>(pVal);
 				}
 
-				pVal = static_cast<const XML_Char*>(_getXMLPropValue("font-weight", atts));
+				pVal = static_cast<const gchar*>(_getXMLPropValue("font-weight", atts));
 				if (pVal)
 				{
 					USED();
@@ -464,7 +518,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 					sBuf += static_cast<const char *>(pVal);
 				}
 
-				pVal = static_cast<const XML_Char*>(_getXMLPropValue("font-style", atts));
+				pVal = static_cast<const gchar*>(_getXMLPropValue("font-style", atts));
 				if (pVal)
 				{
 					USED();
@@ -472,7 +526,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 					sBuf += static_cast<const char *>(pVal);
 				}
 
-				pVal = static_cast<const XML_Char*>(_getXMLPropValue("font-stretch", atts));
+				pVal = static_cast<const gchar*>(_getXMLPropValue("font-stretch", atts));
 				if (pVal)
 				{
 					USED();
@@ -480,7 +534,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 					sBuf += static_cast<const char *>(pVal);
 				}
 
-				pVal = static_cast<const XML_Char*>(_getXMLPropValue("keep-together", atts));
+				pVal = static_cast<const gchar*>(_getXMLPropValue("keep-together", atts));
 				if (pVal)
 				{
 					USED();
@@ -488,7 +542,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 					sBuf += static_cast<const char *>(pVal);
 				}
 
-				pVal = static_cast<const XML_Char*>(_getXMLPropValue("keep-with-next", atts));
+				pVal = static_cast<const gchar*>(_getXMLPropValue("keep-with-next", atts));
 				if (pVal)
 				{
 					USED();
@@ -496,7 +550,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 					sBuf += static_cast<const char *>(pVal);
 				}
 
-				pVal = static_cast<const XML_Char*>(_getXMLPropValue("text-decoration", atts));
+				pVal = static_cast<const gchar*>(_getXMLPropValue("text-decoration", atts));
 				if (pVal)
 				{
 					USED();
@@ -508,22 +562,22 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 
 				xxx_UT_DEBUGMSG(("FO import: inline props='%s'\n", sBuf.utf8_str()));
 
-				p_atts = static_cast<const XML_Char **>(&buf[0]);
+				p_atts = static_cast<const gchar **>(&buf[0]);
 				X_CheckError(_pushInlineFmt(p_atts));
 				X_CheckError(appendFmt(&m_vecInlineFmt));
 
-				pVal = static_cast<const XML_Char*>(_getXMLPropValue("id", atts));
+				pVal = static_cast<const gchar*>(_getXMLPropValue("id", atts));
 				if(pVal)
 				{
-					XML_Char *buf2[5];
+					gchar *buf2[5];
 					buf2[0] = PT_TYPE_ATTRIBUTE_NAME;
 					buf2[1] = "start";
 					buf2[2] = PT_NAME_ATTRIBUTE_NAME;
-					buf2[3] = (XML_Char*)pVal;
+					buf2[3] = (gchar*)pVal;
 					buf2[4] = NULL;
-					X_CheckError(appendObject(PTO_Bookmark, const_cast<const XML_Char **>(buf2)));
+					X_CheckError(appendObject(PTO_Bookmark, const_cast<const gchar **>(buf2)));
 					buf2[1] = "end";
-					X_CheckError(appendObject(PTO_Bookmark, const_cast<const XML_Char **>(buf2)));
+					X_CheckError(appendObject(PTO_Bookmark, const_cast<const gchar **>(buf2)));
 				}
 			}
 			break;
@@ -537,11 +591,11 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 				break;
 			}
 
-			XML_Char *buf[3];
+			gchar *buf[3];
 			buf[2] = NULL;
 
-			XML_Char *p_val = NULL;
-			p_val = (XML_Char *)_getXMLPropValue(static_cast<const XML_Char *>("internal-destination"), atts);
+			gchar *p_val = NULL;
+			p_val = (gchar *)_getXMLPropValue(static_cast<const gchar *>("internal-destination"), atts);
 
 			if(p_val) //internal
 			{
@@ -549,25 +603,25 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 				link += p_val;
 
 				buf[0] = "xlink:href";
-				buf[1] = (XML_Char*)link.utf8_str();
-				X_CheckError(appendObject(PTO_Hyperlink, const_cast<const XML_Char **>(buf)));
+				buf[1] = (gchar*)link.utf8_str();
+				X_CheckError(appendObject(PTO_Hyperlink, const_cast<const gchar **>(buf)));
 				m_bOpenedLink = true;
 				break;
 			}
 
-			p_val = (XML_Char *)_getXMLPropValue(static_cast<const XML_Char *>("external-destination"), atts);
+			p_val = (gchar *)_getXMLPropValue(static_cast<const gchar *>("external-destination"), atts);
 
 			if(p_val) //external
 			{
 				UT_UTF8String link = p_val;
-				int len = UT_XML_strlen(p_val);
+				int len = strlen(p_val);
 				if((len > 7) && (link.substr(0,5) == "url('") && (link.substr(len-2, 2) == "')"))
 				{
 					p_val[len - 2] = '\0';
 					p_val = p_val + 5;
 					buf[0] = "xlink:href";
-					buf[1] = (XML_Char*)p_val;
-					X_CheckError(appendObject(PTO_Hyperlink, const_cast<const XML_Char **>(buf)));
+					buf[1] = (gchar*)p_val;
+					X_CheckError(appendObject(PTO_Hyperlink, const_cast<const gchar **>(buf)));
 					m_bOpenedLink = true;
 				}
 				else
@@ -653,11 +707,11 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 
 			UT_uint32 rowspan = 1, colspan = 1;
 
-			pVal = static_cast<const XML_Char*>(_getXMLPropValue("number-columns-spanned", atts));
+			pVal = static_cast<const gchar*>(_getXMLPropValue("number-columns-spanned", atts));
 			if(pVal)
 				colspan = atoi(pVal);
 
-			pVal = static_cast<const XML_Char*>(_getXMLPropValue("number-rows-spanned", atts));
+			pVal = static_cast<const gchar*>(_getXMLPropValue("number-rows-spanned", atts));
 			if(pVal)
 				rowspan = atoi(pVal);
 
@@ -682,13 +736,13 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 		{
 			X_CheckError((m_parseState == _PS_Block) || (m_parseState == _PS_List) || (m_parseState == _PS_Sec));
 
-			XML_Char *p_val = NULL;
-			p_val = (XML_Char *)_getXMLPropValue(static_cast<const XML_Char *>("src"), atts);
+			gchar *p_val = NULL;
+			p_val = (gchar *)_getXMLPropValue(static_cast<const gchar *>("src"), atts);
 
 			if(p_val)
 			{
 				UT_UTF8String src = p_val;
-				int len = UT_XML_strlen(p_val);
+				int len = strlen(p_val);
 				if((len > 7) && (src.substr(0,5) == "url('") && (src.substr(len-2, 2) == "')"))
 				{
 					p_val[len - 2] = '\0';
@@ -723,7 +777,7 @@ void IE_Imp_XSL_FO::startElement(const XML_Char *name,
 
 #undef USED
 
-void IE_Imp_XSL_FO::endElement(const XML_Char *name)
+void IE_Imp_XSL_FO::endElement(const gchar *name)
 {
 	UT_DEBUGMSG(("XSL-FO import: endElement: %s\n", name));
 
@@ -756,6 +810,12 @@ void IE_Imp_XSL_FO::endElement(const XML_Char *name)
 		{
 			UT_ASSERT_HARMLESS(m_lenCharDataSeen == 0);
 
+			if(m_bIgnoreFootnoteBlock) //we only want to ignore the first block, not all
+			{
+				m_bIgnoreFootnoteBlock = false;
+				break;
+			}
+
 			X_VerifyParseState( _PS_Block);
 			m_iBlockDepth--;
 
@@ -774,12 +834,21 @@ void IE_Imp_XSL_FO::endElement(const XML_Char *name)
 		case TT_FOOTNOTE:
 		{
 			X_CheckError((m_parseState == _PS_Sec) || (m_parseState == _PS_Block) || (m_parseState == _PS_List));
+			X_CheckError(!m_bInFootnote);
 			break;
 		}
 
 		case TT_FOOTNOTEBODY:
 		{
 			X_CheckError((m_parseState == _PS_Sec) || (m_parseState == _PS_Block) || (m_parseState == _PS_List));
+			X_CheckError(m_bInFootnote);
+			X_CheckError(appendStrux(PTX_EndFootnote,static_cast<const gchar **>(NULL)));
+
+			if(m_bIgnoreFootnoteBlock) //there was no block in <fo:footnote-body> (invalid file?)
+			{
+				UT_ASSERT_HARMLESS(UT_SHOULD_NOT_HAPPEN);
+				m_bIgnoreFootnoteBlock = false;
+			}
 
 			if(_isInListTag())
 				m_parseState = _PS_List;
@@ -788,6 +857,8 @@ void IE_Imp_XSL_FO::endElement(const XML_Char *name)
 			else if(m_iBlockDepth == 0)
 				m_parseState = _PS_Sec;
 
+			m_bInFootnote = false;
+
 			break;
 		}
 
@@ -795,8 +866,11 @@ void IE_Imp_XSL_FO::endElement(const XML_Char *name)
 		case TT_CHAR:
 		{
 			UT_ASSERT_HARMLESS(m_lenCharDataSeen==0);
-
 			X_VerifyParseState(_PS_Block);
+
+			if(m_bPendingFootnote)
+				break;
+
 			X_CheckDocument(_getInlineDepth() > 0);
 			_popInlineFmt();
 			X_CheckError(appendFmt(&m_vecInlineFmt));
@@ -946,7 +1020,7 @@ UT_uint32 IE_Imp_XSL_FO::_tagTop(void)
 	return 0;
 }
 
-void IE_Imp_XSL_FO::createImage(const char *name, const XML_Char **atts)
+void IE_Imp_XSL_FO::createImage(const char *name, const gchar **atts)
 {
 	UT_return_if_fail(name && *name && m_szFileName && *m_szFileName);
 
@@ -967,23 +1041,23 @@ void IE_Imp_XSL_FO::createImage(const char *name, const XML_Char **atts)
 	UT_UTF8String dataid;
 	UT_UTF8String_sprintf (dataid, "image%u", static_cast<unsigned int>(m_iImages++));
 
-	const char *mime = UT_strdup("image/png");
+	const char *mime = g_strdup("image/png");
 	UT_return_if_fail(mime);
 	X_CheckError (getDoc()->createDataItem (dataid.utf8_str(), false, pBB, reinterpret_cast<void *>(const_cast<char *>(mime)), NULL));
 
-	XML_Char *buf[5];
+	gchar *buf[5];
 	buf[0] = "dataid";
-	buf[1] = (XML_Char*)dataid.utf8_str();
+	buf[1] = (gchar*)dataid.utf8_str();
 	buf[2] = NULL;
 	buf[3] = NULL;
 	buf[4] = NULL;
 
 	UT_UTF8String props, dim;
-	const XML_Char *p_val = NULL;
+	const gchar *p_val = NULL;
 
 	UT_LocaleTransactor t(LC_NUMERIC, "C");
 
-	p_val = _getXMLPropValue(static_cast<const XML_Char *>("content-height"), atts);
+	p_val = _getXMLPropValue(static_cast<const gchar *>("content-height"), atts);
 
 	if(p_val)
 	{
@@ -993,7 +1067,7 @@ void IE_Imp_XSL_FO::createImage(const char *name, const XML_Char **atts)
 		dim.clear();
 	}
 
-	p_val = _getXMLPropValue(static_cast<const XML_Char *>("content-width"), atts);
+	p_val = _getXMLPropValue(static_cast<const gchar *>("content-width"), atts);
 
 	if(p_val)
 	{
@@ -1008,20 +1082,23 @@ void IE_Imp_XSL_FO::createImage(const char *name, const XML_Char **atts)
 	if(props.length())
 	{
 		buf[2] = PT_PROPS_ATTRIBUTE_NAME;
-		buf[3] = (XML_Char*)props.utf8_str();
+		buf[3] = (gchar*)props.utf8_str();
 	}
 
-	X_CheckError(appendObject(PTO_Image, const_cast<const XML_Char **>(buf)));
+	X_CheckError(appendObject(PTO_Image, const_cast<const gchar **>(buf)));
 	DELETEP(pfg);
 }
 
-void IE_Imp_XSL_FO::charData(const XML_Char *s, int len)
+void IE_Imp_XSL_FO::charData(const gchar *s, int len)
 {
+	if(m_bPendingFootnote) //ignore the character data between <fo:footnote> and <fo:footnote-body>
+		return;
+
 	if(m_iTableDepth && (m_parseState != _PS_Table))
 	{
 		UT_UCS4String span = s;
 
-		if(UT_strcmp(span.utf8_str(), "\n") != 0) //don't insert linefeeds
+		if(strcmp(span.utf8_str(), "\n") != 0) //don't insert linefeeds
 			m_TableHelperStack->Inline(span.ucs4_str(), span.length());
 
 		return;
